//clear & choose directory
e.g.
*local DIR = "C:\Users\Administrator\Documents\Dropbox\Alsace Lorraine\Stata"
cap cd "`DIR'"
*Your directory
local DIR = "   "
cap cd "`DIR'"

********************************************************************************
set more off,perm
clear matrix
clear mata
set mat 5000

/*create folders "data processed" (where processed data are stored) and
"tables" (where tables are stored) [code for this section graciously provided by
Kai Gehring]*/
program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"processed data"'	  	/* does folder "processed data" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "processed data"  	/* makes the folder  */
							  } 
			  else {
				di "folder data processed already exists"
				}
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
*		confirmdir `"ado"'		  /* does folder "ado" exist? */
*			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
*				mkdir "ado"  /* makes the folder  */
*							  } 
*			  else {
*				di "folder ado already exists"
*				}
	program drop confirmdir

***********Find and install necessary programs 
capture  noisily ssc install _gwtmean
capture  noisily ssc install carryforward
capture  noisily net install usespss, replace from(http://radyakin.org/transfer/usespss/beta/)
capture  noisily net install estout, from(http://fmwww.bc.edu/RePEc/bocode/e)
capture  noisily net install  matchit, from(http://fmwww.bc.edu/RePEc/bocode/m)
capture  noisily net install  usespss, from(http://radyakin.org/transfer/usespss/beta)
capture  noisily  install freqindex, from(http://fmwww.bc.edu/RePEc/bocode/f)
*Translate files that contain French letters not available

clear
unicode analyze *
unicode encoding set ISO-8859-1
unicode translate *	

********************************************************************************
*************************	Churches, from Stephanos Vlachos  ******************

import excel "municipalities_churches_Lorraine.xls", sheet("Sheet1") firstrow clear
drop if insee_code==.
gen churches_number = churches_OPR
replace churches_number = churches_Clochers if churches_OPR==.
replace catholic_dummy=-1 if catholic_dummy==1
replace catholic_dummy=1 if catholic_dummy==0
replace catholic_dummy=0 if catholic_dummy==-1

keep insee_code churches_number catholic_dummy protestant_dummy

save "processed data\municipalities_churches_Lorraine.dta", replace

********************************************************************************
*************************	Maginot Line (geoprocessed)*************************

use "Is_maginot_Lorraine_Alsace.dta", clear
gen  maginot_right = Is_maginot
gen distance_maginot=.
replace distance_maginot = NEAR_DIST if maginot_right==1
replace distance_maginot = -NEAR_DIST if maginot_right==0

keep insee_code maginot_right distance_maginot
save "processed data\Is_maginot_Lorraine_Alsace.dta", replace

********************************************************************************
*************************	Department Pairs (from ArcGIS)  ********************
use "processed data\border_pair_distance.dta", clear
destring code_dept code_dept_adjacent, replace force
drop if code_dept==. | code_dept_adjacent==.
egen pair1 = rowmin(code_dept code_dept_adjacent)
egen pair2 = rowmax(code_dept code_dept_adjacent)
gen pair = 100* pair1+pair2
gen distance_pair = .
gen treat_dep = .
replace distance_pair =dborder if code_dept< code_dept_adjacent
replace treat_dep =1 if code_dept< code_dept_adjacent
replace distance_pair =-dborder if code_dept> code_dept_adjacent
replace treat_dep =0 if code_dept> code_dept_adjacent
drop pair1 pair2 dborder
gen insee_code=insee_com
destring insee_code, replace force
drop if insee_code==.
save "processed data\border_pair_distance_final.dta", replace

***************************************************************************************
*************************Digitized data*******************************
***************************************************************************************
import excel "lorraine_clean_parl1968_mixed_circ.xls", firstrow clear
collapse (sum) votes_total votes_UDRRI, by(ID_2)
gen share_68_UDRRI = votes_UDRRI/votes_total
keep ID_2 share_68_UDRRI
gen NAME_2 = "Meurthe-et-Moselle" if ID_2 == 57
replace NAME_2 = "Meuse" if ID_2 == 58
replace NAME_2 = "Moselle" if ID_2 == 59
export excel "lorraine_clean_parl1968_mixed_dep.xls", firstrow(var) replace

***************************************************************************************************
*************************	CATHOLIC CHURCHES, from Stephanos Vlachos *****************************
use "02r_churches.dta", clear

gen insee_code = com
drop com

save "processed data\02r_churches.dta", replace

************ OUT OF WEDLOCK from census 1990 ***********************************

use "fam01sc", clear
keep  codgeo c1 c122 c67 c12 
gen insee_code=codgeo
drop codgeo
destring insee_code, replace force
drop if insee_code==.
collapse (sum) c*, by(insee_code)
gen out_wedlock90 = 1-(c122/c1)
gen single_parents90 = c12/c1
keep insee_code out_wedlock90 single_parents90
save "processed data\census_fam_90.dta", replace

************ OUT OF WEDLOCK from census 1999 ***********************************

use "fam1ss", clear
keep com c1 c12 c122 
gen insee_code=com
drop com
destring insee_code, replace force
drop if insee_code==.
collapse (sum) c*, by(insee_code)
gen out_wedlock99 = 1-(c122/c1)
gen single_parents99 = c12/c1
keep insee_code out_wedlock99 single_parents99
save "processed data\census_fam_99.dta", replace
********************************************************************************

********************************************************************************
************* French Census: People staying at home
*******************************************************************************
*keep variables on people staying in same quarter, commune, department and region

*1990 census: 
use "mig01sc.dta", clear

ren codgeo 	insee_code
* note that 1% of observations is lost to destring force due to A and B in insee codes
replace insee_code = subinstr(insee_code, "A", "888",.)
replace insee_code = subinstr(insee_code, "B", "999",.)

ren c18 	samequarter_8290
ren c19 	samecommune_8290
ren c20 	samedepartment_8290
ren c21 	sameregion_8290

label var samequarter_8290 		"Percentage of residents living in the same quarter in 1990 as in 1982"
label var samecommune_8290 		"Percentage of residents living in the same commune in 1990 as in 1982"
label var samedepartment_8290 	"Percentage of residents living in the same department in 1990 as in 1982"
label var sameregion_8290 		"Percentage of residents living in the same region in 1990 as in 1982"

keep insee_code	samequarter_8290 samecommune_8290 samedepartment_8290 sameregion_8290 
destring insee_code, force replace
collapse (mean) samequarter_8290 samecommune_8290 samedepartment_8290 sameregion_8290, by(insee_code)

save "processed data\mig01sc_cleaned.dta", replace

*1999 census
use "mig2ss.dta", clear

ren com 	insee_code
ren c10 	samequarter_9099
ren c11 	samecommune_9099
ren c12 	samedepartment_9099
ren c13 	sameregion_9099

label var samequarter_9099 		"Percentage of residents living in the same quarter in 1999 as in 1990"
label var samecommune_9099 		"Percentage of residents living in the same commune in 1999 as in 1990"
label var samedepartment_9099 	"Percentage of residents living in the same department in 1999 as in 1990"
label var sameregion_9099 		"Percentage of residents living in the same region 1999 as in 1990"

keep insee_code samequarter_9099 samecommune_9099	samedepartment_9099	sameregion_9099
destring insee_code, force replace
collapse (mean) samequarter_9099 samecommune_9099 samedepartment_9099 sameregion_9099, by(insee_code)

save "processed data\mig2ss_cleaned.dta", replace

********************************************************************************
************* Newspaper Sales (from newspaper directly obtained) ***************
********************************************************************************

*import excel "2014 VNO ABTS ER PAR COMMUNES cleaned.XLSX", sheet("Sheet1") firstrow clear
import excel "2014 VNO ABTS ER PAR COMMUNES cleaned.xls", firstrow clear
*drop summary rows
drop if Localite == ""
 
ren CodeINSEE 			insee_code
ren VenteNette2014 		netsales2014
ren MoyVNOABO2014 		avgVNOABO
ren MoyABO2014 			avgABO
ren VNOMoyenne2014		avgVNO
ren Nombredefoyers 		nrhouseholds
ren Nbpointsdevente2014 nrpointofsale 

drop avgVNO //Usually tiny number
drop  Departement Canton Localite newspaper
destring insee_code, force replace 
collapse (mean) avg*  nrhouseholds (sum) netsales* nrpointofsale, by(insee_code)

label var nrhouseholds			"Nr. of Households in Newspaper Dataset"
label var nrpointofsale			"Nr. of Points of Sale in Newspaper Dataset"
label var avgABO				"Average Subscriptions Republicain Lorrain"
label var avgVNOABO			"Average Subscriptions + other sales Republicain Lorrain"
label var netsales2014 		"No. sold newspapers overall Republicain Lorrain"

foreach var in   avgABO avgVNOABO netsales2014 {
gen `var'_ph=`var'/nrhouseholds 
}
save "processed data\NewspaperSales2014_cleaned.dta", replace


********************************************************************************
************* PART 1: Appending French municipality centroids (from ArcGIS) ****
********************************************************************************
//1.1: French government data on French municipalities
//accessed from https://www.data.gouv.fr/fr/datasets/correspondance-entre-les-codes-postaux-et-codes-insee-des-communes-francaises/ (01/09/15)
//include INSEE codes, zip codes, geosptial reference data, area, population...
//the distances to several borders and cities were calculated using ArcGIS
//the ruggedness data are taken from http://diegopuga.org/data/rugged/ (01/22/15)
//key: insee_com gives INSEE codes, postal_code gives zip codes

//load data set
import excel "FRA_mun_cent_raw.xls", sheet("FRA_mun_cent_raw") firstrow clear

//drop data from GIS that won't be needed for econometric analyses
drop z_moyen id_geofla statut

/*some of the bigger cities have two alternative zip codes, which are provided
as one string. We'll split the two, write the second one to a new variable, and
keep the first one*/
gen zip_code_alt = ""
replace zip_code_alt = substr(postal_cod, -5, .) if strlen(postal_cod)>5
replace postal_cod = substr(postal_cod, 1, 5) if strlen(postal_cod)>5

/*destring numeric variables; we need the force option because Corsican
municipalities have some non-numeric codes*/
destring insee_com postal_cod superficie population code_comm code_cant ///
code_arr code_dept code_reg zip_code_alt, replace force

/*Corsica's not really very interesting to us, so we drop that
(municipalities there have zip codes between [20000,21000). Likewise, overseas
territories have to be dropped (those have INSEE codes >= 97100, but NOT missing
codes)*/
drop if postal_cod>=20000 & postal_cod<21000
drop if insee_com>=97100 & insee_com~=.

gen ID_canton = 1000*code_dept+code_cant

/*for conformity across data sets, we  rename the region/departement etc.
ID variables*/
rename (code_reg code_dept code_cant code_arr code_comm) ///
(ID_1 ID_2 ID_3 ID_4 ID_5)

/*change variable names so they'll match across datasets*/
rename (superficie postal_cod insee_com) (area zip_code insee_code)

/*the ruggedness index is in millimeters, and we  change it to hundreds of
meters*/
replace ra_ruggedness_index_nunn_puga=ra_ruggedness_index_nunn_puga/100000

rename (nom_comm nom_dept nom_reg) (mun_name dep_name reg_name)

/*population is in thousands here, so qw change that */
gen pop_tot=population*1000
drop population

/*to have area in square km, divide by 100 */
replace area=area/100
gen pop_area=pop_tot/area
/*generate a dummy variable is_fra = 1 for all French communes (which
is much easier to do now than after merging the data sets)*/
gen is_fra=1

/*generate dummy variables for being part of Alsace and/or Lorraine, and also
being part of the medieval kingdom*/
gen is_as = (ID_2==67 | ID_2==68)
gen is_lr = (ID_2==57) 
gen is_aslr = (is_as | is_lr)
gen is_med_aslr = (ID_1==41 | ID_1==42)
ren FID OBJECTID

save "processed data\FRA_mun_cent_merge.dta", replace

********************************************************************************
use "processed data\FRA_mun_cent_merge.dta",clear
//reorder the variables
/*the data we're about to merge often have only one observation for Paris,
Marseille und Lyon. The base data have every single arrondissement for those
cities. We'll generate a new observation for each city, that'll have the average
distance to each border and city across all arrondissements as its distance
value. We'll assign it the zip codes that it has in the INSEE data w're about to
merge. If you want to look these up, merge without adding the new observations,
and look at the three _merge==2. This has no relevance for what we do in this paper. */

//Paris
scalar define numobs=_N+1
set obs `=numobs'
sum OBJECTID if is_fra==1, meanonly
scalar define obid=r(max)+1
replace OBJECTID=obid if OBJECTID==.
replace insee_code=75056 if OBJECTID==obid
replace zip_code=75000 if OBJECTID==obid //may be changed for later merges
replace mun_name="PARIS" if OBJECTID==obid
replace dep_name="PARIS" if OBJECTID==obid
replace reg_name="ILE-DE-FRANCE" if OBJECTID==obid
replace ID_1=11 if OBJECTID==obid
replace ID_2=75 if OBJECTID==obid
//there's not really a sensible replacement value for ID_3 for Paris
replace ID_4=1 if OBJECTID==obid
replace ID_5=056 if OBJECTID==obid
quietly foreach var of varlist pop_tot area{
	sum `var' if insee_code>=75000 & insee_code<76000, meanonly
	replace `var'=r(sum) if OBJECTID==obid
}
replace pop_area=pop_tot/area if OBJECTID==obid
quietly foreach var of varlist point_* dist_* ra_*{ 
	sum `var' if insee_code>=75000 & insee_code<76000, meanonly
	replace `var'=r(mean) if OBJECTID==obid
}
quietly foreach var of varlist rmin_*{ 
	sum `var' if insee_code>=75000 & insee_code<76000, meanonly
	replace `var'=r(min) if OBJECTID==obid
}
quietly foreach var of varlist rmax_*{ 
	sum `var' if insee_code>=75000 & insee_code<76000, meanonly
	replace `var'=r(max) if OBJECTID==obid
}
quietly foreach var of varlist rstd_*{ 
	sum `var' if insee_code>=75000 & insee_code<76000
	replace `var'=r(mean) if OBJECTID==obid
}
replace is_fra=1 if OBJECTID==obid
replace is_as=0 if OBJECTID==obid
replace is_lr=0 if OBJECTID==obid
replace is_med_aslr=0 if OBJECTID==obid
scalar drop numobs obid

//Lyon
scalar define numobs=_N+1
set obs `=numobs'
sum OBJECTID if is_fra==1, meanonly
scalar define obid=r(max)+1
replace OBJECTID=obid if OBJECTID==.
replace insee_code=69123 if OBJECTID==obid
replace zip_code=69000 if OBJECTID==obid
replace mun_name="LYON" if OBJECTID==obid
replace dep_name="LYON" if OBJECTID==obid
replace ID_1=82 if OBJECTID==obid
replace ID_2=69 if OBJECTID==obid
replace ID_3=99 if OBJECTID==obid
replace ID_4=1 if OBJECTID==obid
replace ID_5=123 if OBJECTID==obid
quietly foreach var of varlist pop_tot area{
	sum `var' if insee_code>=69380 & insee_code<69390, meanonly
	replace `var'=r(sum) if OBJECTID==obid
}
replace pop_area=pop_tot/area if OBJECTID==obid
quietly foreach var of varlist point_* dist_* ra_*{ 
	sum `var' if insee_code>=69380 & insee_code<69390, meanonly
	replace `var'=r(mean) if OBJECTID==obid
}
quietly foreach var of varlist rmin_*{ 
	sum `var' if insee_code>=69380 & insee_code<69390, meanonly
	replace `var'=r(min) if OBJECTID==obid
}
quietly foreach var of varlist rmax_*{ 
	sum `var' if insee_code>=69380 & insee_code<69390, meanonly
	replace `var'=r(max) if OBJECTID==obid
}
quietly foreach var of varlist rstd_*{ 
	sum `var' if insee_code>=69380 & insee_code<69390
	replace `var'=r(mean) if OBJECTID==obid
}
replace is_fra=1 if OBJECTID==obid
replace is_as=0 if OBJECTID==obid
replace is_lr=0 if OBJECTID==obid
replace is_med_aslr=0 if OBJECTID==obid
scalar drop numobs obid

//Marseille
scalar define numobs=_N+1
set obs `=numobs'
sum OBJECTID if is_fra==1, meanonly
scalar define obid=r(max)+1
replace OBJECTID=obid if OBJECTID==.
replace insee_code=13055 if OBJECTID==obid
replace zip_code=13000 if OBJECTID==obid
replace mun_name="MARSEILLE" if OBJECTID==obid
replace dep_name="MARSEILLE" if OBJECTID==obid
replace ID_1=93 if OBJECTID==obid
replace ID_2=13 if OBJECTID==obid
replace ID_3=99 if OBJECTID==obid
replace ID_4=3 if OBJECTID==obid
replace ID_5=055 if OBJECTID==obid
quietly foreach var of varlist pop_tot area{
	sum `var' if insee_code>=13200 & insee_code<13300, meanonly
	replace `var'=r(sum) if OBJECTID==obid
}
replace pop_area=pop_tot/area if OBJECTID==obid
quietly foreach var of varlist point_* dist_* ra_*{ 
	sum `var' if insee_code>=13200 & insee_code<13300, meanonly
	replace `var'=r(mean) if OBJECTID==obid
}
quietly foreach var of varlist rmin_*{ 
	sum `var' if insee_code>=13200 & insee_code<13300, meanonly
	replace `var'=r(min) if OBJECTID==obid
}
quietly foreach var of varlist rmax_*{ 
	sum `var' if insee_code>=13200 & insee_code<13300, meanonly
	replace `var'=r(max) if OBJECTID==obid
}
quietly foreach var of varlist rstd_*{ 
	sum `var' if insee_code>=13200 & insee_code<13300
	replace `var'=r(mean) if OBJECTID==obid
}
replace is_fra=1 if OBJECTID==obid
replace is_as=0 if OBJECTID==obid
replace is_lr=0 if OBJECTID==obid
replace is_med_aslr=0 if OBJECTID==obid
scalar drop numobs obid

//label variables
label var OBJECTID "ArcGIS object ID"
label var insee_code "INSEE community code"
label var zip_code "Zip code"
label var zip_code_alt "Alternative zip code"
label var ID_1 "R√©gion/Bundesland"
label var ID_2 "D√©partement/Regierungsbezirk"
label var ID_3 "Canton/Kreis"
label var ID_4 "Arrondissement/Gemeindeverband"
label var ID_5 "Commune/Gemeinde"
label var ID_canton "Unique Identifier Canton"
label var mun_name "Municipality name"
label var dep_name "D√©partement/Bundesland name"
label var reg_name "R√©gion/Bundesland name"
label var pop_tot "Total population in 2013"
label var area "Area in square km"
label var pop_area "Population per square km"
label var is_fra "Dummy: French"
label var is_as "Dummy: Alsace"
label var is_lr "Dummy: Lorraine"
label var is_aslr "Dummy: Alsace or Lorraine"
label var is_med_aslr "Dummy: Medieval Alsace-Lorraine"
label var francophone "Dummy: French-speaking side of the language border"
label var point_x_meters "Point x-coordinate in meters"
label var point_y_meters "Point y-coordinate in meters"
label var dist_b_AS_LR "Distance to border: Alsace/Lorraine"
label var dist_b_ASLR_FRA "Distance to border: Alsace-Lorraine/France"
label var dist_b_ASLR_DEU "Distance to border: Alsace-Lorraine/Germany"
label var dist_b_LANGUAGE "Distance to language border"
label var dist_b_MED_ASLR_FRA "Distance to border: Medieval Alsace-Lorraine/France"
label var dist_b_BEL_FRA "Distance to border: Belgium/France"
label var dist_b_BEL_DEU "Distance to border: Belgium/Germany"
label var dist_b_CHE_FRA "Distance to border: Switzerland/France"
label var dist_b_CHE_DEU "Distance to border: Switzerland/Germany"
label var dist_b_LUX_FRA "Distance to border: Luxembourg/France"
label var dist_b_LUX_DEU "Distance to border: Luxembourg/Germany"
label var dist_b_BR_VOSGES "Distance to border: Bas-Rhin/Vosges"
label var dist_b_HR_VOSGES "Distance to border: Haut-Rhin/Vosges"
label var dist_b_HRBR_VOSGES "Distance to border: Haut-Rhin & Bas-Rhin/Vosges"
label var dist_b_MOS_MEMOS "Distance to border: Moselle/Meurthe-et-Moselle"
label var dist_b_HR_BR "Distance to border: Haut-Rhin/Bas-Rhin"
label var dist_c_METZ "Distance to city: Metz"
label var dist_c_STRASBOURG "Distance to city: Strasbourg"
label var dist_c_BELFORT "Distance to city: Belfort"
label var dist_c_NANCY "Distance to city: Nancy"
label var dist_c_EPINAL "Distance to city: Epinal"
label var dist_c_MULHOUSE "Distance to city: Mulhouse"
label var dist_c_BASEL "Distance to city: Basel"
label var dist_c_FREIBURG "Distance to city: Freiburg im Breisgau"
label var dist_c_KARLSRUHE "Distance to city: Karlsruhe"
label var dist_c_SAARBRUECKEN "Distance to city: Saarbruecken"
label var dist_c_BRUSSELS "Distance to city: Brussels"
label var dist_c_LAUSANNE "Distance to city: Lausanne"
label var ra_ruggedness_index_nunn_puga "Raster average: Nunn & Puga ruggedness index"
label var ra_barley_int_irr_resample "Raster average: FAO GAEZ potential yield: barley, intermediate input, irrigated"
label var ra_barley_int_rf_resample "Raster average: FAO GAEZ potential yield: barley, intermediate input, rain-fed"
label var ra_potato_int_irr_resample "Raster average: FAO GAEZ potential yield: potato, intermediate input, irrigated"
label var ra_potato_int_rf_resample "Raster average: FAO GAEZ potential yield: potato, intermediate input, rain-fed"
label var ra_wheat_int_irr_resample "Raster average: FAO GAEZ potential yield: wheat, intermediate input, irrigated"
label var ra_wheat_int_rf_resample "Raster average: FAO GAEZ potential yield: wheat, intermediate input, rain-fed"
label var rmin_elevation_raster "Raster minimum: elevation"
label var rmax_elevation_raster "Raster maximum: elevation"
label var ra_elevation_raster "Raster average: elevation"
label var rstd_elevation_raster "Raster standard deviation: elevation"

/*in order to be able to create subsets of data, we record the
variables that are in here so far, minus all possible identifiers*/
local varlist_identifiers = "OBJECTID insee_code zip_code zip_code_alt"

qui ds `varlist_identifiers', not
local varlist_mun_geo = r(varlist) 

local varlist_all = "`varlist_identifiers' `varlist_mun_geo'"
//export the finished dataset
//just to keep version names coherent
global savenum=1
save "processed data\AlsaceLorraine$savenum.dta", replace

********************************************************************************
************* PART 2: Dependent variables
********************************************************************************

//2.1: CDSP data on French elections
//2.1.1: 1992 & 2005 referendums on EU treaties
//contain data on referendum results, voters, abstentions...
//key: implicitly contain INSEE codes (see below)

//import data on 1992 referendum
import excel "cdsp_refe1992_comm.xls", ///
sheet("cdsp_refe1992_comm") cellrange(A3:M36689) firstrow clear

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren d√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi


/*first, we need to drop Corsica, since a) it's not interesting for the analysis
and b) its department codes contain non-numeric characters, which is
problematic for the following computations	*/
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"

/*these data don't have INSEE codes, but they do have department and commune
numbers, from which INSEE codes may be contructed as follows*/
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune

/*some of the communities in here have old INSEE codes, which we need to change
in order to be able to match them to the base data*/
replace insee_code=14697 if insee_code==14624
replace insee_code=54602 if insee_code==55227

/*some of the communities in here have been integrated into larger ones; we need
to repeat this process in order to really establish a mapping between the
communities in the referendum data and those in the base data. To reconstruct
the list of communities in the referendum data that have been restructured,
simply drop the following section and merge the data to the base data, and
look at those communties in the using data that can't be merged (_merge==2).
Anyways, we just need to add/average data across communities as appropriate,
using the keys of the no longer existent communities to connect their data to
the still existing larger communities*/
matrix oldcode=(7350,16022,16159,21551,26158,27328,28042,39524, ///
49210,50303,50383,51700,51701,51702,51703,51704,51705,51706,51707, ///
51708,51709,51710,51711,51712,51713,59248,59355,59540,61022,61254, ///
62110,62575,70073,71211,71560,74990,74998,74999,76095,79017,79037, ///
79305,80370,81107,85068,88034)

matrix newcode=(7010,16339,16297,21084,26091,27297,28361,39367, ///
49206,50216,50129,51454,51454,51454,51454,51454,51454,51454,51454, ///
51454,51454,51454,51454,51454,51454,59183,59350,59183,61483,61483, ///
62473,62473,70004,71443,71101,74012,74010,74010,76540,79195,79013, ///
79013,80369,81132,85036,88413)

scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-OUIVoix NONVoix{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
sum OUIVoix if insee_code==`=new', meanonly
replace OUIexprims=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum NONVoix if insee_code==`=new', meanonly
replace NONexprims=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

/*finally, there's one municipality in here that can't be merged, 
it is not in any region we are concerned with, drop that*/
drop if commune=="COMMUNE 073"

/*overseas territories have three-digit department codes in these data, so its
easy to drop them*/
drop if Codedpartement>=100

//we drop some variables that are redundant
drop Codedpartement Dpartement Codecommune commune

/*we need to rename the remaining variables to facilitate working with them in
combination with other election/referendum data*/
rename (Inscrits Abstention Votants BlancsetNuls Exprims OUIVoix OUIexprims ///
NONVoix NONexprims) (r92_reg r92_abs r92_votes r92_inval r92_val r92_y r92_yf ///
r92_n r92_nf)
save "processed data\cdsp_refe1992_comm.dta", replace
***************************************************************
//import data on 2005 referendum
clear
import excel "cdsp_refe2005_comm.xls", ///
sheet("cdsp_refe2005_comm") cellrange(A3:M36681) firstrow

*Remove french accents
cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren d√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune
replace insee_code=26020 if insee_code==26383
replace insee_code=61483 if insee_code==61022
matrix oldcode=(21551,28042,39524,50303,59248,59540,76095,79037,79305, ///
80370,81107,88034)
matrix newcode=(21084,28361,39367,50216,59183,59183,76540,79013, ///
79013,80369,81132,88413)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-OUIVoix NONVoix{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
sum OUIVoix if insee_code==`=new', meanonly
replace OUIexprims=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum NONVoix if insee_code==`=new', meanonly
replace NONexprims=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop if Codedpartement>=100
drop Codedpartement Dpartement Codecommune commune
rename (Inscrits Abstention Votants BlancsetNuls Exprims OUIVoix OUIexprims ///
NONVoix NONexprims) (r05_reg r05_abs r05_votes r05_inval r05_val r05_y r05_yf ///
r05_n r05_nf)

save "processed data\cdsp_refe2005_comm.dta", replace

*Keep only commune names and departments
//import data on 1992 referendum
import excel "cdsp_refe1992_comm.xls", ///
sheet("cdsp_refe1992_comm") cellrange(A3:M36689) firstrow clear

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren d√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune

keep Codedpartement Dpartement Codecommune commune
replace commune= "BORS2" if commune=="BORS" &Dpartement=="CHARENTE" & [_n]==5538 //Does not affect estimation later
save "processed data\codes.dta", replace
*********************************************************************
clear
import excel "reg15_northeast", firstrow
ren Codedudépartement ID_2
ren Libellédudépartement dpt_name
ren Codedelacommune ID_5
ren Libellédelacommune commune_name
rename * reg15=
rename ( reg15ID_2 reg15ID_5) (ID_2 ID_5)
rename *LibelléAbrégéListe* *Lal_*
rename *LibelléEtenduListe* *Lel_*
rename *NomTêtedeListe* *Ntl_*
save "processed data\reg15_comm_t1_clean.dta",replace
********************************************************************************

//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1

//merge '92 referendum data
merge m:1 insee_code using "processed data\cdsp_refe1992_comm.dta", nogen

//merge '05 referendum data
merge m:1 insee_code using "processed data\cdsp_refe2005_comm.dta", nogen


duplicates list ID_2 ID_5
drop if ID_5==.


merge 1:1 ID_2 ID_5 using "processed data\reg15_comm_t1_clean.dta", gen(merge1)


//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace

********************************************************************************

//2.1.2: 2007 presidential election (both rounds)
//contain data on election results, voters, abstentions...
//key: implicitly contain INSEE codes (see below)

//import data on first round of election
import excel "cdsp_presi2007t1_comm.xls", ///
sheet("cdsp_presi2007t1_comm") cellrange(A4:AS36566) firstrow clear

*Remove french accents
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Codedepartement Codedpartement
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//data processing is similar to the referendum data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Numrodecommune, replace
gen insee_code=Codedpartement*1000+Numrodecommune
replace insee_code=26020 if insee_code==26383
replace insee_code=61483 if insee_code==61022
matrix oldcode=(21551,28042,59248,59540,76095,81107,88034)
matrix newcode=(21084,28361,59183,59183,76540,81132,88413)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-voixcandidat12{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
sum voixcandidat01 if insee_code==`=new', meanonly
replace parrapportauxinscritscandi =(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace parrapportauxexprimscandi =(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat02 if insee_code==`=new', meanonly
replace N=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace O=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat03 if insee_code==`=new', meanonly
replace Q=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace R=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat04 if insee_code==`=new', meanonly
replace T=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace U=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat05 if insee_code==`=new', meanonly
replace W=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace X=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat06 if insee_code==`=new', meanonly
replace Z=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AA=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat07 if insee_code==`=new', meanonly
replace AC=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AD=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat08 if insee_code==`=new', meanonly
replace AF=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AG=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat09 if insee_code==`=new', meanonly
replace AI=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AJ=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat10 if insee_code==`=new', meanonly
replace AL=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AM=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat11 if insee_code==`=new', meanonly
replace AO=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AP=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat12 if insee_code==`=new', meanonly
replace AR=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace AS=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Numrodecommune Nomdelacommune

gen p07a_lepen_share = voixcandidat10/Exprims
gen p07a_royale_share = voixcandidat08/Exprims
gen p07a_sarkozy_share = voixcandidat12/Exprims

rename (Inscrits Abstentions Votants Blancsetnuls Exprims voixcandidat01 ///
parrapportauxinscritscandi parrapportauxexprimscandi voixcandidat02 N O ///
voixcandidat03 Q R voixcandidat04 T U voixcandidat05 W X voixcandidat06 Z AA ///
voixcandidat07 AC AD voixcandidat08 AF AG voixcandidat09 AI AJ ///
voixcandidat10 AL AM voixcandidat11 AO AP voixcandidat12 AR AS) ///
(p07a_reg p07a_abs p07a_votes p07a_inval p07a_val p07a_c1nvotes p07a_c1freg ///
p07a_c1fvotes p07a_c2nvotes p07a_c2freg p07a_c2fvotes p07a_c3nvotes ///
p07a_c3freg p07a_c3fvotes p07a_c4nvotes p07a_c4freg p07a_c4fvotes ///
p07a_c5nvotes p07a_c5freg p07a_c5fvotes p07a_c6nvotes p07a_c6freg ///
p07a_c6fvotes p07a_c7nvotes p07a_c7freg p07a_c7fvotes p07a_c8nvotes ///
p07a_c8freg p07a_c8fvotes p07a_c9nvotes p07a_c9freg p07a_c9fvotes ///
p07a_c10nvotes p07a_c10freg p07a_c10fvotes p07a_c11nvotes p07a_c11freg ///
p07a_c11fvotes p07a_c12nvotes p07a_c12freg p07a_c12fvotes)

save "processed data\cdsp_presi2007t1_comm.dta", replace


//import data on second round of election
clear
import excel "cdsp_presi2007t2_comm.xls", ///
sheet("cdsp_presi2007t2_comm") cellrange(A4:P36702) firstrow clear

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Numrodecommune, replace
gen insee_code=Codedpartement*1000+Numrodecommune
replace insee_code=26020 if insee_code==26383
replace insee_code=61483 if insee_code==61022
matrix oldcode=(21551,28042,59248,59540,76095,81107,88034)
matrix newcode=(21084,28361,59183,59183,76540,81132,88413)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-voixcandidat2{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
sum voixcandidat1 if insee_code==`=new', meanonly
replace parrapportauxinscritscandi =(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace parrapportauxexprimscandi =(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
sum voixcandidat2 if insee_code==`=new', meanonly
replace O=(r(mean)/Inscrits)*100 if insee_code==`=new' & r(mean)~=.
replace P=(r(mean)/Exprims)*100 if insee_code==`=new' & r(mean)~=.
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

/*there are data on voters abroad for the second round, which we don't need, and
also on overseas territories*/
drop if Dpartement=="FRANCAIS DE L'ETRANGER"
drop if Codedpartement>=100

//drop redundant information
drop Codedpartement Dpartement Numrodecommune Nomdelacommune Population

gen p07b_royale_share = voixcandidat2/Exprims
gen p07b_sarkozy_share = voixcandidat1/Exprims

//rename variables
rename (Inscrits Abstentions Votants Blancsetnuls Exprims voixcandidat1 ///
parrapportauxinscritscandi parrapportauxexprimscandi voixcandidat2 O P) ///
(p07b_reg p07b_abs p07b_votes p07b_inval p07b_val p07b_c1nvotes p07b_c1freg ///
p07b_c1fvotes p07b_c2nvotes p07b_c2freg p07b_c2fvotes)

save "processed data\cdsp_presi2007t2_comm.dta", replace

********************************************************************************
//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1

//merge data on first round of election
merge m:1 insee_code using "processed data\cdsp_presi2007t1_comm.dta", nogen

//merge data on second round of election
merge m:1 insee_code using "processed data\cdsp_presi2007t2_comm.dta", nogen


//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace

********************************************************************************
*************** PARLIAMENTARY ELECTIONS 2002 ***********************************
import delimited  "cdsp_legi2002t1_comm-m3500.csv", encoding(utf8) clear

cap noisily ren codedépartement codedpartement
cap noisily ren exprimés exprims

//drop Corsica
drop if département=="HAUTE CORSE" | département=="CORSE SUD"


//now, we can calculate INSEE codes as before
destring codedpartement codecommune, replace

//calculate INSEE codes
gen insee_code=codedpartement*1000+codecommune

//again, some municipalities need to be merged
matrix oldcode=(59540,76095)
matrix newcode=(59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist  population-extrêmedroite{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

//drop overseas territories
drop if codedpartement>=100 & codedpartement~=.

//continue with data processing (note that abstentions are redundant data) 
rename (inscrits votants blancsetnuls exprims regionalistes divers) (par02_reg par02_votes ///
par02_inval par02_val par02_rp par02_misc)
rename unionpourlamajoritéprésidentiell par02_ump
rename partisocialiste par02_soc
collapse (sum) par02_reg par02_votes par02_inval par02_val par02_rp par02_misc par02_ump par02_soc,by(insee_code)
gen par02_ump_share = par02_ump/par02_val
gen par02_soc_share = par02_soc/par02_val
keep insee_code par02_reg par02_votes ///
par02_inval par02_val par02_rp par02_misc ///
par02_ump par02_soc par02_ump_share par02_soc_share
save "processed data\cdsp_legi2002t1_comm-m3500.dta", replace 
********************************************************************************
//2.1.3: 1983, '89, '95, 2001 and '08 municipal election data (both rounds)
//contain data on election results, voters, abstentions...
//key: implicitly contain INSEE codes (see below)
//import data on first round of 1983 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1983t1_commp9000-ag.xls", ///
sheet("cdsp_muni1983t1_commp9000-ag") cellrange(A5:T904) firstrow clear

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//drop Corsica
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"

//construct INSEE codes
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune

/*actually, to get the correct INSEE codes for Marseille, we need to subtract 700 from
insee_code; same thing for Lyon, but we need to subtract 520; for Paris, we need to
subtract 800, although there already exists an observation for Paris as a whole,
which actually has a correct INSEE code, so we only need to do that for the
arrondissements (note that 'correct' here means, "the same as in the base data")*/
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS") & Codecommune~=0

/*for Paris as a whole, we need to manually replace the INSEE code to get the
correct one*/
replace insee_code=75056 if regexm(Commune, "^PARIS") & Codecommune==0

/*same problem with the previously individual communes that aren't in the base
data anymore, having been incorporated into larger municipalities*/
matrix oldcode=(50383,59355,59540,76095)
matrix newcode=(50129,59350,59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-Divers{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

//drop overseas territories
drop if Codedpartement>=100 & Codedpartement~=.

//drop redundant variables
drop Codedpartement Dpartement Codecommune Commune

/*classify political parties on a 1 - 5 spectrum (1=extreme left, 5=extreme
right), except miscellaneous and regionalist parties (for later elections),
which get their own categories*/
egen m83a_1=rowtotal(PC EXG)
egen m83a_2=rowtotal(PS RADGAUCHE DVG ECO)
egen m83a_3=rowtotal(UDF)
egen m83a_4=rowtotal(RPR DVD)
egen m83a_5=rowtotal(FN EXD)
//drop raw data, since the classification makes them redundant
drop PC EXG PS RADGAUCHE DVG ECO UDF RPR DVD FN EXD
//rename variables
rename (Inscrits Votants Exprims Blancsetnuls Divers) (m83a_reg m83a_votes ///
m83a_val m83a_inval m83a_misc)
//save the processed data
save "processed data\cdsp_muni1983t1_commp9000-ag.dta", replace
********************************************************************************
//import data on second round of 1983 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1983t2_commp9000-ag.xls", ///
sheet("cdsp_muni1983t2_commp9000-ag") cellrange (A3:R153) firstrow
cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS") & Codecommune~=0
replace insee_code=75056 if regexm(Commune, "^PARIS") & Codecommune==0
matrix oldcode=(50383)
matrix newcode=(50129)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-DIVERS{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop if Codedpartement>=100 & Codedpartement~=.
drop Codedpartement Dpartement Codecommune Commune
egen m83b_1=rowtotal(PC)
egen m83b_2=rowtotal(SOC RADGAUCHE DVG ECO)
egen m83b_3=rowtotal(UDF RPR)
egen m83b_4=rowtotal(DVD)
egen m83b_5=rowtotal(FN)
drop PC SOC RADGAUCHE DVG ECO UDF RPR DVD FN
rename (Inscrits Votants Exprims Blancsetnuls DIVERS) (m83b_reg m83b_votes ///
m83b_val m83b_inval m83b_misc)
save "processed data\cdsp_muni1983t2_commp9000-ag.dta", replace

//import data on first round of 1989 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1989t1_commp9000-ag.xls", ///
sheet("cdsp_muni1989t1_commp9000-ag") cellrange (A5:T931) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//data processing is the same as for the 1983 election
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS") & Codecommune~=0
replace insee_code=75056 if regexm(Commune, "^PARIS") & Codecommune==0
matrix oldcode=(50383,59355,59540,76095)
matrix newcode=(50129,59350,59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-Divers{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop if Codedpartement>=100 & Codedpartement~=.
drop Codedpartement Dpartement Codecommune Commune
egen m89a_1=rowtotal(PC EXG)
egen m89a_2=rowtotal(PS RADGAUCHE DVG ECO)
egen m89a_3=rowtotal(UDF RPR)
egen m89a_4=rowtotal(DVD)
egen m89a_5=rowtotal(FN EXD)
drop PC EXG PS RADGAUCHE DVG ECO UDF RPR DVD FN EXD
rename (Inscrits Votants Exprims Blancsetnuls Divers) (m89a_reg m89a_votes ///
m89a_val m89a_inval m89a_misc)

save "processed data\cdsp_muni1989t1_commp9000-ag.dta", replace


//import data on second round of 1989 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1989t2_commp9000-ag.xls", ///
sheet("cdsp_muni1989t2_commp9000-ag") cellrange (A5:S404) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune
drop if Codedpartement>=100 & Codedpartement~=.
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS") & Codecommune~=0
replace insee_code=75056 if regexm(Commune, "^PARIS") & Codecommune==0
matrix oldcode=(50383,59540)
matrix newcode=(50129,59183)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-Divers{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codecommune Commune
egen m89b_1=rowtotal(PC EXG)
egen m89b_2=rowtotal(PS RADGauche DVG ECO)
egen m89b_3=rowtotal(UDF RPR)
egen m89b_4=rowtotal(DVD)
egen m89b_5=rowtotal(FN)
drop PC EXG PS RADGauche DVG ECO UDF RPR DVD FN
rename (Inscrits Votants Exprims Blancsetnuls Divers) (m89b_reg m89b_votes ///
m89b_val m89b_inval m89b_misc)

save "processed data\cdsp_muni1989t2_commp9000-ag.dta", replace

//import data on first round of 1995 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1995t1_commp9000-ag.xls", ///
sheet("cdsp_muni1995t1_commp9000-ag") cellrange (A6:U967) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codecommune, replace
gen insee_code=Codedpartement*1000+Codecommune
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS")
drop if Codedpartement>=100 & Codedpartement~=.
matrix oldcode=(50383,59355,59540,76095)
matrix newcode=(50129,59350,59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-DIV{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codecommune Commune
egen m95a_1=rowtotal(PC EXG)
egen m95a_2=rowtotal(PS RADGauche DVG ECO VERTS)
egen m95a_3=rowtotal(UDF RPR)
egen m95a_4=rowtotal(DVD)
egen m95a_5=rowtotal(FN EXD)
drop PC EXG PS RADGauche DVG ECO VERTS UDF RPR DVD FN EXD
rename (Inscrits Votants Exprims REG DIV) (m95a_reg m95a_votes m95a_val ///
m95a_rp m95a_misc)

save "processed data\cdsp_muni1995t1_commp9000-ag.dta", replace


//import data on second round of 1995 election
//note: these data are on municipalities with >=9000 inhabitants only!
clear
import excel "cdsp_muni1995t2_commp9000-ag.xls", ///
sheet("cdsp_muni1995t2_commp9000-ag") cellrange (A7:U577) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement, replace
gen insee_code=Codedpartement*1000+Codecommune
replace insee_code=insee_code-700 if regexm(Commune, "^MARSEILLE")
replace insee_code=insee_code-520 if regexm(Commune, "^LYON")
replace insee_code=insee_code-800 if regexm(Commune, "^PARIS") & Codecommune~=0
drop if Codedpartement>=100 & Codedpartement~=.
matrix oldcode=(59540)
matrix newcode=(59183)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-DIV{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codecommune Commune
egen m95b_1=rowtotal(PC EXG)
egen m95b_2=rowtotal(PS RADGauche DVG ECO VERTS)
egen m95b_3=rowtotal(UDF RPR)
egen m95b_4=rowtotal(DVD)
egen m95b_5=rowtotal(FN EXD)
drop PC EXG PS RADGauche DVG ECO VERTS UDF RPR DVD FN EXD
rename (Inscrits Votants Exprims REG DIV) (m95b_reg m95b_votes m95b_val ///
m95b_rp m95b_misc)

save "processed data\cdsp_muni1995t2_commp9000-ag.dta", replace

//import data on first round of 2001 election for communities with >=9000 people
/*we have data on smaller communities, but because the data structure is very
different, we'll do that after finishing the 2008 election*/
clear
import excel "cdsp_muni2001t1_commp9000-ag.xls", ///
sheet("cdsp_muni2001t1_commp9000-ag") cellrange (A6:U1048) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//drop Corsica
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"

/*these data contain individual observations for the arrondissements of Paris,
Lyon and Marseille. However, they use non-numeric values for Codecommune to
label those. First, we need to extract INSEE codes by taking only the first
three digits of the non-numeric codes, which correspond to INSEE community
codes. Then, for municipalities that only have one- or two-digit community
codes, we need to replace the newly generated variable (they'll have a missing
value) by their community code*/
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""

/*next, we need to drop the sectors of Marseille, because there are two
arrondissements per sector (which is the unit we're interested in), making
sectors redundant*/
drop if Codedpartement=="13" & (regexm(Codecommune, ///
"[0-9][0-9][0-9]SR[0-9][0-9]"))

/*now, we need to replace code for the arrondissements of Paris, Lyon and
Marseille, so that their INSEE codes are the actual arrondissement INSEE codes,
not the cities'*/
gen temp=regexs(0) if (regexm(Codecommune, "AR[0-9][0-9]$"))
replace temp=regexs(0) if (regexm(Codecommune, "SR[0-9][0-9]$"))
replace code=regexs(0) if (regexm(temp, "[0-9][0-9]$"))

//now, we can calculate INSEE codes as before
destring Codedpartement code, replace

/*actually, to get the correct INSEE codes for Marseille, we need to add 200 to
code; same thing for Lyon, but we need to add 380, and for Paris, adding 100*/
replace code=200+code if Codedpartement==13 & temp~=""
replace code=380+code if Codedpartement==69 & temp~=""
replace code=100+code if Codedpartement==75 & temp~=""

//calculate INSEE codes
gen insee_code=Codedpartement*1000+code

//again, some municipalities need to be merged
matrix oldcode=(59540,76095)
matrix newcode=(59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-DIV{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

//drop overseas territories
drop if Codedpartement>=100 & Codedpartement~=.

//continue with data processing (note that abstentions are redundant data) 
drop Codedpartement Dpartement Codecommune Commune Population Abstentions ///
code temp
egen m01a_1=rowtotal(EXG)
egen m01a_2=rowtotal(GA DVG VERTS ECO)
egen m01a_3=rowtotal(DR)
egen m01a_4=rowtotal(DVD)
egen m01a_5=rowtotal(FN MNR)
drop EXG GA DVG VERTS ECO DR DVD FN MNR
rename (Inscrits Votants Blancsetnuls Exprims REG DIV) (m01a_reg m01a_votes ///
m01a_inval m01a_val m01a_rp m01a_misc)
save "processed data\cdsp_muni2001t1_commp9000-ag.dta", replace 

*******************************************************************************
//import data on second round of 2001 election (communities with >=9000 people)
clear
import excel "cdsp_muni2001t2_commp9000-ag.xls", ///
sheet("cdsp_muni2001t2_commp9000-ag") cellrange (A6:U519) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""
drop if Codedpartement=="13" & (regexm(Codecommune, ///
"[0-9][0-9][0-9]SR[0-9][0-9]"))
gen temp=regexs(0) if (regexm(Codecommune, "AR[0-9][0-9]$"))
replace temp=regexs(0) if (regexm(Codecommune, "SR[0-9][0-9]$"))
replace code=regexs(0) if (regexm(temp, "[0-9][0-9]$"))
destring Codedpartement code, replace
replace code=200+code if Codedpartement==13 & temp~=""
replace code=380+code if Codedpartement==69 & temp~=""
replace code=100+code if Codedpartement==75 & temp~=""
gen insee_code=Codedpartement*1000+code
matrix oldcode=(76095)
matrix newcode=(76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-DIV{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop if Codedpartement>=100 & Codedpartement~=.
drop Codedpartement Dpartement Codecommune Commune Population Abstentions ///
code temp
egen m01b_1=rowtotal(EXG)
egen m01b_2=rowtotal(GA DVG VERTS ECO)
egen m01b_3=rowtotal(DR)
egen m01b_4=rowtotal(DVD)
egen m01b_5=rowtotal(FN MNR)
drop EXG GA DVG VERTS ECO DR DVD FN MNR
rename (Inscrits Votants Blancsetnuls Exprims REG DIV) (m01b_reg m01b_votes ///
m01b_inval m01b_val m01b_rp m01b_misc)
save "processed data\cdsp_muni2001t2_commp9000-ag.dta", replace
*******************************************************************
//import data on first round of 2008 election
//note: these data are on communities with >=3500 people only
import excel "cdsp_muni2008t1_commp3500.xls", clear ///
sheet("cdsp_muni2008t1_commp3500") cellrange (A5:CP2882) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//drop Corsica
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
/*calculate INSEE codes; this is slightly more involved for Paris, Lyon and
Marseille, where we need to use section codes instead of community codes to get
the correct INSEE codes*/
destring Codedpartement Codedelacommune, replace
gen insee_code=Codedpartement*1000+Codedelacommune
destring SectionouSecteurdecommune, replace
replace insee_code=Codedpartement*1000+100+SectionouSecteurdecommune if regexm(Commune, "^Paris")
replace insee_code=Codedpartement*1000+200+SectionouSecteurdecommune if regexm(Commune, "^Marseille")
replace insee_code=Codedpartement*1000+380+SectionouSecteurdecommune if regexm(Commune, "^Lyon")

//drop overseas territories
drop if Codedpartement>=100

/*classify political parties; this is slightly more incolved here, due to the
different data structure as compared to the previous elections. Afterwards, drop
raw data*/
quietly forvalues i=1(1)5{
gen m08a_`i'=0
}
gen m08a_misc=0
gen m08a_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)12{
replace m08a_`i'=m08a_`i'+Voix`j' if inlist(Sigle`j', "LEXG", "LCOM") & `i'==1
replace m08a_`i'=m08a_`i'+Voix`j' if inlist(Sigle`j', "LUG", "LDVG", "LGC", ///
"LSOC", "LVEC") & `i'==2
replace m08a_`i'=m08a_`i'+Voix`j' if inlist(Sigle`j', "LCMD", "LMC") & `i'==3
replace m08a_`i'=m08a_`i'+Voix`j' if inlist(Sigle`j', "LDVD", "LMAJ") & `i'==4
replace m08a_`i'=m08a_`i'+Voix`j' if inlist(Sigle`j', "LFN", "LEXD") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)12{
replace m08a_misc=m08a_misc+Voix`j' if Sigle`j'=="LAUT" & `i'==1
replace m08a_rp=m08a_rp+Voix`j' if Sigle`j'=="LREG" & `i'==2
}
}
drop Sigle1-Voix12

/*a few other cities have sections, but for these we only have one observation
in the base data, so we need to average across these*/
order insee_code, first
duplicates tag insee_code, generate(dup)
gen altcode=Codedpartement*1000+SectionouSecteurdecommune
matrix oldcode=(2002,22002,33002,42002,49002,49004,49005,71002)
matrix newcode=(2001,22001,33001,42001,49001,49001,49001,71001)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m08a_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop dup altcode

/*also, some municipalities need to be merged because they're merged in the
base data as well*/
matrix oldcode=(59248,59540,76095)
matrix newcode=(59183,59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m08a_rp{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
//drop other unnecessary variable
drop Codedpartement Dpartement Codedelacommune SectionouSecteur Commune ///
Abstentions
//rename variables
rename (Inscrits Votants Blancsetnuls Exprims) (m08a_reg m08a_votes ///
m08a_inval m08a_val)
save "processed data\cdsp_muni2008t1_commp3500", replace
*************************************************************************
//load data on second round of 2008 election
//note: these data are on communities with >=3500 people only
import excel "cdsp_muni2008t2_commp3500.xls", clear ///
sheet("cdsp_muni2008t2_commp3500") cellrange (A5:AS983) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
destring Codedpartement Codedelacommune, replace
gen insee_code=Codedpartement*1000+Codedelacommune
destring SectionouSecteurdecommune, replace
replace insee_code=Codedpartement*1000+100+SectionouSecteurdecommune if regexm(Commune, "^Paris")
replace insee_code=Codedpartement*1000+200+SectionouSecteurdecommune if regexm(Commune, "^Marseille")
replace insee_code=Codedpartement*1000+380+SectionouSecteurdecommune if regexm(Commune, "^Lyon")
drop if Codedpartement>=100
quietly forvalues i=1(1)5{
gen m08b_`i'=0
}
gen m08b_misc=0
gen m08b_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)5{
replace m08b_`i'=m08b_`i'+Voix`j' if inlist(Sigle`j', "LEXG", "LCOM") & `i'==1
replace m08b_`i'=m08b_`i'+Voix`j' if inlist(Sigle`j', "LUG", "LDVG", "LGC", ///
"LSOC", "LVEC") & `i'==2
replace m08b_`i'=m08b_`i'+Voix`j' if inlist(Sigle`j', "LCMD", "LMC") & `i'==3
replace m08b_`i'=m08b_`i'+Voix`j' if inlist(Sigle`j', "LDVD", "LMAJ") & `i'==4
replace m08b_`i'=m08b_`i'+Voix`j' if inlist(Sigle`j', "LFN", "LEXD") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)5{
replace m08b_misc=m08b_misc+Voix`j' if Sigle`j'=="LAUT" & `i'==1
replace m08b_rp=m08b_rp+Voix`j' if Sigle`j'=="LREG" & `i'==2
}
}
drop Sigle1-Voix5
order insee_code, first
duplicates tag insee_code, generate(dup)
gen altcode=Codedpartement*1000+SectionouSecteurdecommune
matrix oldcode=(49004,49005)
matrix newcode=(49001,49001)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m08b_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop dup altcode
matrix oldcode=(76095)
matrix newcode=(76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m08b_rp{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codedelacommune SectionouSecteur Commune Abstentions
rename (Inscrits Votants Blancsetnuls Exprims) (m08b_reg m08b_votes ///
m08b_inval m08b_val)
save "processed data\cdsp_muni2008t2_commp3500", replace
**************************************************************************
//now, we can take care of the other data for 2001 as well
//load data on first round of 2001 election, <3500 inhabitants
import excel "cdsp_muni2001t1_comm-m3500.xls", clear ///
sheet("cdsp_muni2001t1_comm-m3500") cellrange (A6:AB34543) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
drop if regexm(Codedpartement, "^[A-Z]")
destring Codedpartement, replace
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""
destring code, replace
gen insee_code=Codedpartement*1000+code
replace insee_code=26020 if insee_code==26383
order insee_code, first
quietly forvalues i=1(1)5{
gen m01a_`i'=0
}
gen m01a_misc=0
gen m01a_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)6{
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LXG") & `i'==1
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LDG", "LGA", "LEC", "LVE") & `i'==2
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LNC", "NC") & `i'==3
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LDD", "LDR") & `i'==4
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LFN", "LMN") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)6{
replace m01a_misc=m01a_misc+Voix`j' if NuanceListe`j'=="LDV" & `i'==1
replace m01a_rp=m01a_rp+Voix`j' if NuanceListe`j'=="LRG" & `i'==2
}
}
drop NuanceListe1-Voix6
duplicates tag insee_code, generate(dup)
gen sct=regexs(0) if (regexm(Codecommune, "[0-9][0-9]$"))
destring sct, replace
gen altcode=insee_code*10+sct
order altcode, first
matrix input newcode=(12451,12771,14111,22761,23081,23131,27131,28011,28201,28321, ///
70311,72041,72071,72701,72841,80571,80691,80961,81891,82001,82351,82401,83331, ///
83441,84211,84481,92891,92991,93061,100581,101481,102761,103101,120141,120591, ///
120851,120991,121361,122321,122521,122551,140461,141491,143521,143721,145131, ///
145151,146211,146291,147121,147211,190341,216411,216671,221791,221901,222821, ///
230901,230931,232201,240351,240861,241721,242601,243561,244971,250361,251601, ///
251871,252121,252881,253341,253741,253851,254051,254171,254331,254681,254861, ///
255241,255371,261971,281681,311741,330771,340191,342351,350641,350961,351321, ///
380051,380511,381601,383481,384101,385451,412201,421421,422251,422391,440051, ///
440211,440681,461551,462471,462961,480041,480531,480881,480891,481061,481741, ///
490941,492061,492151,492761,500661,501671,501971,504561,505311,505901,506291, ///
511361,512481,514921,515371,515851,516111,530031,530791,531211,531601,594881, ///
594971,595451,596311,605371,606681,621111,622191,625061,628971,640101,640181, ///
640491,640641,640711,641131,641681,642941,643001,643191,643451,643541,643621, ///
644311,644321,644371,644401,644881,650361,650541,650951,650991,651231,651271, ///
651411,651431,652361,653061,653291,653531,653891,670741,671041,671221,671601, ///
672421,672631,673471,673511,674421,674741,674951,675301,675321,681061,681781, ///
683181,691391,700451,700581,700591,702831,702921,703731,704471,704871,705281, ///
730101,730131,730711,732011,732031,733221,733231,740321,740771,741851,781931, ///
790141,790161,790631,790661,790901,791221,791361,791711,792681,793211,802111, ///
802221,802291,802451,805541,805571,805661,806231,806301,807031,830531,850341, ///
850361,850401,851351,852771,861201,862251,862331,870271,870921,871801,890051, ///
890141,890271,890731,891591,892331,892351,892621,892831,893371,893411,893441, ///
894201,894381,894461,894721,953551,27383,192752,440672,440152)
matrix input oldcode=(12452,12772,14112,22762,23082,23132,27132,28012,28202,28322, ///
70312,72042,72072,72702,72842,80572,80692,80962,81892,82002,82352,82402,83332, ///
83442,84212,84482,92892,92992,93062,100582,101482,102762,103102,120142,120592, ///
120852,120992,121362,122322,122522,122552,140462,141492,143522,143722,145132, ///
145152,146212,146292,147122,147212,190342,216412,216672,221792,221902,222822, ///
230902,230932,232202,240352,240862,241722,242602,243562,244972,250362,251602, ///
251872,252122,252882,253342,253742,253852,254052,254172,254332,254682,254862, ///
255242,255372,261972,281682,311742,330772,340192,342352,350642,350962,351322, ///
380052,380512,381602,383482,384102,385452,412202,421422,422252,422392,440052, ///
440212,440682,461552,462472,462962,480042,480532,480882,480892,481062,481742, ///
490942,492062,492152,492762,500662,501672,501972,504562,505312,505902,506292, ///
511362,512482,514922,515372,515852,516112,530032,530792,531212,531602,594882, ///
594972,595452,596312,605372,606682,621112,622192,625062,628972,640102,640182, ///
640492,640642,640712,641132,641682,642942,643002,643192,643452,643542,643622, ///
644312,644322,644372,644402,644882,650362,650542,650952,650992,651232,651272, ///
651412,651432,652362,653062,653292,653532,653892,670742,671042,671222,671602, ///
672422,672632,673472,673512,674422,674742,674952,675302,675322,681062,681782, ///
683182,691392,700452,700582,700592,702832,702922,703732,704472,704872,705282, ///
730102,730132,730712,732012,732032,733222,733232,740322,740772,741852,781932, ///
790142,790162,790632,790662,790902,791222,791362,791712,792682,793212,802112, ///
802222,802292,802452,805542,805572,805662,806232,806302,807032,830532,850342, ///
850362,850402,851352,852772,861202,862252,862332,870272,870922,871802,890052, ///
890142,890272,890732,891592,892332,892352,892622,892832,893372,893412,893442, ///
894202,894382,894462,894722,953552,27384,192753,440673,440153)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01a_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
matrix input newcode=(81131,81131,83191,83191,104261,104261,142311,142311,147351,147351,214331,214331, ///
220933,220933,221181,221181,240681,240681,241681,241681,243541,243541,245491, ///
245491,250181,250181,250181,251011,251011,251011,252751,252751,310851,310851, ///
340361,340361,350681,350681,351301,351301,412731,412731,441281,441281,493731, ///
493731,501421,501421,501881,501881,504441,504441,504931,504931,641481,641481, ///
652181,652181,671761,671761,672061,672061,674351,674351,674521,674521,691101, ///
691101,701011,701011,701011,702471,702471,704921,704921,732611,732611,790051, ///
790051,790311,790311,790611,790611,791961,791961,804061,804061,850201,850201, ///
850201,861081,861081,883221,883221,890551,890551,894071,894071,894141,894141, ///
894391,894391, ///
73341,73341,73341,83661,83661,83661,84371,84371,84371,91071,91071,91071,140111, ///
140111,140111,141261,141261,141261,255051,255051,255051,480341,480341,480341, ///
511581,511581,511581,531271,531271,531271,643961,643961,643961,670341,670341, ///
670341,670611,670611,670611,673391,673391,673391,730031,730031,730031,730061, ///
730061,730061,791231,791231,791231,804361,804361,804361,804561,804561,804561, ///
805821,805821,805821,830351,830351,830351,861611,861611,861611,890681,890681, ///
890681, ///
252231,252231,252231,252231, ///
731871,731871,731871,731871,731871, ///
504101,504101,504101,504101,504101,504101,701221,701221,701221,701221,701221, ///
701221,790791,790791,790791,790791,790791,790791,804431,804431,804431,804431, ///
804431,804431, ///
790492,790492,790492,790492,790492,790492,790492, ///
146971,146971,146971,146971,146971,146971,146971,146971,146971,502561,502561, ///
502561,502561,502561,502561,502561,502561,502561)
matrix input oldcode=(81132,81133,83192,83193,104262,104263,142312,142313,147352,147353,214332,214333, ///
220934,220935,221182,221183,240682,240683,241682,241683,243542,243543,245492, ///
245493,250182,250183,250182,251013,251012,251013,252752,252753,310852,310853, ///
340362,340363,350682,350683,351302,351303,412732,412733,441282,441283,493732, ///
493733,501422,501423,501882,501883,504442,504443,504932,504933,641482,641483, ///
652182,652183,671762,671763,672062,672063,674352,674353,674522,674523,691102, ///
691103,701012,701013,701012,702473,702472,704923,704922,732613,732612,790053, ///
790052,790313,790312,790613,790612,791963,791962,804063,804062,850203,850202, ///
850203,861082,861083,883222,883223,890552,890553,894072,894073,894142,894143, ///
894392,894393, ///
73342,73343,73344,83662,83663,83664,84372,84373,84374,91072,91073,91074,140112, ///
140113,140114,141262,141263,141264,255052,255053,255054,480342,480343,480344, ///
511582,511583,511584,531272,531273,531274,643962,643963,643964,670342,670343, ///
670344,670612,670613,670614,673392,673393,673394,730032,730033,730034,730062, ///
730063,730064,791232,791233,791234,804362,804363,804364,804562,804563,804564, ///
805822,805823,805824,830352,830353,830354,861612,861613,861614,890682,890683, ///
890684, ///
252232,252233,252234,252235, ///
731872,731873,731874,731875,731876, ///
504102,504103,504104,504105,504106,504107,701222,701223,701224,701225,701226, ///
701227,790792,790793,790794,790795,790796,790797,804432,804433,804434,804435, ///
804436,804437, ///
790493,790494,790495,790496,790497,790498,790499, ///
146972,146973,146974,146975,146976,146977,146978,146979,146980,502562,502563, ///
502564,502565,502566,502567,502568,502569,502570)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01a_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop dup altcode sct
matrix oldcode=(21551,26158,28042,39524,50303,61022,61254,71211,79037,79305, ///
80370,81107,88034,76095)
matrix newcode=(21084,26091,28361,39367,50216,61483,61483,71443,79013,79013, ///
80369,81132,88413,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01a_rp{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codecommune Population Commune ///
Abstentions code
rename (Inscrits Votants Blancsetnuls Exprims) (m01a_reg m01a_votes ///
m01a_inval m01a_val)
save "processed data\cdsp_muni2001t1_comm-m3500", replace
**************************************************************************
//load data on first round of 2001 election, 3500-9000 inhabitants
clear
import excel "cdsp_muni2001t1_comm3500-9000.xls", ///
sheet("cdsp_muni2001t1_comm3500-9000") cellrange (A6:Y1681) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
drop if regexm(Codedpartement, "^[A-Z]")
destring Codedpartement, replace
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""
destring code, replace
gen insee_code=Codedpartement*1000+code
order insee_code, first
quietly forvalues i=1(1)5{
gen m01a_`i'=0
}
gen m01a_misc=0
gen m01a_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)5{
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LXG") & `i'==1
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LDG", "LGA", "LEC", "LVE") & `i'==2
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LNC", "NC") & `i'==3
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LDD", "LDR") & `i'==4
replace m01a_`i'=m01a_`i'+Voix`j' if inlist(NuanceListe`j', "LFN", "LMN") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)5{
replace m01a_misc=m01a_misc+Voix`j' if NuanceListe`j'=="LDV" & `i'==1
replace m01a_rp=m01a_rp+Voix`j' if NuanceListe`j'=="LRG" & `i'==2
}
}
drop NuanceListe1-Voix5
duplicates tag insee_code, generate(dup)
gen sct=regexs(0) if (regexm(Codecommune, "[0-9][0-9]$"))
destring sct, replace
gen altcode=insee_code*10+sct
matrix oldcode=(27382,220932,422792,441312,493284,493285,530622)
matrix newcode=(27381,220931,422791,441311,493281,493281,530621)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01a_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
matrix oldcode=(59248)
matrix newcode=(59183)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01a_rp{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop dup altcode sct
drop Codedpartement Dpartement Codecommune Population Commune ///
Abstentions code
rename (Inscrits Votants Blancsetnuls Exprims) (m01a_reg m01a_votes ///
m01a_inval m01a_val)
save "processed data\cdsp_muni2001t1_comm3500-9000", replace
*************************************************************************
//load data on second round of 2001 election, <3500 inhabitants
import excel "cdsp_muni2001t2_comm-m3500.xls",clear ///
sheet("cdsp_muni2001t2_comm-m3500") cellrange (A6:AB12203) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
drop if regexm(Codedpartement, "^[A-Z]")
destring Codedpartement, replace
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""
destring code, replace
gen insee_code=Codedpartement*1000+code
order insee_code, first
quietly forvalues i=1(1)5{
gen m01b_`i'=0
}
gen m01b_misc=0
gen m01b_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)6{
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LXG") & `i'==1
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LDG", "LGA", "LEC", "LVE") & `i'==2
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LNC", "NC") & `i'==3
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LDD", "LDR") & `i'==4
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LFN", "LMN") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)6{
replace m01b_misc=m01b_misc+Voix`j' if NuanceListe`j'=="LDV" & `i'==1
replace m01b_rp=m01b_rp+Voix`j' if NuanceListe`j'=="LRG" & `i'==2
}
}
drop NuanceListe1-Voix6
duplicates tag insee_code, generate(dup)
gen sct=regexs(0) if (regexm(Codecommune, "[0-9][0-9]$"))
destring sct, replace
gen altcode=insee_code*10+sct
order altcode, first
matrix input oldcode=(12772,80572,82352,82402,83663,102762,122322,140114,143522, ///
214333,221182,222822,232202,250182,251602,252234,252882,310853,340192,350682, ///
385452,440212,501883,504442,504562,504933,506292,511362,511582,514922,531602, ///
595452,606682,621112,650362,670742,672062,681782,691392,700592,701223,730064, ///
731873,733222,740322,790162,790662,791233,791963,805662,806302,851352,861202, ///
870922,890552,894072, ///
340362,340363,830353,830354,894392,894393)
matrix input newcode=(12771,80571,82351,82401,83661,102761,122321,140111,143521, ///
214332,221181,222821,232201,250181,251601,252231,252881,310852,340191,350681, ///
385451,440211,501882,504441,504561,504931,506291,511361,511581,514921,531601, ///
595451,606681,621111,650361,670741,672061,681781,691391,700591,701221,730061, ///
731871,733221,740321,790161,790661,791231,791962,805661,806301,851351,861201, ///
870921,890551,894071, ///
340361,340361,830351,830351,894391,894391)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01b_rp{
sum `var' if altcode==`=old' & dup>0, meanonly
replace `var'=r(mean)+`var' if altcode==`=new' & dup>0 & r(mean)~=.
}
drop if altcode==`=old' & dup>0
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop dup altcode sct
matrix oldcode=(50303,61022,61254,79305,88034)
matrix newcode=(50216,61483,61483,79013,88413)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist Inscrits-m01b_rp{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
drop Codedpartement Dpartement Codecommune Population Commune ///
Abstentions code
rename (Inscrits Votants Blancsetnuls Exprims) (m01b_reg m01b_votes ///
m01b_inval m01b_val)
save "processed data\cdsp_muni2001t2_comm-m3500", replace
************************************************************************
//load data on second round of 2001 election, 3500-9000 inhabitants
clear
import excel "cdsp_muni2001t2_comm3500-9000.xls", ///
sheet("cdsp_muni2001t2_comm3500-9000") cellrange (A6:V427) firstrow

cap noisily ren Codedepartement Codedpartement
cap noisily ren Codedépartement Codedpartement
cap noisily ren Département Dpartement
cap noisily ren OUIexprimés OUIexprims
cap noisily ren Exprimés Exprims
cap noisily ren NONexprimés NONexprims
cap noisily ren Coded√©partement Codedpartement
cap noisily ren Departement Dpartement
cap noisily ren D√©partement Dpartement
cap noisily ren Exprimes Exprims
cap noisily ren Exprim√©s Exprims
cap noisily ren OUIexprimes OUIexprims
cap noisily ren OUIexprim√©s OUIexprims
cap noisily ren NONexprimes NONexprims
cap noisily ren NONexprim√©s NONexprims
cap noisily ren Numerodecommune Numrodecommune
cap noisily ren Numérodecommune Numrodecommune
cap noisily ren Num√©rodecommune Numrodecommune
cap noisily ren parrapportauxexprimescandi parrapportauxexprimscandi
cap noisily ren parrapportauxexpriméscandi parrapportauxexprimscandi
cap noisily ren parrapportauxexprim√©scandi parrapportauxexprimscandi

//same data structure - same data processing 
drop if Dpartement=="HAUTE CORSE" | Dpartement=="CORSE SUD"
drop if regexm(Codedpartement, "^[A-Z]")
destring Codedpartement, replace
gen code=regexs(0) if (regexm(Codecommune, "^[0-9][0-9][0-9]"))
replace code=Codecommune if code==""
destring code, replace
gen insee_code=Codedpartement*1000+code
drop Codedpartement Dpartement Codecommune Population Commune ///
Abstentions code
quietly forvalues i=1(1)5{
gen m01b_`i'=0
}
gen m01b_misc=0
gen m01b_rp=0
quietly forvalues i=1(1)5{
forvalues j=1(1)4{
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LXG") & `i'==1
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LDG", "LGA", "LEC", "LVE") & `i'==2
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LNC", "NC") & `i'==3
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LDD", "LDR", "NC", "LNC") & `i'==4
replace m01b_`i'=m01b_`i'+Voix`j' if inlist(NuanceListe`j', "LFN", "LMN") & `i'==5
}
}
quietly forvalues i=1(1)2{
forvalues j=1(1)4{
replace m01b_misc=m01b_misc+Voix`j' if NuanceListe`j'=="LDV" & `i'==1
replace m01b_rp=m01b_rp+Voix`j' if NuanceListe`j'=="LRG" & `i'==2
}
}
drop NuanceListe1-Voix4
rename (Inscrits Votants Blancsetnuls Exprims) (m01b_reg m01b_votes ///
m01b_inval m01b_val)
save "processed data\cdsp_muni2001t2_comm3500-9000", replace
*************************************************************************************
//load the base data set
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge m:1 insee_code using "processed data\cdsp_legi2002t1_comm-m3500.dta", nogen

//merge data on first round of '83 election
merge m:1 insee_code using "processed data\cdsp_muni1983t1_commp9000-ag.dta", nogen

//same thing for all other rounds of all other elections
merge m:1 insee_code using "processed data\cdsp_muni1983t2_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni1989t1_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni1989t2_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni1995t1_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni1995t2_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t1_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t2_commp9000-ag.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni2008t1_commp3500.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni2008t2_commp3500.dta", nogen
merge m:1 insee_code using "processed data\02r_churches.dta", nogen
merge m:1 insee_code using "processed data\census_fam_90.dta", nogen
merge m:1 insee_code using "processed data\census_fam_99.dta", nogen
merge m:1 insee_code using "processed data\municipalities_churches_Lorraine.dta", nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t1_comm3500-9000", update nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t1_comm-m3500.dta", update nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t2_comm3500-9000", update nogen
merge m:1 insee_code using "processed data\cdsp_muni2001t2_comm-m3500.dta",update nogen

gen m01a_far_r_share = m01a_5/ (m01a_1 + m01a_2 + m01a_3 + m01a_4 + m01a_5)
gen m01a_far_l_share = m01a_1/ (m01a_1 + m01a_2 + m01a_3 + m01a_4 + m01a_5)
gen m01a_right_share = (m01a_4+m01a_5)/ (m01a_1 + m01a_2 + m01a_3 + m01a_4 + m01a_5)
gen m01a_left_share = (m01a_1+m01a_2)/ (m01a_1 + m01a_2 + m01a_3 + m01a_4 + m01a_5)

/*Paris, Lyon and Marseille need to be assigned the sum/average of all election
data we just merged, since most of those were on individual arrondissements*/

//Paris
quietly foreach var of varlist m95a_reg-m08b_rp{
sum `var' if insee_code>=75000 & insee_code<76000, meanonly
replace `var'=r(sum) if OBJECTID==75056
}
//Lyon
quietly foreach var of varlist m95a_reg-m08b_rp{
sum `var' if insee_code>=69380 & insee_code<69390, meanonly
replace `var'=r(sum) if OBJECTID==69123
}
//Marseille
quietly foreach var of varlist m95a_reg-m08b_rp{
sum `var' if insee_code>=13200 & insee_code<13300, meanonly
replace `var'=r(sum) if OBJECTID==13055
}
/*now, we can compute an index for each municipal election (we could also do
this analogously for the presidential election, by the way) that expresses the
placement of each municipality of a left-to-right spectrum based on the vote
shares of parties there, which are already classified on a 1 to 5 scale (1 being
the left-most parties, and 5 being the far right ones). We simply add up the
points on the scale, weighted by their vote shares. This is not relevant for this paper */
gen m83a_idx=(m83a_1*1+m83a_2*2+m83a_3*3+m83a_4*4+m83a_5*5)/(m83a_1+m83a_2+m83a_3+m83a_4+m83a_5)
gen m83b_idx=(m83b_1*1+m83b_2*2+m83b_3*3+m83b_4*4+m83b_5*5)/(m83b_1+m83b_2+m83b_3+m83b_4+m83b_5)
gen m89a_idx=(m89a_1*1+m89a_2*2+m89a_3*3+m89a_4*4+m89a_5*5)/(m89a_1+m89a_2+m89a_3+m89a_4+m89a_5)
gen m89b_idx=(m89b_1*1+m89b_2*2+m89b_3*3+m89b_4*4+m89b_5*5)/(m89b_1+m89b_2+m89b_3+m89b_4+m89b_5)
gen m95a_idx=(m95a_1*1+m95a_2*2+m95a_3*3+m95a_4*4+m95a_5*5)/(m95a_1+m95a_2+m95a_3+m95a_4+m95a_5)
gen m95b_idx=(m95b_1*1+m95b_2*2+m95b_3*3+m95b_4*4+m95b_5*5)/(m95b_1+m95b_2+m95b_3+m95b_4+m95b_5)
// Check:
gen m01a_idx=(m01a_1*1+m01a_2*2+m01a_3*3+m01a_4*4+m01a_5*5)/(m01a_1+m01a_2+m01a_3+m01a_4+m01a_5)
gen m01b_idx=(m01b_1*1+m01b_2*2+m01b_3*3+m01b_4*4+m01b_5*5)/(m01b_1+m01b_2+m01b_3+m01b_4+m01b_5)
gen m08a_idx=(m08a_1*1+m08a_2*2+m08a_3*3+m08a_4*4+m08a_5*5)/(m08a_1+m08a_2+m08a_3+m08a_4+m08a_5)
gen m08b_idx=(m08b_1*1+m08b_2*2+m08b_3*3+m08b_4*4+m08b_5*5)/(m08b_1+m08b_2+m08b_3+m08b_4+m08b_5)

/*we can do the same for regionalist parties (i.e. simply compute the vote share
of regionalist parties for each round of each election). We only have data on
these beginning in 1995*/
gen m95a_regshare=m95a_rp/(m95a_1+m95a_2+m95a_3+m95a_4+m95a_5+m95a_misc+m95a_rp)
gen m95b_regshare=m95b_rp/(m95b_1+m95b_2+m95b_3+m95b_4+m95b_5+m95b_misc+m95b_rp)
gen m01a_regshare=m01a_rp/(m01a_1+m01a_2+m01a_3+m01a_4+m01a_5+m01a_misc+m01a_rp)
gen m01b_regshare=m01b_rp/(m01b_1+m01b_2+m01b_3+m01b_4+m01b_5+m01b_misc+m01b_rp)
gen m08a_regshare=m08a_rp/(m08a_1+m08a_2+m08a_3+m08a_4+m08a_5+m08a_misc+m08a_rp)
gen m08b_regshare=m08b_rp/(m08b_1+m08b_2+m08b_3+m08b_4+m08b_5+m08b_misc+m08b_rp)

//we can also do the same for the 2007 presidential election
gen p07a_idx=((p07a_c1nvotes+p07a_c2nvotes+p07a_c3nvotes+p07a_c11nvotes)*1+ ///
(p07a_c5nvotes+p07a_c6nvotes+p07a_c8nvotes)*2+(p07a_c4nvotes)*3+(p07a_c12nvotes)*4+ ///
(p07a_c7nvotes+p07a_c9nvotes+p07a_c10nvotes)*5)/p07a_val
gen p07b_idx=(p07b_c2nvotes*2+p07b_c1nvotes*4)/p07b_val

/*we'll generate a variable that simply tells us which faction got the simple
majority in each municipality*/
local rounds = "m83a m83b m89a m89b m95a m95b m01a m01b m08a m08b"

//we need to keep track of which round of elections we're looking at
local k = 1

qui foreach round of local rounds{
	
	/*this variable will give us the number of the faction that won the simple
	majority; 1-5 are like on the index, whereas 6 stands for regionalist
	parties*/
	gen `round'_simplemaj = .
	
	//this is just for labelling that variable, depending on the round
	if substr("`round'", 4, 1)=="a" & `=substr("`round'", 2, 2)'>80{
		label var `round'_simplemaj "Faction that got the simple majority in 19`=substr("`round'", 2, 2)', first round of election"
	}
	
	else if substr("`round'", 4, 1)=="b" & `=substr("`round'", 2, 2)'>80{
		label var `round'_simplemaj "Faction that got the simple majority in 19`=substr("`round'", 2, 2)', second round of election"
	}
	
	else if substr("`round'", 4, 1)=="a" & `=substr("`round'", 2, 2)'<80{
		label var `round'_simplemaj "Faction that got the simple majority in 20`=substr("`round'", 2, 2)', first round of election"
	}
	
	else if substr("`round'", 4, 1)=="b" & `=substr("`round'", 2, 2)'<80{
		label var `round'_simplemaj "Faction that got the simple majority in 20`=substr("`round'", 2, 2)', second round of election"
	}
	
	/*the first four elections don't have data on regionalist parties, hence
	we need to treat them differently than the later ones*/
	if `k' < 5{
		
		/*this is the only difference; this will only add the five numbered
		factions variables*/
		local factions = "`round'_?"
		
		//this is just a temporary utility variable
		egen temp = rowmax(`factions')
		
		//we need to keep track of the number of the faction we're looking at
		local i = 1
		
		foreach f of varlist `factions'{
			
			/*if it got more votes than the current maximum, replace the
			maximum variable with the faction number*/
			replace `round'_simplemaj = `i' if `f'==temp & `f'~=.
			
			//keep track of the faction!
			local ++i
		}
		
		//drop the temporary variable
		drop temp
		
		//drop the faction counter
		macro drop i
	}
	else{
		
		//this will also add regionalist parties
		local factions = "`round'_? `round'_rp"
		
		egen temp = rowmax(`factions')
		
		local i = 1
		
		foreach f of varlist `factions'{
		
			replace `round'_simplemaj = `i' if `f'==temp & `f'~=.
			
			local ++i
		}
		
		drop temp
		
		macro drop factions i
	}
	
	//keep track of the election round
	local ++k
}

//drop the election round counter
macro drop k

//label variables
label var m83a_1 "Votes for far left parties in 1983, first round of election"
label var m83a_2 "Votes for left parties in 1983, first round of election"
label var m83a_3 "Votes for center parties in 1983, first round of election"
label var m83a_4 "Votes for right parties in 1983, first round of election"
label var m83a_5 "Votes for far right parties in 1983, first round of election"
label var m83b_1 "Votes for far left parties in 1983, second round of election"
label var m83b_2 "Votes for left parties in 1983, second round of election"
label var m83b_3 "Votes for center parties in 1983, second round of election"
label var m83b_4 "Votes for right parties in 1983, second round of election"
label var m83b_5 "Votes for far right parties in 1983, second round of election"
label var m89a_1 "Votes for far left parties in 1989, first round of election"
label var m89a_2 "Votes for left parties in 1989, first round of election"
label var m89a_3 "Votes for center parties in 1989, first round of election"
label var m89a_4 "Votes for right parties in 1989, first round of election"
label var m89a_5 "Votes for far right parties in 1989, first round of election"
label var m89b_1 "Votes for far left parties in 1989, second round of election"
label var m89b_2 "Votes for left parties in 1989, second round of election"
label var m89b_3 "Votes for center parties in 1989, second round of election"
label var m89b_4 "Votes for right parties in 1989, second round of election"
label var m89b_5 "Votes for far right parties in 1989, second round of election"
label var m95a_1 "Votes for far left parties in 1995, first round of election"
label var m95a_2 "Votes for left parties in 1995, first round of election"
label var m95a_3 "Votes for center parties in 1995, first round of election"
label var m95a_4 "Votes for right parties in 1995, first round of election"
label var m95a_5 "Votes for far right parties in 1995, first round of election"
label var m95b_1 "Votes for far left parties in 1995, second round of election"
label var m95b_2 "Votes for left parties in 1995, second round of election"
label var m95b_3 "Votes for center parties in 1995, second round of election"
label var m95b_4 "Votes for right parties in 1995, second round of election"
label var m95b_5 "Votes for far right parties in 1995, second round of election"
label var m01a_1 "Votes for far left parties in 2001, first round of election"
label var m01a_2 "Votes for left parties in 2001, first round of election"
label var m01a_3 "Votes for center parties in 2001, first round of election"
label var m01a_4 "Votes for right parties in 2001, first round of election"
label var m01a_5 "Votes for far right parties in 2001, first round of election"
label var m01a_far_r_share "Vote share for far right parties in 2001, first round of election"
label var m01a_far_l_share "Vote share for far left parties in 2001, first round of election"
label var m01a_right_share "Vote share for right parties in 2001, first round of election"
label var m01a_left_share "Vote share for left parties in 2001, first round of election"
label var m01b_1 "Votes for far left parties in 2001, second round of election"
label var m01b_2 "Votes for left parties in 2001, second round of election"
label var m01b_3 "Votes for center parties in 2001, second round of election"
label var m01b_4 "Votes for right parties in 2001, second round of election"
label var m01b_5 "Votes for far right parties in 2001, second round of election"
label var m08a_1 "Votes for far left parties in 2008, first round of election"
label var m08a_2 "Votes for left parties in 2008, first round of election"
label var m08a_3 "Votes for center parties in 2008, first round of election"
label var m08a_4 "Votes for right parties in 2008, first round of election"
label var m08a_5 "Votes for far right parties in 2008, first round of election"
label var m08a_misc "Votes for miscellaneous parties in 2008, first round of election"
label var m08a_rp "Votes for regionalist parties in 2008, first round of election"
label var m08b_1 "Votes for far left parties in 2008, second round of election"
label var m08b_2 "Votes for left parties in 2008, second round of election"
label var m08b_3 "Votes for center parties in 2008, second round of election"
label var m08b_4 "Votes for right parties in 2008, second round of election"
label var m08b_5 "Votes for far right parties in 2008, second round of election"
label var m08b_misc "Votes for miscellaneous parties in 2008, second round of election"
label var m08b_rp "Votes for regionalist parties in 2008, second round of election"
label var m83a_idx "Political spectrum index in 1983, first round of election"
label var m83b_idx "Political spectrum index in 1983, second round of election"
label var m89a_idx "Political spectrum index in 1989, first round of election"
label var m89b_idx "Political spectrum index in 1989, second round of election"
label var m95a_idx "Political spectrum index in 1995, first round of election"
label var m95b_idx "Political spectrum index in 1995, second round of election"
label var m01a_idx "Political spectrum index in 2001, first round of election"
label var m01b_idx "Political spectrum index in 2001, second round of election"
label var m08a_idx "Political spectrum index in 2008, first round of election"
label var m08b_idx "Political spectrum index in 2008, second round of election"
label var m95a_regshare "Vote share of regionalist parties in 1995, first round of election"
label var m95b_regshare "Vote share of regionalist parties in 1995, second round of election"
label var m01a_regshare "Vote share of regionalist parties in 2001, first round of election"
label var m01b_regshare "Vote share of regionalist parties in 2001, second round of election"
label var m08a_regshare "Vote share of regionalist parties in 2008, first round of election"
label var m08b_regshare "Vote share of regionalist parties in 2008, second round of election"
label var p07a_idx "Political spectrum index for 2007 presidential election, first round"
label var p07b_idx "Political spectrum index for 2007 presidential election, second round"
label var r92_nf "Percentage of 'NO'-votes in 1992 referendum"
label var r05_nf "Percentage of 'NO'-votes in 2005 referendum"

//record the variable list for data subsetting
qui ds `varlist_all', not
local varlist_elections = r(varlist)
local varlist_all = "`varlist_all' `varlist_elections'"
//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace
********************************************************************************
//2.2: L'express data on French crime by commune
//data obtained through personal communication with Pierre Falga at L'express (01/09/15)
//contain data on thefts, car theft, physical violence
//key: implicitly contain INSEE codes (see below)
//clear & load data
clear
import excel "Securite Alsace-Lorraine 25 fev 2015.xlsx", ///
sheet("Securite Base communes") cellrange (A1:W3244) firstrow
cap noisily ren Codedep Codedp
cap noisily ren Codedép Codedp
cap noisily ren  CSPCirconscriptionsdesc CSPCirconscriptionsdescu
cap noisily ren  CSPCirconscriptionsdes√©c CSPCirconscriptionsdescu
cap noisily ren  CSPCirconscriptionsdeséc CSPCirconscriptionsdescu
cap noisily ren CGDCompagniesdegendarmer  CGDCompagniesdegendarmeri
cap noisily ren Lesviolencesphysiquescrapuleu Lesviolencesphysiquescrapuleus
cap noisily ren  Coded√©p Codedp
//generate INSEE codes
destring Codedp Codecommune, replace
gen insee_code=Codedp*1000+Codecommune

//drop redundant or unnecessary variables
drop A-Populationmunicipale2010
//rename variables, so we know which crime they refer to
rename (Communeenzonepolice0genda CSPCirconscriptionsdescu ///
CGDCompagniesdegendarmeri Lesviolencesauxpersonnes Rangsur408 Rangsur379 ///
Lesatteintesauxbiens M N Lesviolencesphysiquescrapuleus P Q ///
Lescambriolages S T Lesvolsdautomobiles V W) (police_zone CSP CGD ///
cr_violence_persons cr_rank_CSP_violence_persons cr_rank_CGD_violence_persons ///
cr_property_damage cr_rank_CSP_property_damage cr_rank_CGD_property_damage ///
cr_phys_violence cr_rank_CSP_phys_violence cr_rank_CGD_phys_violence ///
cr_burglary cr_rank_CSP_burglary cr_rank_CGD_burglary cr_gta cr_rank_CSP_gta ///
cr_rank_CGD_gta)
//save processed data
save "processed data\Security Alsace-Lorraine 25 fev 2015.dta", replace
********************************************************************************
//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1
//merge crime data
merge m:1 insee_code using "processed data\Security Alsace-Lorraine 25 fev 2015.dta", nogen
//variable list for subsetting
qui ds `varlist_all', not
local varlist_crime = r(varlist)
local varlist_all = "`varlist_all' `varlist_crime'"
//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace
********************************************************************************
************* PART 3: Independent variables
********************************************************************************

//3.1: INSEE data on French municipalities
//overview over communal-level data: http://www.insee.fr/fr/bases-de-donnees/default.asp?page=statistiques-locales/donnees-detaillees_tableau.htm (01/06/15)
//cover a wide range of municipality characteristics
//key: CODGEO gives INSEE municipality ID codes
//import first data set to be merged, in this case INSEE data on commerce
import excel "equip-serv-action-sociale-com-13.xls", ///
sheet("COM") cellrange(A6:Y36687) firstrow clear
//rename CODGEO to insee_code for conformity across data sets
rename CODGEO insee_code
/*drop Corsica, like in the base data (also, Corsica has non-numeric department
codes, which would cause problems later on)*/
drop if REG=="94"
//drop overseas territories, like in the base data
drop if insee_code>="97100" & insee_code~=""
//destring insee_code (data compatibility)
destring insee_code, replace
//drop redundant variables
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
//save the data to Stata format (makes for much easier merges) & clear
save "processed data\equip-serv-action-sociale-com-13.dta", replace
clear
****************************************************************************
//same thing for other INSEE data sets
import excel "equip-serv-commerce-com.xls", ///
sheet("COM") cellrange(A6:AE36687) firstrow clear
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU12010
save "processed data\equip-serv-commerce-com.dta", replace
clear
*************************************************************************
import excel "equip-serv-ens-1er-degre-com.xls", ///
sheet("COM") cellrange(A6:X36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-ens-1er-degre-com.dta", replace
clear
***************************************************************************
import excel "equip-serv-ens-2eme-degre-com-2013.xls", ///
sheet("COM") cellrange(A6:AA36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-ens-2eme-degre-com-2013.dta", replace
clear
***************************************************************************
import excel "equip-serv-ens-sup-form-serv-com-13.xls", ///
sheet("COM") cellrange(A6:Z36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-ens-sup-form-serv-com-13.dta", replace
clear
**********************************************************************
import excel "equip-serv-medical-para-com.xls", ///
sheet("COM") cellrange(A6:AE36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-medical-para-com.dta", replace
clear
*****************************************************************
import excel "equip-serv-particuliers-com-13.xls", ///
sheet("COM") cellrange(A6:AU36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-particuliers-com-13.dta", replace
clear
*****************************************************************
import excel "equip-serv-sante-com-13.xls", ///
sheet("COM") cellrange(A6:AA36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-serv-sante-com-13.dta", replace
clear

*****************************************************************
import excel "equip-sport-loisir-socio-com-13.xls", ///
sheet("COM") cellrange(A6:CK36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-sport-loisir-socio-com-13.dta", replace
clear

**************************
import excel "equip-tour-transp-com-13.xls", ///
sheet("COM") cellrange(A6:Q36687) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 UU2010
save "processed data\equip-tour-transp-com-13.dta", replace
clear
***********Education data, Source Insee 2015, as of 1.1.2012, geography of municipalities as of 1.1.1999, Source RP2010 exploitation principale
import excel "base-cc-diplomes-formation-2010.xls", ///
sheet("COM") cellrange(A6:CR36711) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 
*Labels
label var P10_POP1114 "Pop 11-14 ans en 2010 "
label var P10_POP1517 "Pop 15-17 ans en 2010 "
label var P10_POP1824 "Pop 18-24 ans en 2010 "
label var P10_POP2529 "Pop 25-29 ans en 2010 "
label var P10_POP30P "Pop 30 ans ou plus en 2010 "
*2010
label var P10_SCOL1114 "No. People currrently in education 11-14 ans years 2010"
label var P10_SCOL1517 "No. People currrently in education 15-17 years 2010"
label var P10_SCOL1824 "No. People currrently in education 18-24 years 2010"
label var P10_SCOL2529 "No. People currrently in  education 25-29 years 2010 "
label var P10_SCOL30P "No. People currrently in  education 30 or more 2010 "
label var P10_NSCOL15P "Pop 15 years or older not in school (1999) (2010)"
label var P10_NSCOL15P_DIPL0 "Pop 15 years or older not in school anymore who finished 10th grade succ. (2010)"
label var P10_NSCOL15P_BAC "Population 15 years and older not in school anymore with highschool degree BAC (2010)"
*1999
*Population
label var P99_POP1114 "Pop 11-14 ans en 1999 "
label var P99_POP1517 "Pop 15-17 ans en 1999 "
label var P99_POP1824 "Pop 18-24 ans en 1999 "
label var P99_POP2529 "Pop 25-29 ans en 1999 "
label var P99_POP30P "Pop 30 ans ou plus en 1999 "

label var P99_SCOL1114 "No. People currrently in education 11-14 ans en 1999 "
label var P99_SCOL1517 "No. People currrently in education 15-17 ans en 1999"
label var P99_SCOL1824 "No. People currrently in education18-24 ans 1999 "
label var P99_SCOL2529 "No. People currrently in education 25-29 ans 1999"
label var P99_SCOL30P "No. People currrently in education 30 ans ou plus 1999"
*Certificates in whole popuation

label var P99_NSCOL15P "Pop 15 years or older not in school (1999)"
label var P99_NSCOL15P_DIPL0 "Pop 15 years or older  not in school anymore who finished 10th grade succ.(1999)"
label var P99_NSCOL15P_BAC "Population 15 years and older not in school anymore with highschool degree BAC (1999)"
*Population
keep P10_POP1114 P10_POP1517 P10_POP1824 P10_POP2529 P10_POP30P ///
P10_SCOL1114 P10_SCOL1517 P10_POP1824 P10_POP2529 P10_POP30P ///
P10_NSCOL15P P10_NSCOL15P_DIPL0    P10_NSCOL15P_BAC P10_SCOL2529 P10_SCOL30P ///
P10_NSCOL15P P10_NSCOL15P_DIPL0     P10_NSCOL15P_BAC ///
P99_POP1114 P99_POP1517 P99_POP1824 P99_POP2529 P99_POP30P ///
P99_SCOL1824 P99_SCOL2529 P99_SCOL30P P99_SCOL1517 P10_SCOL1824   ///
P99_SCOL1114 P99_SCOL30P ///
P99_NSCOL15P P99_NSCOL15P_DIPL0 P99_NSCOL15P_BAC ///
 insee_code ID_MODIF_GEO 
save "processed data\education-2012.dta", replace
clear
********************************************************************************
//load the base data set
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1
//merge first data set
merge m:1 insee_code using "processed data\equip-serv-action-sociale-com-13", nogen
//do the same for the other INSEE data sets
merge m:1 insee_code using "processed data\equip-serv-commerce-com", nogen
merge m:1 insee_code using "processed data\equip-serv-ens-1er-degre-com", nogen
merge m:1 insee_code using "processed data\equip-serv-ens-2eme-degre-com-2013", nogen
merge m:1 insee_code using "processed data\equip-serv-ens-sup-form-serv-com-13", nogen
merge m:1 insee_code using "processed data\equip-serv-medical-para-com", nogen
merge m:1 insee_code using "processed data\equip-serv-particuliers-com-13", nogen
merge m:1 insee_code using "processed data\equip-serv-sante-com-13", nogen
merge m:1 insee_code using "processed data\equip-sport-loisir-socio-com-13", nogen
merge m:1 insee_code using "processed data\equip-tour-transp-com-13", nogen
merge m:1 insee_code using "processed data\education-2012.dta", nogen
//label the added variables
label var NB_D401 "elderly people : accomodation"
label var NB_D402 "elderly people : home care"
label var NB_D403 "elderly people : assistance service"
label var NB_D404 "elderly people : foyer restaurant"
label var NB_D405 "elderly people : home food delivery service"
label var NB_D501 "pre-school age child care worker"
label var NB_D601 "disabled children : accomodation"
label var NB_D602 "disabled children : home or ambulatory services"
label var NB_D603 "disabled adults : accomodation"
label var NB_D604 "disabled adults : services"
label var NB_D605 "sheltered job"
label var NB_D701 "children's social security: accomodation"
label var NB_D702 "children's social security:  educative action"
label var NB_D703 "CHRS : centre for accomodation and social rehabilitation "
label var NB_D704 "provisional accomodation center"
label var NB_D705 "reception center for asylum seekers"
label var NB_D709 "other establishments for adults and families in distress"
label var NB_B101 "Hypermarche"
label var NB_B102 "Supermarche"
label var NB_B103 "Grande surface de bricolage"
label var NB_B201 "Superette"
label var NB_B202 "Epicerie"
label var NB_B203 "Boulangerie"
label var NB_B204 "Boucherie charcuterie"
label var NB_B205 "Produits surgeles"
label var NB_B206 "Poissonnerie"
label var NB_B301 "Librairie papeterie journaux"
label var NB_B302 "Magasin de v√™tements"
label var NB_B303 "Magasin d'equips du foyer"
label var NB_B304 "Magasin de chaussures"
label var NB_B305 "Magasin d'electromenager et de materiel audio-video"
label var NB_B306 "Magasin de meubles"
label var NB_B307 "Magasin d'articles de sports et de loisirs"
label var NB_B308 "Magasin de rev√™tements murs et sols"
label var NB_B309 "Droguerie quincaillerie bricolage"
label var NB_B310 "Parfumerie"
label var NB_B311 "Horlogerie Bijouterie"
label var NB_B312 "Fleuriste"
label var NB_B313 "Magasin d'optique"
label var NB_B314 "Station service"
label var NB_C101 "nursery school "
label var NB_C101_NB_CANT "nursery school with canteen"
label var NB_C101_NB_RPIC "nursery school in RPIC"
label var NB_C101_NB_EP "nursery school belonging to a network of priority education(REP)"
label var NB_C102 "nursery classe with scatterd RPI"
label var NB_C102_NB_CANT "nursery class with scattered RPI with canteen"
label var NB_C102_NB_EP "nursery school with scattered RPI belonging to a network of priority education"
label var NB_C104 "elementary school"
label var NB_C104_NB_CANT "elementary school with canteen"
label var NB_C104_NB_CL_PELEM "elementary schoool with pre-elementary class"
label var NB_C104_NB_RPIC "elementary school in RPIC"
label var NB_C104_NB_EP "elementary school beloning to a network with priority education"
label var NB_C105 "elementary class with scattered RPI"
label var NB_C105_NB_CANT "elementary class with RPI and canteen"
label var NB_C105_NB_CL_PELEM "elementary class with scattered RPI and pre-elementary class"
label var NB_C105_NB_EP "elementary class with scattered RPI belonging to a network of priority education"
label var NB_C201 "secondary school"
label var NB_C201_NB_CANT "secondary school with canteen"
label var NB_C201_NB_INT "secondary school with boarding school"
label var NB_C201_NB_EP "secondary school beloning to a network of priority education"
label var NB_C301 "high-school with general and/or technological education"
label var NB_C301_NB_CANT "high-school with general and/or technological education with canteen"
label var NB_301_NB_CL_PGE "high-school with general and/or technological education and preparatory class for elite universities"
label var NB_C301_NB_INT "high-school with general and/or technological education with boarding school"
label var NB_C301_NB_EP "high-school with general and/or technological education belonging to a network of priority education"
label var NB_C302 "secondary school for vocational training"
label var NB_C302_NB_CANT "secondary school for vocational training with canteen"
label var NB_C302_NB_INT "secondary school for vocational training with boarding school"
label var NB_C302_NB_EP "secondary school for vocational training belonging to a network of priority education"
label var NB_C303 "secondary school for technical and/or agricultural vocational training"
label var NB_C303_NB_INT "secondary school for technical and/or agricultural vocational training with boarding school"
label var NB_C304 "SGT : department of general and technological education"
label var NB_C304_NB_CANT "SGT with canteen"
label var NB_C305 "SEP : department of professional training"
label var NB_C305_NB_CANT "SEP with canteen"
label var NB_C401 "senior technician department, preparatory class for elite universities"
label var NB_C402 "health education"
label var NB_C403 "commercial education"
label var NB_C409 "other post-high-school non-academic education"
label var NB_C501 "Education and Reserach unit"
label var NB_C502 "university insitute"
label var NB_C503 "engineering school"
label var NB_C504 "general private higher education"
label var NB_C509 "other higher education"
label var NB_C601 "vocational training center"
label var NB_C602 "GRETA"
label var NB_C603 "CFPPA"
label var NB_C604 "education for sports professions"
label var NB_C605 "agricultural vocational training center"
label var NB_C605_NB_INT "agricultural vocational training center with boarding school"
label var NB_C609 "other continued education"
label var NB_C701 "student residence"
label var NB_C702 "university canteen"
label var NB_D201 "Medecin omnipraticien"
label var NB_D202 "Specialiste en cardiologie"
label var NB_D203 "Specialiste en dermatologie venereologie"
label var NB_D204 "Specialiste en gynecologie medicale"
label var NB_D205 "Specialiste en gynecologie obstetrique"
label var NB_D206 "Specialiste en gastro-enterologie hepatologie"
label var NB_D207 "Specialiste en psychiatrie"
label var NB_D208 "Specialiste en ophtalmologie"
label var NB_D209 "Specialiste en oto-rhino-laryngologie"
label var NB_D210 "Specialiste en pediatrie"
label var NB_D211 "Specialiste en pneumologie"
label var NB_D212 "Specialiste en radiodiagnostic et imagerie medicale"
label var NB_D213 "Specialiste en stomatologie"
label var NB_D221 "Chirurgien dentiste"
label var NB_D231 "Sage-femme"
label var NB_D232 "Infirmier"
label var NB_D233 "Masseur kinesitherapeute"
label var NB_D235 "Orthophoniste"
label var NB_D236 "Orthoptiste"
label var NB_D237 "Pedicure-podologue"
label var NB_D238 "Audio prothesiste"
label var NB_D239 "Ergotherapeute"
label var NB_D240 "Psychomotricien"
label var NB_A101 "Police"
label var NB_A104 "gendarmerie/constabulary"
label var NB_A105 "appeal court"
label var NB_A106 "District court"
label var NB_A107 "court of first instance"
label var NB_A108 "labour court"
label var NB_A109 "commercial court"
label var NB_A110 " proximity agency"
label var NB_A111 "agent employment center"
label var NB_A112 "permanent employment center"
label var NB_A115 "specialised agency"
label var NB_A116 "public service house and agency"

label var NB_A117 "Point d'information et de mediation multiservices"
label var NB_A118 "Espace public numerique et autres"
label var NB_A119 "DGFiP"
label var NB_A120 "DRFiP"
label var NB_A121 "DDFiP"
label var NB_A203 "Banque, Caisse d'Epargne"
label var NB_A205 "morticians"
label var NB_A206 "post office"
label var NB_A207 "postal agency run by shopkeepers"
label var NB_A208 "communal postal agency"
label var NB_A301 "Reparation auto et de materiel agricole"
label var NB_A302 "Contr√¥le technique automobile"
label var NB_A303 "Location auto-utilitaires legers"
label var NB_A304 "Ecole de conduite"
label var NB_A401 "Ma√ßon"
label var NB_A402 "Platrier peintre"
label var NB_A403 "Menuisier, charpentier, serrurier"
label var NB_A404 "Plombier, couvreur, chauffagiste"
label var NB_A405 "Electricien"
label var NB_A406 "Entreprise generale du batiment"
label var NB_A501 "Coiffure"
label var NB_A502 "Veterinaire"
label var NB_A503 "Agence de travail temporaire"
label var NB_A504 "Restaurant"
label var NB_A505 "Agence immobili√®re"
label var NB_A506 "Blanchisserie-Teinturerie"
label var NB_A507 "Soins de beaute"
label var NB_D101 "Health care establishments for short stays"
label var NB_D102 "Health care establishments for medium-term stays"
label var NB_D103 "Health care establishments for long stays"
label var NB_D104 "psychiatric establishments"
label var NB_D105 "centers for fighting cancer "
label var NB_D106 "Emergencies"
label var NB_D107 "maternity hospital"
label var NB_D108 "health care centre"
label var NB_D109 "psychiatric and ambulatory structures"
label var NB_D110 "centre for preventive medicine"
label var NB_D111 "Dialyse"
label var NB_D112 "Hospitalisation at home"
label var NB_D113 "multidisciplinary nursing home"
label var NB_D301 "Pharmacy"
label var NB_D302 "Laboratoire d'analyses medicales"
label var NB_D303 "Ambulance"
label var NB_D304 "Transfusion sanguine"
label var NB_D305 "Etablissement thermal"
label var NB_D306 "Etablissement lutte contre l'alcoolisme"
label var NB_F101 "Bassin de natation"
label var NB_F101_NB_AIREJEU "Bassin de natation- no bassins de natation, sportive, ludique"
label var NB_F101_NB_COU "Bassin de natation au mo un bassin couvert"
label var NB_F101_NB_ECL "Bassin de natation au mo un bassin eclaire"
label var NB_F102 "Boulodrome"
label var NB_F102_NB_AIREJEU "Boulodrome - no de terrains"
label var NB_F102_NB_COU "Boulodrome au mo un terrain couvert"
label var NB_F102_NB_ECL "Boulodrome au mo un terrain eclaire"
label var NB_F103 "Tennis"
label var NB_F103_NB_AIREJEU "Tennis - no de courts"
label var NB_F103_NB_COU "Tennis au mo un court couvert"
label var NB_F103_NB_ECL "Tennis au mo un court eclaire"
label var NB_F104 "√âquipement de cyclisme"
label var NB_F104_NB_AIREJEU "√âquipement de cyclisme - no de pistes"
label var NB_F104_NB_COU "√âquipement de cyclisme au mo une piste couverte"
label var NB_F104_NB_ECL "√âquipement de cyclisme au mo une piste eclairee"
label var NB_F105 "Domaine skiable"
label var NB_F105_NB_AIREJEU "Domaine skiable - no de pistes"
label var NB_F105_NB_COU "Domaine skiable au mo une piste couverte"
label var NB_F105_NB_ECL "Domaine skiable au mo une piste eclairee"
label var NB_F106 "Centre equestre"
label var NB_F106_NB_AIREJEU "Centre equestre - no de carri√®res, man√®ges"
label var NB_F106_NB_COU "Centre equestre au mo un equip couvert"
label var NB_F106_NB_ECL "Centre equestre au mo un equip eclaire"
label var NB_F107 "Athletisme"
label var NB_F107_NB_AIREJEU "Athletisme - no d'aires de pratique"
label var NB_F107_NB_COU "Athletisme au mo une aire de pratique couverte"
label var NB_F107_NB_ECL "Athletisme au mo une aire de pratique eclairee"
label var NB_F108 "Terrain de golf"
label var NB_F108_NB_AIREJEU "Terrain de golf - no d'aires de pratique"
label var NB_F108_NB_COU "Terrain de golf au mo une aire de pratique couverte"
label var NB_F108_NB_ECL "Terrain de golf au mo une aire de pratique eclairee"
label var NB_F109 "Parcours sportif"
label var NB_F109_NB_AIREJEU "Parcours sportif - no de parcours"
label var NB_F109_NB_COU "Parcours sportif au mo un parcours couvert"
label var NB_F109_NB_ECL "Parcours sportif au mo un parcours eclaire"
label var NB_F110 "Sports de glace"
label var NB_F110_NB_AIREJEU "Sports de glace - no d'aires de pratique"
label var NB_F110_NB_COU "Sports de glace au mo une aire de pratique couverte"
label var NB_F110_NB_ECL "Sports de glace au mo une aire de pratique eclairee"
label var NB_F111 "Plateau exterieur ou salle multisports"
label var NB_F111_NB_AIREJEU "Plateau exterieur ou salle multisports - no d'aires de pratique"
label var NB_F111_NB_COU "Plateau exterieur ou salle multisports av au mo une aire de pratique couverte"
label var NB_F111_NB_ECL "Plateau exterieur ou salle multisports av mo une aire de pratique eclairee"
label var NB_F112 "Salle,terrain de petits jeux"
label var NB_F112_NB_AIREJEU "Salle,terrain de petits jeux - no d'aires de pratique"
label var NB_F112_NB_COU "Salle,terrain de petits jeux av mo une aire de pratique couverte"
label var NB_F112_NB_ECL "Salle,terrain de petits jeux av mo une aire de pratique eclairee"
label var NB_F113 "Terrain de grands jeux"
label var NB_F113_NB_AIREJEU "Terrain de grands jeux - no de terrains"
label var NB_F113_NB_COU "Terrain de grands jeux avec av mo un terrain couvert"
label var NB_F113_NB_ECL "Terrain de grands jeux avec av mo un terrain eclaire"
label var NB_F114 "Salle de combat"
label var NB_F114_NB_AIREJEU "Salle de combat - no d'aires de pratique"
label var NB_F114_NB_COU "Salle de combat au mo une aire de pratique couverte"
label var NB_F114_NB_ECL "Salle de combat au mo une aire de pratique eclairee"
label var NB_F115 "Salle,terrain specialise"
label var NB_F115_NB_AIREJEU "Salle,terrain specialise - no d'aires de pratique"
label var NB_F115_NB_COU "Salle,terrain specialise au mo une aire de pratique couverte"
label var NB_F115_NB_ECL "Salle,terrain specialise au mo une aire de pratique eclairee"
label var NB_F116 "Salle non specialisee"
label var NB_F116_NB_AIREJEU "Salle non spece-no d'equip s'exerce au mo 1 activite physique,sportive"
label var NB_F116_NB_COU "Salle non specialisee au mo un equip couvert"
label var NB_F116_NB_ECL "Salle non specialisee au mo un equip eclaire"
label var NB_F117 "Roller-Skate-Velo bicross ou freestyle"
label var NB_F117_NB_AIREJEU "Roller-Skate-Velo bicross ou freestyle - no de pistes"
label var NB_F117_NB_COU "Roller-Skate-Velo bicross,freestyle au mo un equip couvert"
label var NB_F117_NB_ECL "Roller-Skate-Velo bicross,freestyle au mo un equip eclaire"
label var NB_F118 "Sports nautiques"
label var NB_F118_NB_AIREJEU "Sports nautiques - no d'aires de pratique"
label var NB_F118_NB_COU "Sports nautiques au mo une aire de pratique couverte"
label var NB_F118_NB_ECL "Sports nautiques au mo une aire de pratique eclairee"
label var NB_F201 "Baignade amenagee"
label var NB_F201_NB_AIREJEU "Baignade amenagee - no d'aires de pratique"
label var NB_F202 "Port de plaisance - Mouillage"
label var NB_F202_NB_AIREJEU "Port de plaisance - Mouillage - no de ports, de zones"
label var NB_F203 "Boucle de randonnee"
label var NB_F203_NB_AIREJEU "Boucle de randonnee - no de circuits"
label var NB_F301 "Cinema"
label var NB_F302 "theatres"
label var NB_F302_NB_SALLES "number of theatre rooms"
label var NB_E101 "Taxi"
label var NB_E102 "Aeroport"
label var NB_E103 "Gare avec train TAGV (train √† grande vitesse)"
label var NB_E104 "Gare sous convention avec l‚Äô√âtat"
label var NB_E105 "Gare sous convention avec les conseils regionaux ou STIF"
label var NB_G101 "Agence de voyage"
label var NB_G102 "H√¥tel homologue"
label var NB_G103 "Camping homologue"
label var NB_G104 "Information Touristique"
//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace
********************************************************************************
//3.2: INSEE data on business creation, communal level
//all data accessed at INSEE website: http://www.insee.fr/fr/default.asp (02/10/15)
//overview over communal-level data: http://www.insee.fr/fr/bases-de-donnees/default.asp?page=statistiques-locales/donnees-detaillees_tableau.htm (02/10/15)
//give data on business creation by sector
//key: CODGEO gives INSEE municipality ID codes

//data processing is very similar to the other INSEE data (3.1)
clear
import excel "base-cc-demo-entreprises-11.xlsx", ///
sheet("DENTR_COM") cellrange(A6:BO36686) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 EPCI
/*we need to take care of two municipalities that have since been merged with
others*/
matrix oldcode=(28042,76095)
matrix newcode=(28361,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist ENCTOT11-ETNOQ11{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

save "processed data\base-cc-demo-entreprises-11.dta", replace
clear
********************************************************************
import excel "base-cc-demo-entreprises-12.xlsx", ///
sheet("DEN_COM") cellrange(A6:AN36689) firstrow
rename CODGEO insee_code
//dropping Corsica is slightly more involved here
drop if regexm(insee_code, "^[0-9][A-Z]")
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO
save "processed data\base-cc-demo-entreprises-12.dta", replace
clear
*****************************************************************
import excel "base-cc-demo-entreprises-13.xlsx", ///
sheet("COM") cellrange(A7:AQ36735) firstrow
rename CODGEO insee_code
drop if regexm(insee_code, "^[0-9][A-Z]")
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO
save "processed data\base-cc-demo-entreprises-13.dta", replace
clear
********************************************************************************
//load the base data set
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1
//merge first data set
merge m:1 insee_code using "processed data\base-cc-demo-entreprises-11.dta", nogen
//do the same for the other INSEE data sets
merge m:1 insee_code using "processed data\base-cc-demo-entreprises-12.dta", nogen
merge m:1 insee_code using "processed data\base-cc-demo-entreprises-13.dta", nogen

* /label the added variables
label var ENCTOT11 "creation of companies 2011" 
label var ENCBE11 "new industrial companies 2011"
label var ENCCFZ11 "creation of building companies in 2011"
label var ENCGU11 "creation of commercial, transport and miscellaneous services companies 2011"
label var ENCGZ11 "of which creations of commercial companies 2011"
label var ENCOQ11 "creation of public administration, education, health and social welfare companies 2011"
label var ENCTOT10 "creation of companies 2010"
label var ENCTOT09 "creation of companies  2009"
label var ENCTOT08 "creation of companies  2008"
label var ENCTOT07 "creation of companies  2007"
label var ENCTOT06 "creation of companies  in 2006"
label var ENCITOT11 "creation of single-member companies in 2011"
label var ENCIBE11 "creation of industrial single-member companies in 2011"
label var ENCICFZ11 "creation of single-member building companies in 2011"
label var ENCIGU11 "creation of single-member commercial, transport and miscellaneous services companies"
label var ENCIGZ11 "of which creations of single-member commercial companies in 2011"
label var ENCIOQ11 "creation of individual public administration, education, health and social welfare companies in 2011"
label var ENCITOT10 "creation of single-member companies in 2010"
label var ENCITOT09 "creation of single-member companies in 2009"
label var ENCITOT08 "creation of single-member companies in 2008"
label var ENCITOT07 "creation of single-member companies in 2007"
label var ENCITOT06 "creation of single-member companies in 2006"
label var ENCATOT11 "creation of self proprietorships in 2011"
label var ENCABE11 "creation of industrial sole proprietorships in 2011"
label var ENCACFZ11 "creation of building sole proprietorships in 2011"
label var ENCAGU11 "creation of  commercial, transport and miscellaneous services sole proprietorships in 2011"
label var ENCAGZ11 "of which creations of commercial sole proprietorships in 2011"
label var ENCAOQ11 "creation of public administration, education, health and social welfare sole proprietorships in 2011"
label var ENNTOT11 "companies in 2011"
label var ENNBE11 "industrial companies in 2011"
label var ENNCFZ11 "buliding companies in 2011"
label var ENNGU11 "commercial, transport and miscellaneous services companies in 2011"
label var ENNGZ11 "of which commercial companies in 2011"
label var ENNOQ11 "public administration, education, health and social welfare companies in 2011" 
label var ENN0AN11 "companies existing for less than a year in 2011"
label var ENN1AN11 "companies existing for 1 year in 2011"
label var ENN2AN11 "companies existing for 2 years in 2011"
label var ENN3AN11 "companies existing for 3 years in 2011"
label var ENN4AN11 "companies existing for 4 years in 2011"
label var ENN5AN11 "companies existing for 5 years in 2011"
label var ENN6AN11 "companies existing for 6 to 9 years in 2011"
label var ENN7AN11 "companies existing for 10 or more years in 2011"
label var ETCTOT11 "creation of establishments in 2011"
label var ETCBE11 "creation of industrial establishments in 2011"
label var ETCCFZ11 "creation of buliding establishments in 2011"
label var ETCGU11 "creation of commercial, transport and miscellaneous services establishments in 2011"
label var ETCGZ11 "of which creation of commercial est in 2011"
label var ETCOQ11 "creation of  pub admin, edu, health and social welfare establishments in 2011"
label var ETCTOT10 "creation of establishments in 2010"
label var ETCTOT09 "creation of establishments in 2009"
label var ETCTOT08 "creation of establishments in 2008"
label var ETCTOT07 "creation of establishments in 2007"
label var ETCTOT06 "creation of establishments in 2006"
label var ETNTOT11 "establishments in 2011"
label var ETNBE11 "industrial establishments in 2011"
label var ETNCFZ11 "building establishments in 2011"
label var ETNGU11 "commercial, transport and miscellaneous services establishments in 2011"
label var ETNGZ11 "of which commercial establishments in 2011"
label var ETNOQ11 "creation of est. for pub admin, edu, health and social welfare in 2011"
label var ENCTOT12 "creation of companies in 2012"
label var ENCBE12 "creation of industrial companies in 2012"
label var ENCCFZ12 "creation of building companies in 2012"
label var ENCGU12 "creation of commercial, transport and miscellaneous services companies in 2012"
label var ENCGZ12 "of which commercial companies in 2012"
label var ENCOQ12 "creation of pub admin, edu, health and social welfare companies in 2012"
label var ENCITOT12 "creation of single-member companies in 2012"
label var ENCIBE12 "creation of industrial single-member companies in 2012"
label var ENCICFZ12 "creation of  single-member building companies in 2011"
label var ENCIGU12 "creation of single-member commercial, transport and miscellaneous services companies 2012"
label var ENCIGZ12 "of which creation of commercial single-member companies 2012"
label var ENCIOQ12 "creation of single-member public administration, education, health and social welfare companies in 2012"
label var ENNTOT12 "Companies in 2012"
label var ENNBE12 "Industrial companies in 2012"
label var ENNCFZ12 "buliding companies in 2012"
label var ENNGU12 "commercial, transport and miscellaneous services companies in 2012"
label var ENNGZ12 "of which commercial companies in 2012"
label var ENNOQ12 "public administration, education, health and social welfare companies in 2012"
label var ENN0AN12 "companies existing for less than a year in 2012"
label var ENN1AN12 "comp. existing for one year in 2012"
label var ENN2AN12 "comp. existing for 2 years in 2012"
label var ENN3AN12 "comp. existing for 3 years in 2012"
label var ENN4AN12 "comp. existing for 4 years in 2012"
label var ENN5AN12 "comp. existing for 5 years in 2012"
label var ENN6AN12 "comp. existing for 6 to 9 years in 2012"
label var ENN7AN12 "comp. existing for 10 or more years in 2012"
label var ETCTOT12 "creation of establishments in 2012"
label var ETCBE12 "creation of industrial establishments in 2012"
label var ETCCFZ12 "creation of buliding establishments in 2012"
label var ETCGU12 "Creation of commercial, transport and miscellaneous services establishments in 2012"
label var ETCGZ12 "of which commercial establishments in 2012"
label var ETCOQ12 "creation of establishments of public administration, education, health and social welfare in 2012"
label var ETNTOT12 "establishments in 2012"
label var ETNBE12 "industrial establishments in 2012"
label var ETNCFZ12 "buliding establishments in 2012"
label var ETNGU12 "commercial, transport and miscellaneous services establishments in 2012"
label var ETNGZ12 "of which commercial establishments 2012"
label var ETNOQ12 "establishments of public administration, education, health and social welfare in 2012"
label var ENCTOT13 "creation of companies in 2013"
label var ENCBE13 "creation of industrial companies in 2013"
label var ENCCFZ13 "creation of building companies in 2013"
label var ENCGU13 "creation of commercial, transport and miscellaneous service companies in 2013"
label var ENCGZ13 "of which creation of commercial companies in 2013"
label var ENCOQ13 "creation of public administration, education, health and social welfare companies in 2013"
label var ENCTOT12 "creation of companies in 2012"
label var ENCITOT13 "creation of single-member companies in 2013"
label var ENCIBE13 "cresation of single-member industrial companies in 2013"
label var ENCICFZ13 "creation of single-member building companies in 2013"
label var ENCIGU13 "creation of single-member commercial, transport and miscellaneous services companies in 2013"
label var ENCIGZ13 "of which creation of single-member commercial companies in 2013"
label var ENCIOQ13 "creation of single-member companies in public admin, education, health and social welfare in 2013"
label var ENCITOT12 "creation of single-member companies in 2012"
label var ENNTOT13 "companies in 2013"
label var ENNBE13 "industrial companies in 2013"
label var ENNCFZ13 "building companies in 2013"
label var ENNGU13 "commercial, transport and miscellaneous services companies in 2013"
label var ENNGZ13 "of which commercial companies in 2013"
label var ENNOQ13 "public admin, education, health and social welfare companies in 2013"
label var ENN0AN13 "companies existing for less than a year in 2012"
label var ENN1AN13 "comp. existing for one year in 2013"
label var ENN2AN13 "comp. existing for 2 years in 2013"
label var ENN3AN13 "comp. existing for 3 years in 2012"
label var ENN4AN13 "comp. existing for 4 years in 2013"
label var ENN5AN13 "comp. existing for 5 years in 2012"
label var ENN6AN13 "comp. existing for 6 to 9 years in 2013"
label var ENN7AN13 "comp. existing for 10 or more years in 2013"
label var ETCTOT13 "creation of establishments in 2013"
label var ETCBE13 "creation of industrial establishments in 2013"
label var ETCCFZ13 "creation of building establishments in 2013"
label var ETCGU13 "creation of commercial, transport and miscellaneous services establishments in 2013"
label var ETCGZ13 "of which creation of commercial establishments in 2013"
label var ETCOQ13 "creation of public admin, education, health and social welfare establishments in 2013"
label var ETCTOT12 "creation of establishments in 2012"
label var ETNTOT13 "establishments in 2013"
label var ETNBE13 "industrial establishments in 2013"
label var ETNCFZ13 "buliding establishments in 2013"
label var ETNGU13 "commercial, tansport and miscellaneous services establishments in 2013"
label var ETNGZ13 "of which commercial establishments in 2013"
label var ETNOQ13 "establishments of public admin, education, health and social welfare in 2013"

//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace
********************************************************************************
//3.3: INSEE detailed population data
//all data accessed at INSEE website: http://www.insee.fr/fr/default.asp (02/11/15)
//overview over communal-level data: http://www.insee.fr/fr/bases-de-donnees/default.asp?page=statistiques-locales/donnees-detaillees_tableau.htm (02/11/15)
//give detailed population breakdown
//key: CODGEO gives INSEE municipality ID codes
//this is a big one
set excelxlsxlargefile on
//data processing is very similar to the other INSEE data (3.1, 3.2)
clear
import excel "base-cc-evol-struct-pop-2011.xlsx", ///
sheet("COM") cellrange(A6:EQ36694) firstrow
rename CODGEO insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE2010 ID_MODIF_GEO

/*we need to take care of two municipalities that have since been merged with
others*/
matrix oldcode=(21551,28042,59248,59540,76095)
matrix newcode=(21048,28361,59183,59183,76540)
scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist P11_POP-C11_POP55P_CS8{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode
save "processed data\base-cc-evol-struct-pop-2011.dta", replace
********************************************************************************
//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1
//merge first data set
merge m:1 insee_code using "processed data\base-cc-evol-struct-pop-2011.dta", nogen
//add labels
label var P11_POP "Population in 2011 (princ)"
label var P06_POP "Population in 2006 (princ)"
label var P11_POP0014 "Pop 0-14 years in 2011 (princ)"
label var P11_POP1529 "Pop 15-29 years in 2011 (princ)"
label var P11_POP3044 "Pop 30-44 years in 2011 (princ)"
label var P11_POP4559 "Pop 45-59 years in 2011 (princ)"
label var P11_POP6074 "Pop 60-74 years in 2011 (princ)"
label var P11_POP7589 "Pop 75-89 years in 2011 (princ)"
label var P11_POP90P "Pop 90 years or more in 2011 (princ)"
label var P06_POP0014 "Pop 0-14 years in 2006 (princ)"
label var P06_POP1529 "Pop 15-29 years in 2006 (princ)"
label var P06_POP3044 "Pop 30-44 years in 2006 (princ)"
label var P06_POP4559 "Pop 45-59 years in 2006 (princ)"
label var P06_POP6074 "Pop 60-74 years in 2006 (princ)"
label var P06_POP7589 "Pop 75-89 years in 2006 (princ)"
label var P06_POP90P "Pop 90 years or more in 2006 (princ)"
label var P11_POPH "male Pop in 2011 (princ)"
label var P11_H0014 "male Pop 0-14 ans en 2011 (princ)"
label var P11_H1529 "male Pop 15-29 years in 2011 (princ)"
label var P11_H3044 "male Pop 30-44 years in 2011 (princ)"
label var P11_H4559 "male Pop 45-59 years in 2011 (princ)"
label var P11_H6074 "male Pop 60-74 years in 2011 (princ)"
label var P11_H7589 "male Pop 75-89 years in 2011 (princ)"
label var P11_H90P "male Pop 90 years or more in 2011 (princ)"
label var P11_H0019 "male Pop 0-19 years in 2011 (princ)"
label var P11_H2064 "male Pop 20-64 years in 2011 (princ)"
label var P11_H65P "male Pop 65 ans or more in 2011 (princ)"
label var P11_POPF "female Pop in 2011 (princ)"
label var P11_F0014 "female Pop 0-14 years in 2011 (princ)"
label var P11_F1529 "female Pop 15-29 years in 2011 (princ)"
label var P11_F3044 "female Pop 30-44 years in2011 (princ)"
label var P11_F4559 "female Pop  45-59 years in 2011 (princ)"
label var P11_F6074 "female Pop  60-74 years in 2011 (princ)"
label var P11_F7589 "female Pop  75-89 years in 2011 (princ)"
label var P11_F90P "female Pop 90 years or more in 2011 (princ)"
label var P11_F0019 "female Pop 0-19 years in 2011 (princ)"
label var P11_F2064 "female Pop  20-64 years in 2011 (princ)"
label var P11_F65P "Pop Femmes 65 years or more in 2011 (princ)"
label var P11_POP01P "Pop 1 year or more in 2011 (princ)"
label var P11_POP01P_IRAN1 "Pop 1 year or more living 1 year before in same aptm in 2011 (princ)"
label var P11_POP01P_IRAN2 "Pop 1 year or more living 1 year before in other aptm same municipality in 2011 (princ)"
label var P11_POP01P_IRAN3 "Pop 1 year or more living 1 year before in other municipality same dept in 2011 (princ)"
label var P11_POP01P_IRAN4 "Pop 1 year or more living 1 year before in other dept same region in 2011(princ)"
label var P11_POP01P_IRAN5 "Pop 1 year or more living 1 year before in other metropolitan region (other region of home country) in 2011 (princ)"
label var P11_POP01P_IRAN6 "Pop 1 year or more living 1 year before in french overseas dept in 2011 (princ)"
label var P11_POP01P_IRAN7 "Pop 1 year or more living 1 year before outside home country or french overseas dept in 2011 (princ)"
label var P11_POP0114_IRAN2P "Pop 1-14 years living 1 year before other aptm in 2011 (princ)"
label var P11_POP0114_IRAN2 "Pop 1-14 years living 1 year before other aptm same municipality in 2011 (princ)"
label var P11_POP0114_IRAN3P "Pop 1-14 years living 1 year before other municipality in 2011 (princ)"
label var P11_POP1524_IRAN2P "Pop 15-24 years living 1 year before other aptm in 2011 (princ)"
label var P11_POP1524_IRAN2 "Pop 15-24 years living 1 year before other aptm same municipality in 2011 (princ)"
label var P11_POP1524_IRAN3P "Pop 15-24 years living 1 year before other municipality in 2011 (princ)"
label var P11_POP2554_IRAN2P "Pop 25-54 years living 1 year before other aptm in 2011 (princ)"
label var P11_POP2554_IRAN2 "Pop 25-54 years living 1 year before other aptm same municipality in 2011 (princ)"
label var P11_POP2554_IRAN3P "Pop 25-54 years living 1 year before other municipality in 2011 (princ)"
label var P11_POP55P_IRAN2P "Pop 55 years or more living 1 year before other aptm in 2011 (princ)"
label var P11_POP55P_IRAN2 "Pop 55 years or more living 1 year before other aptm same municipality in 2011 (princ)"
label var P11_POP55P_IRAN3P "Pop 55 years or more living 1 year before other municipality in 2011 (princ)"
label var C11_POP15P "Pop 15 years or more in 2011 (compl)"
label var C11_POP15P_CS1 "Pop 15 years or more farmers in 2011 (compl)"
label var C11_POP15P_CS2 "Pop 15 years or more Artisans, Comm., managing directors in 2011 (compl)"
label var C11_POP15P_CS3 "Pop 15 years or more executives, intellecutal professionals in 2011 (compl)"
label var C11_POP15P_CS4 "Pop 15 years or more intermediate professions in 2011 (compl)"
label var C11_POP15P_CS5 "Pop 15 years or more employees in 2011 (compl)"
label var C11_POP15P_CS6 "Pop 15 years or more workers in 2011 (compl)"
label var C11_POP15P_CS7 "Pop 15 years or more retired in 2011 (compl)"
label var C11_POP15P_CS8 "Pop 15 years or more other in 2011 (compl)"
label var C06_POP15P "Pop 15 years or more in 2006 (compl)"
label var C06_POP15P_CS1 "Pop 15 years or more farmers in 2006 (compl)"
label var C06_POP15P_CS2 "Pop 15 years or more Artisans, Comm., managing directors in 2006 (compl)"
label var C06_POP15P_CS3 "Pop 15 years or more executives, intellecutal professionals in 2006 (compl)"
label var C06_POP15P_CS4 "Pop 15 years or more intermediate professions in 2006 (compl)"
label var C06_POP15P_CS5 "Pop 15 years or more employees in 2006 (compl)"
label var C06_POP15P_CS6 "Pop 15 years or more workers in 2006 (compl)"
label var C06_POP15P_CS7 "Pop 15 years or more retired in 2006 (compl)"
label var C06_POP15P_CS8 "Pop 15 years or more other en 2006 (compl)"
label var C11_H15P "Pop 15 years or more male in 2011 (compl)"
label var C11_H15P_CS1 "Pop 15 years or more male farmers in 2011 (compl)"
label var C11_H15P_CS2 "Pop 15 years or more male Artisans, Comm., managing directors in 2011 (compl)"
label var C11_H15P_CS3 "Pop 15 years or more male executives, intellecutal professionals in 2011 (compl)"
label var C11_H15P_CS4 "Pop 15 years or more male intermediate professions in 2011 (compl)"
label var C11_H15P_CS5 "Pop 15 years or more male employees in 2011 (compl)"
label var C11_H15P_CS6 "Pop 15 years or more male workers in 2011 (compl)"
label var C11_H15P_CS7 "Pop 15 years or more male retired in 2011 (compl)"
label var C11_H15P_CS8 "Pop 15 years or more male other in 2011 (compl)"
label var C06_H15P "Pop 15 years or more male in 2006 (compl)"
label var C06_H15P_CS1 "Pop 15 years or more male farmers in 2006 (compl)"
label var C06_H15P_CS2 "Pop 15 years or more male artisans, comm., managing directors in 2006 (compl)"
label var C06_H15P_CS3 "Pop 15 years or more male executives, intellecutal professionals in 2006 (compl)"
label var C06_H15P_CS4 "Pop 15 years or more male intermediate professions in 2006 (compl)"
label var C06_H15P_CS5 "Pop 15 years or more male employees in 2006 (compl)"
label var C06_H15P_CS6 "Pop 15 years or more male workers in 2006 (compl)"
label var C06_H15P_CS7 "Pop 15 years or more male retired in 2006 (compl)"
label var C06_H15P_CS8 "Pop 15 years or more male other in 2006 (compl)"
label var C11_F15P "Pop 15 years or more female in 2011 (compl)"
label var C11_F15P_CS1 "Pop 15 years or more female farmers in 2011 (compl)"
label var C11_F15P_CS2 "Pop 15 years or more female artisans, comm., managing directors in 2011 (compl)"
label var C11_F15P_CS3 "Pop 15 years or more female executives, intellecutal professionals in 2011 (compl)"
label var C11_F15P_CS4 "Pop 15 years or more female intermediate professions in 2011 (compl)"
label var C11_F15P_CS5 "Pop 15 years or more female employees in 2011 (compl)"
label var C11_F15P_CS6 "Pop 15 years or more female workers in 2011 (compl)"
label var C11_F15P_CS7 "Pop 15 years or more female retired in 2011 (compl)"
label var C11_F15P_CS8 "Pop 15 years or more female other in 2011 (compl)"
label var C06_F15P "Pop 15 years or more female in 2006 (compl)"
label var C06_F15P_CS1 "Pop 15 years or more female farmers in 2006 (compl)"
label var C06_F15P_CS2 "Pop 15 years or more female artisans, comm., managing directors in  2006 (compl)"
label var C06_F15P_CS3 "Pop 15 years or more female executives, intellecutal professionals in 2006 (compl)"
label var C06_F15P_CS4 "Pop 15 years or more female intermediate professions in 2006 (compl)"
label var C06_F15P_CS5 "Pop 15 years or more female employees in 2006 (compl)"
label var C06_F15P_CS6 "Pop 15 years or more female workers in 2006 (compl)"
label var C06_F15P_CS7 "Pop 15 years or more female retired in 2006 (compl)"
label var C06_F15P_CS8 "Pop 15 years or more female other in 2006 (compl)"
label var C11_POP1524 "Pop 15-24 years in 2011 (compl)"
label var C11_POP1524_CS1 "Pop 15-24 years farmers in 2011 (compl)"
label var C11_POP1524_CS2 "Pop 15-24 years artisans, comm., managing directors in 2011 (compl)"
label var C11_POP1524_CS3 "Pop 15-24 years executives, intellecutal professionals in 2011 (compl)"
label var C11_POP1524_CS4 "Pop 15-24 years intermediate professions in 2011 (compl)"
label var C11_POP1524_CS5 "Pop 15-24 years employees in 2011 (compl)"
label var C11_POP1524_CS6 "Pop 15-24 years workers in 2011 (compl)"
label var C11_POP1524_CS7 "Pop 15-24 years retired in 2011 (compl)"
label var C11_POP1524_CS8 "Pop 15-24 years other in 2011 (compl)"
label var C11_POP2554 "Pop 25-54 years in 2011 (compl)"
label var C11_POP2554_CS1 "Pop 25-54 years farmers in 2011 (compl)"
label var C11_POP2554_CS2 "Pop 25-54 years artisans, comm., managing directors in 2011 (compl)"
label var C11_POP2554_CS3 "Pop 25-54 years executives, intellecutal professionals in 2011 (compl)"
label var C11_POP2554_CS4 "Pop 25-54 years intermediate professions in 2011 (compl)"
label var C11_POP2554_CS5 "Pop 25-54 years employees in 2011 (compl)"
label var C11_POP2554_CS7 "Pop 25-54 years retired in 2011 (compl)"
label var C11_POP2554_CS8 "Pop 25-54 years other en 2011 (compl)"
label var C11_POP55P "Pop 55 years or more in 2011 (compl)"
label var C11_POP55P_CS1 "Pop 55 years or more farmers in 2011 (compl)"
label var C11_POP55P_CS2 "Pop 55 years or more artisans, comm., managing directors in 2011 (compl)"
label var C11_POP55P_CS3 "Pop 55 years or more executives, intellecutal professionals in 2011 (compl)"
label var C11_POP55P_CS4 "Pop 55 years or more intermediate professions in 2011 (compl)"
label var C11_POP55P_CS5 "Pop 55 years or more employees in 2011 (compl)"
label var C11_POP55P_CS6 "Pop 55 years or more workers in 2011 (compl)"
label var C11_POP55P_CS7 "Pop 55 years or more retired in 2011 (compl)"
label var C11_POP55P_CS8 "Pop 55 years or more other en 2011 (compl)"
//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace

*******************************************************************************
//3.4: INSEE revenue data
//all data accessed at INSEE website: http://www.insee.fr/fr/default.asp (04/13/15)
//overview over communal-level data: http://www.insee.fr/fr/bases-de-donnees/default.asp?page=statistiques-locales/donnees-detaillees_tableau.htm (02/11/15)
//give detailed revenue information
//key: CODGEO gives INSEE municipality ID codes

//data processing is very similar to the other INSEE data (3.1, 3.2, 3.3)
clear
import excel "base-cc-irpp-nouv-serie-09.xls", ///
sheet("REVIM_COM") cellrange(A6:AJ36686) firstrow

rename CODGEO insee_code

drop if REG=="94"

drop if insee_code>="97100" & insee_code~=""

destring insee_code, replace

drop LIBGEO REG DEP ARR CV ZE2010 EPCI

/*we need to take care of two municipalities that have since been merged with
others*/
matrix oldcode=(28042,76095)

matrix newcode=(28361,76540)

scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist NBFF09-RNETFFNI06{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

save "processed data\base-cc-irpp-nouv-serie-09.dta", replace
**********************************************************************
//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1
//merge first data set
merge m:1 insee_code using "processed data\base-cc-irpp-nouv-serie-09.dta", nogen
//add labels
label var NBFF09 "households in 2009"
label var RNETFF09 "net declared income of households in 2009 (EUR)"
label var IMPTOTFF09 "Impet total households in 2009 (EUR)"
label var NBFFI09 "taxable households in 2009"
label var RNETFFI09 "net declared income of taxable housholds in 2009 (EUR)"
label var NBFFNI09 "non-taxable households in 2009"
label var RNETFFNI09 "net declared income of non-taxable households in 2009 (EUR)"
label var NBFF08 "households in 2008"
label var RNETFF08 "net declared income of households in 2008 (EUR)"
label var IMPTOTFF08 "Impet total households in 2008 (EUR)"
label var NBFFI08 "taxable households in 2008"
label var RNETFFI08 "net declared income of taxable households in 2008 (EUR)"
label var NBFFNI08 "non-taxable households in 2008"
label var RNETFFNI08 "net declared income of non-taxable housholds in 2008 (EUR)"
label var NBFF07 "households in 2007"
label var RNETFF07 "net declared income of households in 2007 (EUR)"
label var IMPTOTFF07 "Impet total households in 2007 (EUR)"
label var NBFFI07 "taxable households in 2007"
label var RNETFFI07 "net declared income of taxable households in 2007 (EUR)"
label var NBFFNI07 "non-taxable households in 2007"
label var RNETFFNI07 "net declared income of non-taxable housholds in 2007 (EUR)"
label var NBFF06 "households in 2006"
label var RNETFF06 "net declared income of households in 2006 (EUR)"
label var IMPTOTFF06 "Impet total households in 2006 (EUR)"
label var NBFFI06 "taxable households in 2006"
label var RNETFFI06 "net declared income of taxable households in 2006 (EUR)"
label var NBFFNI06 "non-taxable households in 2006"
label var RNETFFNI06 "net declared income of non-taxable housholds in 2006 (2)"
//export the merged data
save "processed data\AlsaceLorraine$savenum.dta", replace
********************************************************************************
//3.5: INSEE Household income data
//key: COM gives INSEE municipality ID codes

//data processing is very similar to the other INSEE data (3.1, 3.2, 3.3, 3.4)
clear
import excel "RFDM2008COM.xls", ///
sheet("D_M") cellrange(A7:X36567) firstrow
rename COM insee_code
drop if REG=="94"
drop if insee_code>="97100" & insee_code~=""
destring insee_code, replace
drop LIBGEO REG DEP ARR CV ZE1990 
/*we need to take care of two municipalities that have since been merged with
others*/
matrix oldcode=(28042,59248,59540,76095)

matrix newcode=(28361,59183,59183,76540)

scalar define imax=colsof(oldcode)
quietly forvalues i=1(1)`=imax'{
scalar define old=el(oldcode,1,`i')
scalar define new=el(newcode,1,`i')
foreach var of varlist NBMEN08-RFMGI08{
sum `var' if insee_code==`=old', meanonly
replace `var'=r(mean)+`var' if insee_code==`=new' & r(mean)~=.
}
drop if insee_code==`=old'
scalar drop old new
}
scalar drop imax
matrix drop oldcode newcode

keep RFMMO08 RFMGI08 NBMEN08 RFMQ108 RFMQ208  RFMIQ08 insee_code

label var insee_code "Insee code"
label var NBMEN08 "Nb de menages fiscaux"
label var RFMQ108 "1er quartile (EUR)"
label var RFMQ208 "Mediane (EUR)"
label var RFMIQ08 "3eme quartile (EUR)"
label var RFMMO08 "Moyenne (EUR)"
label var RFMGI08 "Indice de Gini"
save "processed data\RFDM2008COM.dta", replace
*****************************************************************************************************************
*************************************Historic Population, obtained directly from author *************************
***Bas-Rhin population
*Load File
import excel "Bas-Rhin population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A== "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*Destring merge-variable
destring insee_code, replace
destring Population_1916, replace
*Drop unnecessary variables
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Bas-Rhin population 1916", replace

*Load File
import excel "Bas-Rhin population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Bas-Rhin population 1926", replace

*Load File
import excel "Bas-Rhin population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Bas-Rhin population 1936", replace

*Load File
import excel "Bas-Rhin population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Bas-Rhin population 1946", replace
*Merge Bas-Rhin
use "processed data\Bas-Rhin population 1916", clear
merge 1:1 insee_code using "processed data\Bas-Rhin population 1926", nogen
merge 1:1 insee_code using "processed data\Bas-Rhin population 1936", nogen
merge 1:1 insee_code using "processed data\Bas-Rhin population 1946", nogen
save "processed data\Bas-Rhin population 1916-46", replace

***Haut-Rhin population
import excel "Haut-Rhin population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*destring
destring insee_code, replace
destring Population_1916, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Haut-Rhin population 1916", replace

import excel "Haut-Rhin population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Haut-Rhin population 1926", replace

import excel "Haut-Rhin population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Haut-Rhin population 1936", replace

import excel "Haut-Rhin population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Haut-Rhin population 1946", replace

*Merge Haut-Rhin
use "processed data\Haut-Rhin population 1916", clear
merge 1:1 insee_code using "processed data\Haut-Rhin population 1926", nogen
merge 1:1 insee_code using "processed data\Haut-Rhin population 1936", nogen
merge 1:1 insee_code using "processed data\Haut-Rhin population 1946", nogen
save "processed data\Haut-Rhin population 1916-46", replace

***Meurte-et-Moselle population
import excel "Meurte-et-Moselle population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*destring
destring insee_code, replace
destring Population_1916, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Meurte-et-Moselle population 1916", replace

import excel "Meurte-et-Moselle population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Meurte-et-Moselle population 1926", replace

import excel "Meurte-et-Moselle population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Meurte-et-Moselle population 1936", replace

import excel "Meurte-et-Moselle population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Meurte-et-Moselle population 1946", replace

*Merge
use "processed data\Meurte-et-Moselle population 1916", clear
merge 1:1 insee_code using "processed data\Meurte-et-Moselle population 1926", nogen
merge 1:1 insee_code using "processed data\Meurte-et-Moselle population 1936", nogen
merge 1:1 insee_code using "processed data\Meurte-et-Moselle population 1946", nogen
save "processed data\Meurte-et-Moselle population 1916-46", replace

***Meuse population
import excel "Meuse population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*destring
destring insee_code, replace
destring Population_1916, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Meuse population 1916", replace

import excel "Meuse population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Meuse population 1926", replace

import excel "Meuse population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Meuse population 1936", replace

import excel "Meuse population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Meuse population 1946", replace
*Merge
use "processed data\Meuse population 1916", clear
merge 1:1 insee_code using "processed data\Meuse population 1926", nogen
merge 1:1 insee_code using "processed data\Meuse population 1936", nogen
merge 1:1 insee_code using "processed data\Meuse population 1946", nogen
save "processed data\Meuse population 1916-46", replace

***Moselle population
import excel "Moselle population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*destring
destring insee_code, replace
destring Population_1916, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Moselle population 1916", replace

import excel "Moselle population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Moselle population 1926", replace

import excel "Moselle population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Moselle population 1936", replace

import excel "Moselle population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Moselle population 1946", replace

*Merge
use "processed data\Moselle population 1916", clear
merge 1:1 insee_code using "processed data\Moselle population 1926", nogen
merge 1:1 insee_code using "processed data\Moselle population 1936", nogen
merge 1:1 insee_code using "processed data\Moselle population 1946", nogen
save "processed data\Moselle population 1916-46", replace

***Vosges population
import excel "Vosges population_dept_67_1916_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1916
*destring
destring insee_code, replace
destring Population_1916, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1916, by (insee_code)
*Save as .dta
save "processed data\Vosges population 1916", replace

import excel "Vosges population_dept_67_1926_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1926
*destring
destring insee_code, replace
destring Population_1926, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1926, by (insee_code)
*Save as .dta
save "processed data\Vosges population 1926", replace

import excel "Vosges population_dept_67_1936_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1936
*destring
destring insee_code, replace
destring Population_1936, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1936, by (insee_code)
*Save as .dta
save "processed data\Vosges population 1936", replace

import excel "Vosges population_dept_67_1946_entre_1_et_500000", clear
*Drop header
drop if A == "INSEE"
*Rename Variables
rename A insee_code
rename C Population_1946
*destring
destring insee_code, replace
destring Population_1946, replace
*Drop
drop B D
*Collapse multiple insee_codes (community-fusions)
collapse (sum)Population_1946, by (insee_code)
*Save as .dta
save "processed data\Vosges population 1946", replace
*merge
use "processed data\Vosges population 1916", clear
merge 1:1 insee_code using "processed data\Vosges population 1926", nogen
merge 1:1 insee_code using "processed data\Vosges population 1936", nogen
merge 1:1 insee_code using "processed data\Vosges population 1946", nogen
save "processed data\Vosges population 1916-46", replace

*Join all population datasets
use "processed data\Bas-Rhin population 1916-46", clear
append using "processed data\Haut-Rhin population 1916-46"
append using "processed data\Meurte-et-Moselle population 1916-46"
append using "processed data\Meuse population 1916-46"
append using "processed data\Moselle population 1916-46"
append using "processed data\Vosges population 1916-46"
label var Population_1916 "Population according to 1916 census"
label var Population_1926 "Population according to 1926 census"
label var Population_1936 "Population according to 1936 census"
label var Population_1946 "Population according to 1946 census"
save "processed data\Total population 1916-46", replace

*****************************************************************************************************************
*************************************Associations********************************************************************
*Load file
import excel "rna_sub", firstrow clear
*keep relevant variables and format
keep titre objet_social1 adrs_codeinsee
rename objet_social1 os1
rename adrs_codeinsee insee_code
format %14s titre
/*clean up insee-code (force is done because corsican Insee-Codes contain letters. Since they are not relevant for the study, they can be forced out. */
destring insee_code, force replace
sort insee_code
drop if mi(insee_code)

*Generate various measurements for associations by insee-code
sort insee_code os1
egen assoc_tot = count(os1), by(insee_code)

egen assoc00 = total(os1 == 10000), by(insee_code)

egen assoc05 = total(os1 == 10005), by(insee_code)

egen assoc10 = total (os1 == 10010), by(insee_code)

egen assoc15 = total (os1 == 10015), by(insee_code)

egen assoc20 = total (os1 == 10020), by(insee_code)

egen assoc22 = total (os1 == 10022), by(insee_code)

egen assoc30 = total (os1 == 10030), by(insee_code)

*Collapse, so that each insee-code appears only once
drop titre
collapse assoc_tot - assoc30, by(insee_code)

label var assoc_tot "Total number of associations per insee-code"
label var assoc00 "Number of 10000-subcategory associations per insee-code"
label var assoc05 "Number of 10005-subcategory associations per insee-code"
label var assoc10 "Number of 10010-subcategory associations per insee-code"
label var assoc15 "Number of 10015-subcategory associations per insee-code"
label var assoc20 "Number of 10020-subcategory associations per insee-code"
label var assoc22 "Number of 10022-subcategory associations per insee-code"
label var assoc30 "Number of 10030-subcategory associations per insee-code"

save "processed data\associations", replace

*****************************************************************************************************************
*************************************Twitter********************************************************************
import excel "Tweets_select_final.xls", ///
sheet("Tweets_select_final")  firstrow clear
keep if In_Area==1
gen Other_tweet=0
replace Other_tweet=1 if Frankreich=="FALSE" & Deutschland=="FALSE"
gen Germany_tweet=0
replace Germany_tweet=1 if Deutschland=="TRUE"
gen France_tweet=0
replace France_tweet=1 if Frankreich=="TRUE"
keep Other_tweet France_tweet Germany_tweet insee_com  nom_comm
collapse (sum) Other_tweet France_tweet Germany_tweet, by (insee_com nom_comm)
ren  insee_com insee_code
save "processed data\tweets.dta", replace
********************************************************************************

//load the base data set
clear
use "processed data\AlsaceLorraine$savenum.dta"
global savenum=$savenum+1

//merge income data
merge m:1 insee_code using "processed data\RFDM2008COM.dta", nogen

//merge EU funds
merge m:1 dep_name using "processed data\EUfunds", keep(1 3) keepusing(payments_nuts3_2006 )
bys dep_name:egen Pop_dep=total(pop_tot) 
gen EUpc=payments_nuts3_2006/Pop_dep

//merge population data
merge m:1 insee_code using "processed data\Total population 1916-46.dta", nogen keep(1 3)


//merge association data
merge m:1 insee_code using "processed data\associations.dta", nogen
*Replace missing values w/ 0
replace assoc_tot = 0 if (assoc_tot >= .)
replace assoc00 = 0 if (assoc00 >= .)
replace assoc05 = 0 if (assoc05 >= .)
replace assoc10 = 0 if (assoc10 >= .)
replace assoc15 = 0 if (assoc15 >= .)
replace assoc20 = 0 if (assoc20 >= .)
replace assoc22 = 0 if (assoc22 >= .)
replace assoc30 = 0 if (assoc30 >= .)

*weighting with population numbers
gen assoc_tot_w = assoc_tot/(pop_tot/1000)
label var assoc_tot_w "Number of associations, per 1000 inhabitants"
cap drop _merge
*********************************************************************************
//merge Cencus and Newspaper data
merge m:1 insee_code using "processed data\mig2ss_cleaned.dta", nogen
*
merge m:1 insee_code using "processed data\mig01sc_cleaned.dta", nogen
*Regional newspaper
merge m:1 insee_code using "processed data\NewspaperSales2014_cleaned.dta", nogen
label var avgVNOABO_ph "Average subscriptions+ot. sales per household Republicain Lorraine 2014"
label var avgABO_ph "Average subscriptions per household Republicain Lorraine 2014"

*save "processed data\CensusandNewspapers.dta", replace
********************************************************************************
drop if insee_code==.
cap drop _merge
merge 1:1 insee_code using "processed data\tweets.dta", keep(1 3) keepusing(France_tweet Germany_tweet Other_tweet)
replace France_tweet=0 if France_tweet==.
replace Germany_tweet=0 if Germany_tweet==.
replace Other_tweet=0 if Other_tweet==.

label var France_tweet "No of Tweets about French football team during 2014 WC"
label var Germany_tweet "No of Tweets about German football team during 2014 WC"
label var  Other_tweet "No of tweets during 2014 WC"
//export the merged data
cap noisily saveold "processed data\AlsaceLorraine$savenum.dta",  replace
cap noisily saveold "processed data\AlsaceLorraine$savenum.dta", replace version(12)

*****************************************************************************************************************************
*****************************************************************************************************************************
*****************************************************************************************************************************
*merging suitabilities to the data

clear
import delim "processed data\insee.txt", clear //this was exported from arcgis manually could be automated also 
destring insee_com, replace force
ren insee_com insee_code
keep fid insee_code
save "processed data\insee.dta", replace

use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1

drop if OBJECTID ==.
save "processed data\AlsaceLorraine$savenum.dta", replace
local files : dir "2018_05_03_suitabilities\" files "*.xls"
foreach file in `files'{
	import excel "2018_05_03_suitabilities/`file'", firstrow clear
	rename COUNT fid
	local name : subinstr local file ".xls" ".dta", all 
	display "`name'"
	local cropdta : subinstr local name "tab1_corre" "sui_", all
	display "`cropdta'"
	local crop : subinstr local cropdta ".dta" "", all
	display "`crop'"	
	rename STD `crop'
	keep fid `crop'
	merge 1:1 fid using "processed data\insee.dta", keep(1 3)
	drop if insee_code ==.
	save "processed data/`cropdta'", replace
	use "processed data\AlsaceLorraine$savenum.dta", clear
	merge 1:1 insee_code using "processed data/`cropdta'", nogen
	drop fid
	save "processed data\AlsaceLorraine$savenum.dta", replace	
}

*merging elevation and ruggedness to the data

use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1

drop if OBJECTID ==.
save "processed data\AlsaceLorraine$savenum.dta", replace
local files : dir "elev_rugg\" files "*.xls"
foreach file in `files'{
	import excel "elev_rugg/`file'", firstrow clear
	rename COUNT fid
	local name : subinstr local file ".xls" ".dta", all 
	display "`name'"
	local er_dta : subinstr local name "elev_mn15_grd_" "er_", all
	display "`er_dta'"
	local er : subinstr local er_dta ".dta" "", all
	display "`er'"	
	rename STD `er'
	if "`er'" == "er_elev"{
		rename SUM st_dev_elev
		keep fid `er' st_dev_elev
	}
	else{
		keep fid `er' 
	}
	merge 1:1 fid using "processed data\insee.dta", keep(1 3)
	drop if insee_code ==.
	save "processed data/`er_dta'", replace
	use "processed data\AlsaceLorraine$savenum.dta", clear
	merge 1:1 insee_code using "processed data/`er_dta'", nogen
	drop fid
	save "processed data\AlsaceLorraine$savenum.dta", replace	
}
label var er_elev Eleveation
label var er_rug Ruggedess
label var st_dev_elev "std. dev. of Elevation"

** merging the old border distance
import excel "near_table_old_border\neartable_FRA.xls", firstrow clear
ren insee_com insee_code
drop if insee_code==0 //this affects only Corse
ren NEAR_DIST dist_old_border
lab var dist_old_border "Historical border btw Meurthe/Moselles"
keep insee_code dist_old_border
save "processed data\neartable_FRA.dta", replace

use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
drop if OBJECTID ==. //getting rid of some Guadeloupe stuff (from sui merge)
merge 1:1 insee_code using "processed data\neartable_FRA.dta", nogen keep(1 3)
* merge (1 3) drops some more overseas stuff and keeps Marsaille, Lyon & Paris
* which are master only
save "processed data\AlsaceLorraine$savenum.dta", replace

* adding border segments of the actual treatment 
import excel "border_segments\neartable_FRA_south", firstrow clear
ren insee_com insee_code
ren NEAR_DIS_1 dist_mid_border
ren NEAR_DIS_2 dist_north_border
ren NEAR_DIS_3 dist_south_border
drop if insee_code==0
keep insee dist_mid dist_north dist_south
save "processed data\neartable_segments.dta",replace

use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge 1:1 insee_code using "processed data\neartable_segments.dta", nogen keep(1 3)

* generate border segment closest dummies 
* there is no case where all three distances are exactly equal
gen close_north=1 if dist_north_border<=dist_mid_border & dist_north_border<dist_south_border
replace close_north=0 if dist_north_border>dist_mid_border | dist_north_border >= dist_south_border

gen close_mid=1 if dist_mid_border<=dist_south_border & dist_mid_border<dist_north_border
replace close_mid=0 if dist_mid_border>dist_south_border | dist_mid_border>= dist_north_border

gen close_south=1 if dist_south_border<dist_mid_border & dist_south_border<=dist_north_border
replace close_south=0 if dist_south_border>=dist_mid_border | dist_south_border>dist_north_border

lab var close_north "northern border segment ist closest"
lab var close_south "southern border segment ist closest"
lab var close_mid "middle border segment is closest"
save "processed data\AlsaceLorraine$savenum.dta", replace

tempfile ntl
import delim "border_segments\neartable_lorraine.txt", clear
ren near_dist lorraine_dist_seg

gen lorraine_close_mid = 1 if near_fc == "treatment_border_lorrainemid_proj"
replace lorraine_close_mid = 0 if near_fc != "treatment_border_lorrainemid_proj"

gen lorraine_close_north = 1 if near_fc == "treatment_border_lorrainenorth_proj"
replace lorraine_close_north = 0 if near_fc != "treatment_border_lorrainenorth_proj"

gen lorraine_close_south = 1 if near_fc == "treatment_border_lorrainesouth_proj"
replace lorraine_close_south = 0 if near_fc != "treatment_border_lorrainesouth_proj"
save `ntl'

tempfile ntl_insee
import delim "border_segments\FRA_mun_cent_proj.txt", clear
ren insee_com insee_code
keep fid insee_code
ren fid in_fid
merge 1:1 in_fid using `ntl', nogen keep(1 3)
drop in_fid objectid near_fid near_fc
drop if insee_code == 0 //drop Corse
save `ntl_insee'
****************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge 1:1 insee_code using `ntl_insee', nogen keep(1 3) //some overseas are dropped here
save "processed data\AlsaceLorraine$savenum.dta", replace
****************************************************************************
* adding identifier for old districts
import excel "intersect_muncent_alldepbefore71.xls", firstrow clear
ren insee_com insee_code
drop if insee_code == 0 // Corse dropped
ren short_name dep_name_old
lab var dep_name_old "Name of department before 1871"
ren FID_alldep FID_dep_old
ren num  dep_num_old
keep dep_num_old FID_dep_old dep_name_old insee_code
collapse (first) dep_num_old dep_name_old, by(insee_code) // there are some duplicate 2 codes which dont matter
save "processed data\dep_old_id.dta", replace
***************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge 1:1 insee_code using "processed data\dep_old_id.dta", nogen
gen FE_meurthe = 0
replace FE_meurthe = 1 if dep_num_old == 153
gen FE_moselle = 0
replace FE_moselle = 1 if dep_num_old == 152
save "processed data\AlsaceLorraine$savenum.dta", replace
***************************************************************************
* adding the nonoverlapping parts of the old border
import excel "near_table_old_border\neartable_FRA_old.xls", firstrow clear
ren insee_com insee_code
drop if insee_code==0 //this affects only Corse
ren NEAR_DIST dist_ob_nonaligned
lab var dist_ob_nonaligned "Excludes part alligned with todays border"
keep insee_code dist_ob_nonaligned
save "processed data\neartable_FRA_old.dta", replace
***************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
drop if OBJECTID ==. //getting rid of some Guadeloupe stuff (from sui merge)
merge 1:1 insee_code using "processed data\neartable_FRA_old.dta", nogen keep(1 3)
* merge (1 3) drops some more overseas stuff and keeps Marsaille, Lyon & Paris
* which are master only
save "processed data\AlsaceLorraine$savenum.dta", replace
***************************************************************************
* 1969 Referendum
*Meuse
tempfile ref_meuse //create tempfile
import excel "Referendum1969_meuse.xls", firstrow clear //import vote data
qui for var *: rename X X_1969_meuse //append names with identifiers
gen lCommunes_1969_meuse = lower(Communes_1969_meuse)
gen lCantonde_1969_meuse = lower(Cantonde_1969_meuse)
egen cantid_1969_meuse = group(lCantonde_1969_meuse)
gen uid = _n
save "`ref_meuse'", replace
***************************************************************************
tempfile ref_meuse2
import excel "historiq2018_lorrain.xls", firstrow clear //import communal change data
* some transoformations to obtain unique insee_codes and possible name changes
destring DEP, force replace
drop if DEP==.
keep DEP AR CT COM NCCOFF NCCANC LEG
gen year = substr(LEG,-4,.)
destring year, replace
drop if year<1969 // only years after 1969 are relevant
drop if year > 2006 // our data is from 2005 so changes after 2006 should not appear in our sample
keep if DEP == 54 | DEP == 55 | DEP == 57
gen insee_code = 1000*DEP + COM
sort insee_code year
collapse (last) NCCANC, by(insee_code)
drop if NCCANC == ""
save "`ref_meuse2'"
***************************************************************************
tempfile ref_meuse1
use "processed data\AlsaceLorraine$savenum.dta", clear
keep if ID_2 == 55
keep mun_name dep_name reg_name ID_5 ID_3 ID_canton insee_code dep_num_old dep_name_old
merge 1:1 insee_code using "`ref_meuse2'", nogen keep(1 3) //checked! this is fine
gen lmun_name = lower(mun_name)
replace NCCANC = ustrto(ustrnormalize(NCCANC, "nfd"), "ascii", 2)  //handling nasty accents
gen lold_name = lower(NCCANC)
replace lold_name = lmun_name if lold_name == ""
save "`ref_meuse1'"
***************************************************************************
tempfile canton_names
import excel "FRA_adm5.xls", firstrow clear
keep if ID_2 == 55
gen insee_code = 1000*ID_2 + ID_5
keep i ID_3 NAME_3 ID_4 NAME_4 ID_5 NAME_5 insee_code

forvalues i = 3/5{
replace NAME_`i' = ustrto(ustrnormalize(NAME_`i', "nfd"), "ascii", 2)  //handling nasty accents
replace NAME_`i' = lower(NAME_`i')
}
save "`canton_names'"
***************************************************************************
use "`ref_meuse1'"
merge 1:1 insee_code using "`canton_names'", nogen
save "`ref_meuse1'", replace
***************************************************************************
use "`ref_meuse'", clear
matchit uid lCommunes_1969_meuse using "`ref_meuse1'", idu(insee_code) txtu(lold_name) diagnose time override sim(token) threshold(0.3) weights(root)
collapse (first) lCommunes_1969_meuse lold_name uid, by(insee_code)
merge 1:1 uid using "`ref_meuse'", nogen
sort lCommunes
drop if uid==174 // resolving issue about bar-le-duc aggregated
replace lCommunes = "bar-le-duc" if uid==176
replace insee_code = 55029 if uid==176
gen ID_2 = 55
save "processed data\referendum1969_meuse.dta", replace
***************************************************************************
* Meurthe-et-Moselle
tempfile ref_meumo //create tempfile
import excel "Referendum1969_Meurthe-et-Moselle.xls", firstrow clear //import vote data
qui for var *: rename X X_1969_meumo //append names with identifiers
drop if Arrondissementde_1969_meumo == "Nancy-Ville"
gen lCommunes_1969_meumo = lower(Communes_1969_meumo)
gen lCantonde_1969_meumo = lower(Cantonde_1969_meumo)
egen cantid_1969_meumo = group(lCantonde_1969_meumo)
gen uid = _n
save "`ref_meumo'", replace
***************************************************************************
tempfile ref_meumo2
import excel "historiq2018_lorrain.xls", firstrow clear //import communal change data
* some transoformations to obtain unique insee_codes and possible name changes
destring DEP, force replace
drop if DEP==.
keep DEP AR CT COM NCCOFF NCCANC LEG
gen year = substr(LEG,-4,.)
destring year, replace
drop if year<1969 // only years after 1969 are relevant
drop if year > 2006 // our data is from 2005 so changes after 2006 should not appear in our sample
keep if DEP == 54 | DEP == 55 | DEP == 57
gen insee_code = 1000*DEP + COM
sort insee_code year
collapse (last) NCCANC, by(insee_code)
drop if NCCANC == ""
save "`ref_meumo2'"
***************************************************************************
tempfile ref_meumo1
use "processed data\AlsaceLorraine$savenum.dta", clear
keep if ID_2 == 54
keep mun_name dep_name reg_name ID_5 ID_3 ID_canton insee_code dep_num_old dep_name_old
merge 1:1 insee_code using "`ref_meumo2'", nogen keep(1 3) //checked! this is fine
gen lmun_name = lower(mun_name)
replace NCCANC = ustrto(ustrnormalize(NCCANC, "nfd"), "ascii", 2)  //handling nasty accents
gen lold_name = lower(NCCANC)
replace lold_name = lmun_name if lold_name == "" 
save "`ref_meumo1'" // from here you can get a complete list of the names
***************************************************************************
use "`ref_meumo'", clear
matchit uid lCommunes_1969_meumo using "`ref_meumo1'", idu(insee_code) txtu(lold_name) diagnose time override sim(token) threshold(0.3) weights(root)
collapse (first) lCommunes_1969_meumo lold_name uid, by(insee_code)
merge 1:1 uid using "`ref_meumo'", nogen
sort lCommunes_1969_meumo
gen ID_2 = 54
save "processed data\referendum1969_meumo.dta", replace
***************************************************************************
*Moselle
tempfile ref_mos //create tempfile
import excel "Referendum1969_Moselle.xls",  clear firstrow
ren Communede Communes
keep Arrondissementde Cantonde Commu Inscrits Votants Exprimes Oui Non
qui for var *: rename X X_1969_mos //append names with identifiers
gen lCommunes_1969_mos = lower(Commu)
gen lCantonde_1969_mos = lower(Cantonde_1969_mos)
egen cantid_1969_mos = group(lCantonde_1969_mos)
gen uid = _n
drop if lCommunes_1969_mos == "totaux"
save "`ref_mos'", replace
***************************************************************************
tempfile ref_mos2
import excel "historiq2018_lorrain.xls", firstrow clear //import communal change data
* some transoformations to obtain unique insee_codes and possible name changes
destring DEP, force replace
drop if DEP==.
keep DEP AR CT COM NCCOFF NCCANC LEG
gen year = substr(LEG,-4,.)
destring year, replace
drop if year<1969 // only years after 1969 are relevant
drop if year > 2006 // our data is from 2005 so changes after 2006 should not appear in our sample
keep if DEP == 54 | DEP == 55 | DEP == 57
gen insee_code = 1000*DEP + COM
sort insee_code year
collapse (last) NCCANC, by(insee_code)
drop if NCCANC == ""
save "`ref_mos2'"
***************************************************************************
tempfile ref_mos1
use "processed data\AlsaceLorraine$savenum.dta", clear
keep if ID_2 == 57
keep mun_name dep_name reg_name ID_5 ID_3 ID_canton insee_code dep_num_old dep_name_old
merge 1:1 insee_code using "`ref_mos2'", nogen keep(1 3) //checked! this is fine
gen lmun_name = lower(mun_name)
replace NCCANC = ustrto(ustrnormalize(NCCANC, "nfd"), "ascii", 2)  //handling nasty accents
gen lold_name = lower(NCCANC)
replace lold_name = lmun_name if lold_name == "" 
save "`ref_mos1'" // from here you can get a complete list of the names
***************************************************************************
use "`ref_mos'", clear
matchit uid lCommunes_1969_mos using "`ref_mos1'", idu(insee_code) txtu(lold_name) diagnose time override sim(token) threshold(0.5) weights(root)
collapse (first) lCommunes_1969_mos lold_name uid, by(insee_code)
merge 1:1 uid using "`ref_mos'", nogen
sort lCommunes_1969_mos
gen ID_2 = 57
save "processed data\referendum1969_mos.dta", replace
***************************************************************************
* getting together all three voting results (append)
append using "processed data\referendum1969_meumo.dta" "processed data\referendum1969_meuse.dta"
gen communes_1969 = Communes_1969_meuse
replace communes_1969 = Communes_1969_meumo if communes_1969 ==""
replace communes_1969 = Communes_1969_mos if communes_1969 ==""
gen lcommunes_1969 = lCommunes_1969_meuse
replace lcommunes_1969 = lCommunes_1969_meumo if lcommunes_1969 ==""
replace lcommunes_1969 = lCommunes_1969_mos if lcommunes_1969 ==""
gen inscrits_1969 = Inscrits_1969_mos
replace inscrits_1969 = Inscrits_1969_meuse if inscrits_1969==.
replace inscrits_1969 = Inscrits_1969_meumo if inscrits_1969==.
gen votants_1969 = Votants_1969_mos
replace votants_1969 = Votants_1969_meuse if votants_1969==.
replace votants_1969 = Votants_1969_meumo if votants_1969==.
gen exprimes_1969 = Exprimes_1969_mos
replace exprimes_1969 = Suffrexpr_1969_meuse if exprimes_1969==.
replace exprimes_1969 = Suffrexpr_1969_meumo if exprimes_1969==.
gen oui_1969 = Oui_1969_mos
replace oui_1969 = Oui_1969_meuse if oui_1969 ==.
replace oui_1969 = Oui_1969_meumo if oui_1969 ==.
gen non_1969 = Non_1969_mos
replace  non_1969 = Non_1969_meuse if non_1969==.
replace non_1969 = Non_1969_meumo if non_1969 ==.
keep insee_code ID_2 communes_1969 lcommunes_1969 inscrits_1969 votants_1969 exprimes_1969 oui_1969 non_1969 
drop if lcommunes_1969 == "forbach" | lcommunes_1969 == "rupt" 
drop if oui_1969 ==. & non_1969==.
drop if oui_1969 ==0 & non_1969==0
collapse (mean) oui_1969 non_1969 inscrits votants exprimes (first) communes ID_2 insee_code, by(lcommunes)
save "processed data\referendum1969.dta", replace
***************************************************************************
* getting insee codes to the appended file by merging with the manually created files using lCommunes_1969 as a key
* merging the referendum data to the naster
local filename "matching2018_06_08.xls"  //enter file name
local departs "Meuse Meumo Moselle"
foreach dep in `departs'{
	tempfile m_`dep'
	import excel `filename', firstrow clear sheet("`dep'")
	drop if insee_code ==. 
	ren *_1969_* *1969
	gen ID_2=99
	if "`dep'" == "Meumo"{
		replace ID_2 =54
		di "`dep' 54" 
	}
	else if "`dep'" == "Meuse"{
		replace ID_2 =55 
		di "`dep' 55"
	}
	else if "`dep'" == "Moselle"{
		replace ID_2 =57
		di "`dep' 57"
	}
	save "`m_`dep''", replace
}
***************************************************************************
tempfile appended
append using "`m_Meumo'" "`m_Meuse'"
ren lCommunes1969 lcommunes_1969
keep insee_code lcommunes_1969 ID_2
drop if lcommunes_1969==""
collapse (first) insee_code ID_2, by(lcommunes_1969)
merge 1:1 lcommunes_1969 ID_2 using "processed data\referendum1969.dta", nogen keep(3)
replace insee_code = 55114 if lcommunes_1969=="chronville"
drop if insee_code==55160 & lcommunes_1969=="saulx"
replace insee_code=57542 if lcommunes_1969=="saint-bernard"
collapse (sum) oui_1969 non_1969 inscrits_1969 votants_1969 exprimes_1969 (first) communes_1969, by(insee_code)
drop if insee_code == 67002
save "`appended'", replace
// there are around 250 using only and 30 master only this is due to 250 communes 
// being listet in the papers but are not in the master, 30 communes from the master
// cannot be assigned to a commune mentioned in the papers
***************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge 1:1 insee_code using "`appended'", nogen keep(1 3)
gen oui_perv1969 = oui_1969/ votants_1969
gen oui_perex1969 = oui_1969/ exprimes_1969
gen non_perex1969 = non_1969/ exprimes_1969
gen non_perv1969 = non_1969/ votants_1969
gen percval969 = exprimes_1969/ votants_1969
lab var percval969 "Share of valid votes in votes cast"
gen tournout69= votants_1969/ inscrits_1969
lab var tournout69 "votes / eligible voters"
save "processed data\AlsaceLorraine$savenum.dta", replace
***************************************************************************
import excel "ref69_d_final.xls", firstrow clear
save "processed data\ref69.dta", replace
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge 1:1 insee_code using "processed data\ref69.dta", nogen
lab var oui_1969 "Number of 'oui' votes 1969" 
lab var non_1969 "Number of 'non' votes 1969"
lab var inscrits_1969 "Number of eligible voters"
lab var votants_1969 "Number of total voters/votes cast"
lab var exprimes_1969 "Number valid votes"
lab var oui_perv1969  "Share of 'oui' in total votes 1969"
lab var oui_perex1969 "Share of 'oui' in valid votes 1969"
lab var non_perex1969 "Share of 'non' in valid votes 1969"
lab var non_perv1969 "Share of 'non' in total votes 1969"
lab var percval69 "Share of valid votes in total votes 1969"
lab var tournout69 "Tournout // total votes by eligible voters 1969"
gen oui_share69 = 100* oui_1969/ votants_1969
label var oui_share69 "Share of 'oui' in total votes 1969"
save "processed data\AlsaceLorraine$savenum.dta", replace
************************population density, obtained from authors *********
import excel "cleaned_mun_pop_density.xls", firstrow clear
ren FRA_adm5Shape_Area mun_area
sort insee_code
quietly by insee_code:  gen dup = cond(_N==1,0,_n) 
drop if dup > 1
drop dup
save "processed data\cleaned_mun_pop_density.dta", replace
***************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
merge m:1 insee_code using "processed data\cleaned_mun_pop_density.dta", nogen
destring p1806 p1831 p1836 p1846 p1856 p1866 p1876 p1886 p1896 p1906 p1911 p1926 p1936 p1946 p1954 p1975 p1962 p1982 p1990 p1999, replace force
replace mun_area = mun_area/1000000
gen popdens_1866 = p1866/mun_area
label variable p1866 "Municipal Population 1866"
label variable popdens_1866 "Municipal Population Density 1866 (per km2)"
drop p1806 p1831 p1836 p1846 p1856 p1876 p1886 p1896 p1906 p1911 p1926 p1936 p1946 p1954 p1975 p1962 p1982 p1990 p1999
save "processed data\AlsaceLorraine$savenum.dta", replace
***************************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
global savenum=$savenum+1
sort insee_code
quietly by insee_code:  gen dup = cond(_N==1,0,_n)
drop if dup >1
drop dup
save "processed data\AlsaceLorraine$savenum.dta", replace
***************************************************************************
import excel "Dep_Closeness_to_Border.xls", firstrow clear
drop dep_name
save "processed data\dep_closesness_to_border.dta", replace
***************************************************************************
import excel "border_departments_distance.xls",clear firstrow
drop if TYPE_5 == "Water body" | TYPE_5 == "Water Body"
keep NEAR_DIST ID_5 ID_2
ren NEAR_DIST distance_robust_border
gen insee_code = ID_2*1000+ID_5
drop ID_5 ID_2
sort insee_code
quietly by insee_code:  gen dup = cond(_N==1,0,_n)
drop if dup >0
drop dup
save "processed data\border_departments_distance_alternative_border.dta", replace
***********************From ArcGIS ************************************
import excel "distance_national_border.xls",clear firstrow
drop if TYPE_5 == "Water body" | TYPE_5 == "Water Body"
keep NEAR_DIST ID_5 ID_2
ren NEAR_DIST distance_national_border
gen insee_code = ID_2*1000+ID_5
sort insee_code
quietly by insee_code:  gen dup = cond(_N==1,0,_n)
drop if dup >0
drop dup
drop ID_5 ID_2
merge 1:1 insee_code using "processed data\border_departments_distance_alternative_border.dta", nogen // -> all matched because based on same dataset
merge 1:1 insee_code using "processed data\AlsaceLorraine$savenum.dta", nogen // -> not all matched because "master" only has information for border and adjacent departments -> check one master_only = 1
global savenum=$savenum+1
merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta", nogen // -> all matched because "using" has information for all Departments
gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1
gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1
label variable sui_brl "Raster average: FAO GAEZ soil suitability: barley, immediate input, rain-fed"
label variable sui_mze "Raster average: FAO GAEZ soil suitability: maize, immediate input, rain-fed"
label variable sui_oni "Raster average: FAO GAEZ soil suitability: onion, immediate input, rain-fed"
label variable sui_rsd 
label variable sui_sfl "Raster average: FAO GAEZ soil suitability: sunflower, immediate input, rain-fed"
label variable sui_whe "Raster average: FAO GAEZ soil suitability: wheat, immediate input, rain-fed"
label variable sui_wpo "Raster average: FAO GAEZ soil suitability: white potato, immediate input, rain-fed"
label variable er_elev "Raster average: Elevation"
label variable er_rug "Raster average: Nunn & Puga Ruggedness Index"
label variable st_dev_elev "Raster average: Standard Deviation Elevation"
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "AL_road_length.xls", firstrow clear
save "AL_road_length.dta", replace
***************************************************
use "AL_road_length.dta",  clear
merge 1:1 insee_code using "processed data\AlsaceLorraine$savenum.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "AL_rivers_length.xls", firstrow clear
save "AL_rivers_length.dta", replace
***************************************************
merge 1:1 insee_code using "processed data\AlsaceLorraine$savenum.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "distance_hist_road.xls", firstrow clear
save "distance_hist_road.dta", replace
***************************************************
merge 1:1 insee_code using "processed data\AlsaceLorraine$savenum.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "dist_river.xls", firstrow clear
save "dist_river.dta", replace
***************************************************
merge 1:1 insee_code using "processed data\AlsaceLorraine$savenum.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "cropland.xls", firstrow clear
save "cropland.dta", replace
import excel "grazing.xls", firstrow clear
save "grazing.dta", replace
import excel "Urban Population.xls", firstrow clear
save "Urban Population.dta", replace
import excel "Total Population.xls", firstrow clear
save "Total Population.dta", replace
import excel "Rural Population.xls", firstrow clear
save "Rural Population.dta", replace
***********************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear

merge 1:1 insee_code using "cropland.dta", nogen 
gen rel_LU_cropland_1860 = LU_cropland_1860/area

merge 1:1 insee_code using "grazing.dta", nogen 
gen rel_LU_grazing_1860 = LU_grazing_1860/area

merge 1:1 insee_code using "Urban Population.dta", nogen 
gen rel_urb_pop_1860 = urb_pop_1860/area

merge 1:1 insee_code using "Total Population.dta", nogen 
gen rel_tot_pop_1860 = tot_pop_1860/area

merge 1:1 insee_code using "Rural Population.dta", nogen 
gen rel_rur_pop_1860 = rur_pop_1860/area

global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "segment_FE_lorraine.xls", firstrow clear
save "segment_FE_lorraine.dta", replace
***************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
merge 1:1 insee_code using "segment_FE_lorraine.dta", nogen 
drop lorraine_close_mid lorraine_close_north lorraine_close_south
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "AL_railway.xls", firstrow clear
save "AL_railway.dta", replace
***************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
merge 1:1 insee_code using "AL_railway.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "AL_adm5_closest_treat_border_segment.xls", firstrow clear
save "AL_adm5_closest_treat_border_segment.dta", replace
***************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
merge 1:1 insee_code using "AL_adm5_closest_treat_border_segment.dta", nogen 
merge 1:1 insee_code using "processed data\Is_maginot_Lorraine_Alsace.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "distance_mulhouse.xls", firstrow clear
order insee_code, first
duplicates tag insee_code, generate(dup)
drop if dup > 0
drop dup
save "distance_mulhouse.dta", replace
***********************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
merge 1:1 insee_code using "distance_mulhouse.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace
***********************From ArcGIS ************************************
import excel "distance_paris.xls", firstrow clear
order insee_code, first
duplicates tag insee_code, generate(dup)
drop if dup > 0
drop dup
save "distance_paris.dta", replace
*******************************************************************
use "processed data\AlsaceLorraine$savenum.dta", clear
merge 1:1 insee_code using "distance_paris.dta", nogen 
global savenum=$savenum+1
save "processed data\AlsaceLorraine$savenum.dta", replace

********************************************************************************
//varlist for subsetting
qui ds `varlist_all', not
local varlist_insee = r(varlist)
local varlist_all = "`varlist_all' `varlist_insee'"
********************************************************************************
************* PART 3: Data subsetting
********************************************************************************
cap gen code_dept = floor(insee_code/1000)
//we can clear the stuff we have so far, that just clutters up the directory
//local files_delete: dir "processed data" files "*.dta"
local subsets = "mun_geo elections crime insee all"
local nsubsets: word count `subsets'
qui forvalues i = 1/`nsubsets'{
	
	local subset: word `i' of `subsets'
	
	preserve
	
	keep `varlist_identifiers' `varlist_`subset''
	
	if "`subset'"=="all"{
// keep only variables that are used 

		save "processed data\AlsaceLorraine", replace
	
	}
	
	else{
	
		save "processed data\AlsaceLorraine_subset_`subset'", replace
	
	}
	restore
	
	macro drop subset
}

macro drop savenum
capture log close

local i=1
while `i'<100 {

        cap rm "processed data/AlsaceLorraine`i'.dta"
		local i= `i' + 1
}
//findit done
use "processed data/AlsaceLorraine.dta", clear
cap gen code_dept = floor(insee_code/1000)
keep insee_code mun_name pop_area dep_name is_fra is_aslr P11_POP dist_b_ASLR_FRA distance_robust_border ///
distance_maginot ra_wheat_int_rf_resample sui_wpo sui_brl p1866 is_as is_lr ///
is_med_aslr row_dum dist_b_LANGUAGE francophone dist_b_MED_ASLR_FRA FE_moselle ///
FE_meurthe dist_old_border dist_c_METZ dist_c_STRASBOURG dist_c_BRUSSELS dist_b_LUX_FRA ///
dist_c_NANCY dist_b_ASLR_DEU distance_national_border P06_POP0014 P06_POP P06_POP1529 ///
P06_POP3044 P06_POP4559 P06_POP6074 P06_POP7589 P06_POP90P P99_POP1517 P99_POP1824 ///
P99_POP2529 P99_POP30P P99_NSCOL15P_BAC P99_NSCOL15P_DIPL0 P99_SCOL1824 P99_SCOL2529 ///
P99_SCOL30P C06_POP15P C06_POP15P_CS6 C06_POP15P_CS1 C06_POP15P_CS2 C06_POP15P_CS3 C06_POP15P_CS4 ///
C06_POP15P_CS5 C11_POP15P ENNTOT11 ETNBE11 ETNCFZ11 ETNGU11 ///
NB_F111_NB_AIREJEU NB_F107_NB_AIREJEU NB_F101_NB_AIREJEU NB_D101 NB_D102 NB_D103 ///
NB_D104 NB_A206 NB_A112 NB_A116 NB_C302 NB_C303 NB_C301 NB_C104 point_x_meters ///
point_y_meters r92_yf r05_yf p07a_c10fvotes RFMQ208 RFMMO08 RFMGI08 er_rug sui_wpo ///
sui_whe ra_wheat_int_rf_resample P11_POP01P sui_brl er_elev st_dev_elev NB_D601 ///
NB_D603 NB_B204 NB_B206 NB_B312 NB_C101 avgABO_ph out_wedlock90 out_wedlock99 ///
single_parents90 single_parents99 insee_code mun_name ID_1 ID_2 ID_3 ID_4 ID_5 ///
ID_canton  ra_elevation_raster rstd_elevation_raster ///
Other_tweet France_tweet Germany_tweet Population_1916 Population_1926 Population_1936 ///
Population_1946 nrpointofsale avgABO avgVNOABO reg15VotIns reg15VoixInsLREG reg15VoixExpLREG ///
close_mid close_south close_north oui_1969 non_1969 inscrits_1969 votants_1969 exprimes_1969 ///
communes_1969 row_dum row_dum2 p1866 popdens_1866 lorr_seg_north lorr_seg_middle ///
lorr_seg_south road_length river_length LU_grazing_1860 LU_cropland_1860 gare_1860 ///
hie_1860 catholic_dummy churches_number maginot_right distance_maginot cr_burglary ///
cr_gta cr_property_damage m83a_idx m83b_idx m89a_idx m89b_idx m95a_idx m95b_idx ///
m01a_idx m01b_idx m08a_idx m08b_idx m95a_regshare m95b_regshare m01a_regshare ///
m01b_regshare m08a_regshare m08b_regshare OBJECTID zip_code zip_code_alt ///
reg_name code_dept m95a_* m83a_* m89a_* m01a_* ENNOQ11 NB_F302_NB_SALLES r92_abs ///
r05_abs r92_reg r05_reg pop_area
save "processed data/AlsaceLorraine.dta", replace
*/
********************************************************************************
***************** GENERATE DEPARTEMENT BORDERS DATASET   ***********************
***********************From ArcGIS ************************************
********************************************************************************
use "processed data/AlsaceLorraine.dta", clear
gen code_dept = floor(insee_code/1000)
encode reg_name, gen(reg_id)
collapse reg_id, by(code_dept)
gen reg_id_adj = reg_id
gen code_dept_adjacent = code_dept
save "processed data/dep_reg_map.dta", replace

use "processed data\border_pair_distance_final.dta", clear
drop if  pair==7592 | pair==7593  | pair==7594  | pair==8384
merge m:1 insee_code using "processed data\AlsaceLorraine.dta", nogen
merge m:1 code_dept using "processed data\dep_reg_map.dta", nogen keepusing(reg_id)
merge m:1 code_dept_adjacent using "processed data\dep_reg_map.dta", nogen keepusing(reg_id_adj)
keep index insee_com code_dept code_dept_adjacent pair distance_pair treat_dep insee_code r92* r05* reg_id reg_id_adj ID_* OBJECTID reg_name point_x_meters point_y_meters
save "processed data\border_pair_distance_final_merged.dta", replace
********************************************************************************
***************** GENERATE MUNICIPALITY ELECTIONS  DATASET  ********************
********************************************************************************
use "processed data\AlsaceLorraine.dta", replace
keep if m83a_1 !=. & m89a_1!=. & m95a_2 !=. & m01a_1!=.
local years_mun 83 89 95 01
foreach y of local years_mun{
	gen mun_far_l_share19`y' = m`y'a_1/ (m`y'a_1 + m`y'a_2 + m`y'a_3 + m`y'a_4 + m`y'a_5)
	gen mun_far_r_share19`y' = m`y'a_5/ (m`y'a_1 + m`y'a_2 + m`y'a_3 + m`y'a_4 + m`y'a_5)
	gen mun_right_share19`y' = (m`y'a_4+m`y'a_5)/ (m`y'a_1 + m`y'a_2 + m`y'a_3 + m`y'a_4 + m`y'a_5)
	gen mun_left_share19`y' = (m`y'a_1+m`y'a_2)/ (m`y'a_1 + m`y'a_2 + m`y'a_3 + m`y'a_4 + m`y'a_5)
	gen mun_idx19`y' = m`y'a_idx 
}

rename *1901 *2001

reshape long mun_far_l_share mun_far_r_share mun_right_share mun_left_share mun_idx, i(insee_code) j(year)  

save "processed data\reshaped_AlsaceLorraine_municipal_elections.dta", replace

*******************************************Sub-Analysis Departmental level********************************
use "processed data\AlsaceLorraine.dta",clear
cap drop _merge

ren  ID_2 department
keep department r92_yf r05_yf

collapse (mean)   r92_yf r05_yf, by(department)
saveold "processed data\AL_dep.dta", replace

*"Vosges"  "Moselle" "Meuse" "Meurthe-et-Moselle" "Haut-Rhin" "Bas-Rhin"  "Belfort (Territoire)"
**********************************************************************
************Surveys on national identity 2003
****************************************************************************************************************************
use "National Identity II - ISSP 2003.dta", clear
keep if C_ALPHAN=="FR"
drop C_ALPHAN COUNTRY
gen year =2003
drop v1 V2
order fr_reg, before(v4)
ren V3 count
ren fr_reg department
ren fr_size size_community
drop *_reg *_size *_prty

									
local varlist v7 v8 v9 v10
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
label define LabX`var' 1 "Not close at all" 2 "Not very close" 3 "Close" 4 "Very close" .c "Cant choose" .n "Na",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}

local varlist v11 v12 v13 v14 v15 v16 v17 v18
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
label define LabX`var' 1 "Not important at all" 2 "Not very important" 3 "Fairly important" 4 "Very important" .c "Cant choose" .a "Na",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}

local varlist v26 v27 v28 v29 v30 v31 v32 v33 v34 v35 v63
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
label define LabX`var' 1 "Not proud at all" 2 "Not very proud" 3 "Somehow proud" 4 "Very proud" .c "Cant choose" .a "Na" .n "NA",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}
*One nation vs separate
replace v66=5 if v66==2
replace v66=6 if v66==1
replace v66=v66-4
label define One 1 "Become separate" 2 "Stay united", modify
label values v66 One

*Help minorities to preserve traditions
clonevar Xv49=v49
replace Xv49=1 if v49==2
replace Xv49=2 if v49==1
drop v49
ren Xv49 v49
label define two 1 " Adapt into larger society" 2 "Maintain traditions", modify
label values v49 two
label var v49 "Government should help minorities to maintain traditions"

*Referedum for EU
replace v74=v74+10
replace v74=1 if v74==12
replace v74=2 if v74==11
replace v74 =. if v74 ==.a | v74==.c
label define One 1 "Vote against" 2 "Vote to stay", modify
label values v74 One

*Heard or read about EU
local varlist v69 
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace `var'=. if `var'==6 |`var'==7
label define LabX`var' 1 "Disagree strongly" 2 "Disagree" 3 "Agree" 4 "Strongly agree"  .c "Cant choose" .a "Na" .n "NA",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}
label var v69  "I heard or read a lot about the EU"

*national vs regional
local varlist v68
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==5
replace X`var'=2 if `var'==4
replace X`var'=3 if `var'==3
replace X`var'=4 if `var'==2
replace X`var'=5 if `var'==1
replace `var'=. if `var'==6 |`var'==7
label define LabX`var' 1 "Only national" 2 "More national" 3 "As regional as national" 4 "More regional" 5 "Only regional" .c "Cant choose" .a "Na" .n "NA",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
replace `var'=. if `var'==6 |`var'==7
}
*EU more power than government
local varlist v72
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==5
replace X`var'=2 if `var'==4
replace X`var'=3 if `var'==3
replace X`var'=4 if `var'==2
replace X`var'=5 if `var'==1
replace `var'=. if `var'==6 |`var'==7
label define LabX`var' 1 "Much less" 2 "Less" 3 "As regional as national" 4 "More " 5 "Much more" .c "Cant choose" .a "Na" .n "NA",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}
*Rather French than any other nationality, benfit from EU, follow EU decisions
local varlist v19 v23 v70_1 v71 v43 v44 v47 v48 v47 v50 v44 v22 v54
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==5
replace X`var'=2 if `var'==4
replace X`var'=3 if `var'==3
replace X`var'=4 if `var'==2
replace X`var'=5 if `var'==1
replace `var'=. if `var'==6 |`var'==7
label define LabX`var' 1 "Disagree strongly" 2 "Disagree" 3 "Neutral" 4 "Agree" 5 "Strongly agree" .c "Cant choose" .a "Na" .n "NA",modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}

*******Important variables on whether subject would vote to stay in EU
replace v74=0 if v74==1
replace v74=1 if v74==2
label define Labv74 0 "Leave" 1 "Stay" ,modify
label values v74 Labv74

*Variables that need adjustment for survey regressions
replace union =0 if union ==2 | union ==.n |union==.a
replace sex=0 if sex==2

**Attend religious service variable:
replace attend = 2 if attend ==3
replace attend = 3 if attend ==4
replace attend = 4 if attend ==5
replace attend = 5 if attend ==7
replace attend = 6 if attend ==8
clonevar Xattend=attend
label define LabXattend 1 "Weekly" 2  "2 or 3 times a month" 3 "Once a month" ///
						4  "Sev times a year" 5 "Less frequently"  6 "Never" ,modify
label values Xattend LabXattend
drop attend
ren Xattend attend

tab attend, gen(D_attend)

*Religous groups
tab religgrp, gen(Relig)

order year, after (department)
merge m:1 department using "processed data\AL_dep.dta",keep(1 3) nogen
save "processed data\natidentity2003.dta", replace
*********************************************************************************************
***************************************************************************************
***************************At department level***************************************************
use "processed data\natidentity2003.dta", clear
drop weight
bys department: egen weight=count(attend)


foreach v of var r92_yf v43 v44   r05_yf D_attend* Relig1  Relig2 Relig3 Relig4 Relig5 Relig6 Relig7  ///
sex age educyrs   degree  urbrural attend union income rincome hompop {
local l`v' : variable label `v'
     if `"`l`v''"' == "" {
	local l`v' "`v'"
	}
	}						 

collapse (mean) r92_yf v43 v44   r05_yf D_attend* Relig1  Relig2 Relig3 Relig4 Relig5 Relig6 Relig7  ///
sex age educyrs   degree  urbrural attend union income rincome hompop , by(department)

foreach v of var r92_yf v43 v44   r05_yf D_attend* Relig1  Relig2 Relig3 Relig4 Relig5 Relig6 Relig7  ///
sex age educyrs   degree  urbrural attend union income rincome hompop {
label var `v' "`l`v''"
}

forvalue i=1(1)6 {
replace D_attend`i'=D_attend`i'*100
}
forvalue i=1(1)7 {
replace Relig`i'=Relig`i'*100
}

label var attend "Attendance: Average"
label var D_attend1 "Attendance: Weekly"
label var D_attend2 "Attendance: 2-3 times a month"
label var D_attend3 "Attendance: Once a month"
label var D_attend4 "Attendance: Sev. times a year"
label var D_attend5 "Attendance: Attendance: Less freq."
label var D_attend5 "Attendance: Never"
**************
label var Relig1 "No religion"
label var Relig2 "Roman Catholic"
label var Relig3 "Protestant"
label var Relig4 "Christian Ortodox"
label var Relig5 "Jewish"
label var Relig6 "Moslem"
label var Relig7 "Other religion"
save "processed data\natidentity2003_dep.dta", replace

***************************ENQUETES REGIONALES 1999*************Questionnaire**************LE BAROMETRE DU FAIT REGIONAL*********************************
*******************************************************More observations per department*****************************************************************
usespss "fr_cdsp_ddi_oip_1999_F1.sav",clear
label var age5 "Age in 5 classes"
label var agglo5 "Size of home town in 5 classes"
ren rs1 age
label var age "Age in years"
replace rs2=0 if rs2==2
ren rs2 gender
label define genderX 1 "male" 0 "female"
label values   gender genderX

gen diplome = rs13
replace diplome=0 if diplome == 9 | diplome == .b | diplome == .a
replace diplome=1 if diplome == 2
replace diplome = 2 if diplome == 3 | diplome == 4 | diplome == 5 | diplome == 6 
replace diplome = 3 if diplome == 7 | diplome == 8
label define diplomeX 0 "Dont know" 1 "Lower than High School" 2 "High School or Equal" 3 "Higher than High School" 
label values diplome diplomeX

ren rs5 employmentstatus
replace employmentstatus=0 if employmentstatus==6 |employmentstatus==.a |employmentstatus==.b
label define employmentstatusX 0 "Dont know or no answer" 1 "Self-employed" 2 "Employer" 3 "Receives private salary" 4 "Public service" 5 "Public Enterprise employee" 
label values   employmentstatus employmentstatusX

ren dipl degree
replace degree=0 if degree==.b

***************Recode variables

gen opinion_counseil1 = q9
replace opinion_counseil1 = -1 if q9 == 2
replace opinion_counseil1 = 0 if q9 == .b & q8 == 2
replace opinion_counseil1 = . if opinion_counseil1 == 3 | opinion_counseil1 == .a | opinion_counseil1 == .b
label define project3 1 "good project" 0 "no project" -1 "bad project"
label values  opinion_counseil1 project3


replace q8 = . if q8 == 3  | q8 == .a
replace q8 = 3-q8-1
label define project1 1 "yes" 0 "no"
label values  q8 project1

replace q9 = . if q9 == 3  | q9 == .a | q9 == .b
replace q9 = 3-q9-1
label define project2 1 "good direction" 0 "bad direction"
label values  q9 project2
ren q9 opinion_counseil

gen Optm_region = q12a2 
replace Optm_region = . if q12a2 == 5 | q12a2 == .a
replace Optm_region = 5 - Optm_region

gen Optm_france = q12a3 
replace Optm_france = . if q12a3 == 5 | q12a3 == .a
replace Optm_france = 5 - Optm_france

local varlist q21a1 q21a2 q21a3 q21a4
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==3
replace X`var'=2 if `var'==2
replace X`var'=3 if `var'==1
replace X`var'=. if `var'==4
label define LabX`var' 1 "Very much" 2 "To some degree"  3 "No"  ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 
ren q21a1 Assoc_humani
label var Assoc_humani "I am active in an Association concerned with humanitarian aid"
ren q21a2 Assoc_envir
label var Assoc_envir "I am active in an Association concerned with environmental aid"
ren q21a3 Assoc_consum
label var Assoc_consum "I am active in an Association concerned with consumer protection"
ren q21a4 Assoc_region
label var Assoc_region "I am active in an Association concerned with Regionalism"


local varlist q6 q5 q13
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace X`var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 

ren q6 DemoRegion
label var DemoRegion "Democracy works well within the region"
ren q5 DemoFrance
label var DemoFrance "Democracy works well within France"
*Information availability and information
ren q13 SatisfactionInformation
label  var SatisfactionInformation "The quality of information on regional policies is higher"


local varlist q3a1 q3a2 q3a3 q3a4 q3a5
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace X`var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 
rename q3a1 attachement_europe
label variable attachement_europe "My identity is attached to Europe"

rename q3a2 attachement_france
label variable attachement_france "My identity is attached to France"

rename q3a3 attachement_region
label variable attachement_region "My identity is attached my region"

rename q3a4 attachement_department
label variable attachement_department "My identity is attached to my department"

rename q3a5 attachement_municipality
label variable attachement_municipality "My identity is attached to my municipality"

save "processed data\oip1999_temp.dta",replace
***************************************************
clear
unicode analyze *
unicode encoding set ISO-8859-1
unicode translate *	
use "processed data\oip1999_temp.dta",clear
save  "processed data\oip1999.dta", replace
***************************ENQUETES REGIONALES 2001*************Questionnaire**************LE BAROMETRE DU FAIT REGIONAL*********************************
usespss "fr_cdsp_ddi_oip_2001_F1.sav",clear

label var age5 "Age in 5 classes"
label var agglo5 "Size of home town in 5 classes"
ren rs1 age
label var age "Age in years"
replace rs2=0 if rs2==2
ren rs2 gender
label define genderX 1 "male" 0 "female"
label values   gender genderX

gen diplome = rs13
replace diplome=0 if diplome == 9 | diplome == .b
replace diplome=1 if diplome == 2
replace diplome = 2 if diplome == 3 | diplome == 4 | diplome == 5 | diplome == 6 
replace diplome = 3 if diplome == 7 | diplome == 8
label define diplomeX 0 "Dont know" 1 "Lower than High School" 2 "High School or Equal" 3 "Higher than High School" 
label values diplome diplomeX

ren rs5 employmentstatus
replace employmentstatus=0 if employmentstatus==6 |employmentstatus==.a |employmentstatus==.b
label define employmentstatusX 0 "Dont know or no answer" 1 "Self-employed" 2 "Employer" 3 "Receives private salary" 4 "Public service" 5 "Public Enterprise employee" 
label values   employmentstatus employmentstatusX

ren dipl degree
replace degree=0 if degree==.b

gen opinion_counseil1 = q10
replace opinion_counseil1 = -1 if q10 == 2
replace opinion_counseil1 = 0 if q10 == .b & q9 == 2
replace opinion_counseil1 = . if opinion_counseil1 == 3 | opinion_counseil1 == .a | opinion_counseil1 == .b
label define project3 1 "good project" 0 "no project" -1 "bad project"
label values  opinion_counseil1 project3

replace q10 = . if q10 == 3 | q10 == .b
replace q10 = 3-q10-1
label define project2 1 "good direction" 0 "bad direction"
label values  q10 project2
ren q10 opinion_counseil

local varlist q2a1 q2a2 q2a3 q2a4 q2a5 q5 q14  q18
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace X`var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 
ren q5 DemoRegion
label var DemoRegion "Democracy works well within the region"
ren q4 DemoFrance
label var DemoFrance "Democracy works well within France"
*Information availability and information
ren q14 SatisfactionInformation
label  var SatisfactionInformation "The quality of information on regional policies is good"

***********Transfer of policies to regional council
local varlist q36a1 q36a2 q36a3 q36a4 q36a5 q36a6 q36a7 q36a8 q36a9 q36a10 q35a1 q35a2 q35a3 q35a4 q35a5
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace X`var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 

rename q2a1 attachement_europe
label variable attachement_europe "My identity is attached to Europe"
rename q2a2 attachement_france
label variable attachement_france "My identity is attached to France"
rename q2a3 attachement_region
label variable attachement_region "My identity is attached my region"
rename q2a4 attachement_department
label variable attachement_department "My identity is attached to my department"
rename q2a5 attachement_municipality
label variable attachement_municipality "My identity is attached to my municipality"
save "processed data\oip2001.dta",replace
********************************************************************************
use "processed data\oip2001.dta",clear
append using "processed data\oip1999_temp.dta"
******************************************************************************
rename annee year
cap drop treat_AL
gen treat_AL = .
replace treat_AL=0 if dep == 54 | dep == 55   | dep == 88
replace treat_AL = 1 if dep == 67 | dep == 68 | dep == 57
label var treat_AL "Binary Indicator for AL indicating treatment"
*keep if dep=="Haut-Rhin" |dep=="Bas-Rhin" |dep=="Bas-Rhin" |dep=="Meurthe-et-Moselle"|dep=="Moselle " |dep=="Meuse"
*keep if dep==67 |dep==54 |dep==68 |dep==55 |dep==90|dep==88|dep==57
gen treat_L=.
replace treat_L=1 if dep==57
replace treat_L=0 if dep==54 | dep==55
label var treat_L "Binary Indicator for Lorraine indicating treatment"
gen treat_A=.
replace treat_A=1 if dep==67 | dep==68
replace treat_A=0 if dep == 88
label var treat_A "Binary Indicator for Lorraine indicating treatment"
*****************Generate variables
gen attach_regionVSnation=attachement_region/attachement_france
label var attach_regionVSnation "Regional relative to national attachment"
gen attach_EUVSnation=attachement_europe/attachement_france
label var attach_EUVSnation "European relative to national attachment"
*****************Within Lorraine
egen zattach_regionVSnation_L = std(attach_regionVSnation) if treat_L!=.
label var zattach_regionVSnation_L "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_L = std(attach_EUVSnation) if treat_L!=.
label var zattach_EUVSnation_L "European relative to national attachment, standardized"
*Within Lorraine and  Alsace
egen zattach_regionVSnation_AL = std(attach_regionVSnation) if treat_AL!=.
label var zattach_regionVSnation_AL "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_AL = std(attach_EUVSnation) if treat_AL!=.
label var zattach_EUVSnation_AL "European relative to national attachment, standardized"
*Within  Alsace
egen zattach_regionVSnation_A = std(attach_regionVSnation) if treat_A!=.
label var zattach_regionVSnation_A "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_A = std(attach_EUVSnation) if treat_A!=.
label var zattach_EUVSnation_A "European relative to national attachment, standardized"

***************Generate variables to explain WHO is responsible for difference between treated and untreated
foreach var in attach_regionVSnation attach_EUVSnation {
*Lorraine
bys treat_L: egen M_`var'=mean(`var') //Mean in treated and untreated
bys treat_L: egen MUT_`var'X=mean(`var') if treat_L==0 //Generate average in untreated
egen MUT_`var'=mean(MUT_`var'X) 
cap drop MUT_`var'X
*Alsace and Lorraine
bys treat_AL: egen M_`var'_AL=mean(`var') //Mean in treated and untreated
bys treat_AL: egen MUT_`var'X_AL=mean(`var') if treat_AL==0 //Generate average in untreated
egen MUT_`var'_AL=mean(MUT_`var'X_AL) 
cap drop MUT_`var'X_AL
*Alsace 
bys treat_A: egen M_`var'_A=mean(`var') //Mean in treated and untreated
bys treat_A: egen MUT_`var'X_A=mean(`var') if treat_A==0 //Generate average in untreated
egen MUT_`var'_A=mean(MUT_`var'X_A) 
cap drop MUT_`var'X_A
}
bys dep: sum(attachement_region )
bys dep: sum(attachement_france )
bys dep: sum(attachement_europe )

*Lorraine
gen Reg_RH_treat=.
replace Reg_RH_treat=0 if treat_L==1 & attach_regionVSnation<MUT_attach_regionVSnation
replace Reg_RH_treat=1 if treat_L==1 & attach_regionVSnation>=MUT_attach_regionVSnation
label var Reg_RH_treat "Regional/National relation higher than in untreated Lorraine"
**Lorraine EU
gen EU_RH_treat=.
replace EU_RH_treat=0 if treat_L==1 & attach_EUVSnation<MUT_attach_EUVSnation
replace EU_RH_treat=1 if treat_L==1 & attach_EUVSnation>=MUT_attach_EUVSnation
label var EU_RH_treat "EU/National Relation higher than in untreated Lorraine"

*Alsace and Lorraine
gen Reg_RH_treat_AL=.
replace Reg_RH_treat_AL=0 if treat_AL==1 & attach_regionVSnation<MUT_attach_regionVSnation_AL
replace Reg_RH_treat_AL=1 if treat_AL==1 & attach_regionVSnation>=MUT_attach_regionVSnation_AL
label var Reg_RH_treat_AL "Regional/National relation higher than in untreated Alsace and Lorraine"

gen EU_RH_treat_AL=.
replace EU_RH_treat_AL=0 if treat_AL==1 & attach_EUVSnation<MUT_attach_EUVSnation_AL
replace EU_RH_treat_AL=1 if treat_AL==1 & attach_EUVSnation>=MUT_attach_EUVSnation_AL
label var EU_RH_treat_AL "EU/National Relation higher than in untreated Alsace and Lorraine"

*Alsace 
gen Reg_RH_treat_A=.
replace Reg_RH_treat_A=0 if treat_A==1 & attach_regionVSnation<MUT_attach_regionVSnation_A
replace Reg_RH_treat_A=1 if treat_A==1 & attach_regionVSnation>=MUT_attach_regionVSnation_A
label var Reg_RH_treat_A "Regional/National relation higher than in untreated Alsace"

gen EU_RH_treat_A=.
replace EU_RH_treat_A=0 if treat_A==1 & attach_EUVSnation<MUT_attach_EUVSnation_A
replace EU_RH_treat_A=1 if treat_A==1 & attach_EUVSnation>=MUT_attach_EUVSnation_A
label var EU_RH_treat_A "EU/National Relation higher than in untreated Alsace"

***************Generate variables to explain WHO is responsible for difference between treated and untreated - non standardized
foreach var in attachement_region attachement_france attachement_europe {
*Lorraine
bys treat_L: egen M_`var'=mean(`var') //Mean in treated and untreated
bys treat_L: egen MUT_`var'X=mean(`var') if treat_L==0 //Generate average in untreated
egen MUT_`var'=mean(MUT_`var'X) 
cap drop MUT_`var'X
*Alsace and Lorraine
bys treat_AL: egen M_`var'_AL=mean(`var') //Mean in treated and untreated
bys treat_AL: egen MUT_`var'X_AL=mean(`var') if treat_AL==0 //Generate average in untreated
egen MUT_`var'_AL=mean(MUT_`var'X_AL) 
cap drop MUT_`var'X_AL
*Alsace
bys treat_A: egen M_`var'_A=mean(`var') //Mean in treated and untreated
bys treat_A: egen MUT_`var'X_A=mean(`var') if treat_A==0 //Generate average in untreated
egen MUT_`var'_A=mean(MUT_`var'X_A) 
cap drop MUT_`var'X_A
}

*Lorraine only
gen EU_H_treat=.
replace EU_H_treat=0 if treat_L==1 & attachement_europe<MUT_attachement_europe
replace EU_H_treat=1 if treat_L==1 & attachement_europe>=MUT_attachement_europe
label var EU_H_treat "EU attachment higher than in untreated Lorraine"
*
gen Reg_H_treat=.
replace Reg_H_treat=0 if treat_L==1 & attachement_region<MUT_attachement_region
replace Reg_H_treat=1 if treat_L==1 & attachement_region>=MUT_attachement_region
label var Reg_H_treat "Regional attachment higher than in untreated Lorraine"

*Alsace and Lorraine
gen EU_H_treat_AL=.
replace EU_H_treat_AL=0 if treat_AL==1 & attachement_europe<MUT_attachement_europe_AL
replace EU_H_treat_AL=1 if treat_L==1 & attachement_europe>=MUT_attachement_europe_AL
label var EU_H_treat_AL "EU attachment higher than in untreated Alsace and Lorraine"
*
gen Reg_H_treat_AL=.
replace Reg_H_treat_AL=0 if treat_AL==1 & attachement_region<MUT_attachement_region_AL
replace Reg_H_treat_AL=1 if treat_AL==1 & attachement_region>=MUT_attachement_region_AL
label var Reg_H_treat_AL "Regional attachment higher than in untreated Alsace and Lorraine"

******************************************************************************************************************************************
drop M_attach_regionVSnation  M_attach_EUVSnation M_attach_regionVSnation M_attach_regionVSnation_AL M_attach_EUVSnation M_attach_EUVSnation_AL
***********Transfer of policies to regional council
egen Av_transferOIP2001=rowmean(q36a1 q36a2 q36a3 q36a4 q36a5 q36a6 q36a7 q36a8 q36a9 q36a10)
label var  Av_transferOIP2001 "I am in favor of transfering policy competences to region, arithmetic average across 10 policy areas"
*Second question
egen Av_transfer2OIP2001=rowmean(q35a1 q35a2 q35a3 q35a4 q35a5)
label var  Av_transfer2OIP2001 "I am in favor of allowing more autonomy at the regional level, arithmetic average of 5 questions"

forvalues i=1(1)5 {
gen age_`i'=0
}
replace age_1=1 if age > 59
replace age_2=1 if age> 49& age <=59
replace age_3 =1 if age> 39& age <=49
replace age_4=1 if age> 29& age <=39
replace age_5=1   if age <=29

gen ageC=.
replace ageC=1 if age > 59
replace ageC=2 if age> 49& age <=59
replace ageC =3 if age> 39& age <=49
replace ageC=4 if age> 29& age <=39
replace ageC=5   if age <=29

order dep reginsee year  q19 age ageC gender employmentstatus diplome rs17 treat_L treat_AL attach* zattach_regionVSnation_L zattach_EUVSnation_L Reg_RH_treat EU_RH_treat Reg_H_treat EU_H_treat Av_transferOIP2001 ///
Av_transfer2OIP2001 DemoRegion DemoFrance SatisfactionInformation Assoc_humani Assoc_envir Assoc_consum Assoc_region zattach_regionVSnation_AL zattach_EUVSnation_AL zattach_regionVSnation_A zattach_EUVSnation_A ///
Reg_RH_treat_AL EU_RH_treat_AL EU_H_treat_AL Reg_H_treat_AL , before(catcomm)
save "processed data\oip99_01_temp.dta",replace
*************************************************************************
keep id dep year age gender employmentstatus diplome attachement_europe attachement_france attachement_region attachement_department attachement_municipality treat_L treat_AL
save "processed data\oip1999_attachment.dta",replace
***********************************************************************
***********************************************************************
import excel "Dep_Closeness_to_Border.xls", firstrow clear
save "processed data\dep_closesness_to_border.dta", replace

***********************************************************************
******************************************************************************************************************************************************************
***************************ENQUETES REGIONALES 2003*************Questionnaire**************LE BAROMETRE DU FAIT REGIONAL*********************************
usespss "fr_cdsp_ddi_oip_2003_F1.sav",clear
*Treatment Status
gen treat_AL = .
replace treat_AL=0 if dep == 54 | dep == 55  | dep == 90 | dep == 88
replace treat_AL = 1 if dep == 67 | dep == 68 | dep == 57
label var treat_AL "Binary Indicator for AL indicating treatment"
*keep if dep=="Territoire de Belfort" |dep=="Haut-Rhin" |dep=="Bas-Rhin" |dep=="Bas-Rhin" |dep=="Meurthe-et-Moselle"|dep=="Moselle " |dep=="Meuse"
*keep if dep==67 |dep==54 |dep==68 |dep==55 |dep==90|dep==88|dep==57
gen treat_L=.
replace treat_L=1 if dep==57
replace treat_L=0 if dep==54 | dep==55
label var treat_L "Binary Indicator for Lorraine indicating treatment"

label var age5 "Age in 5 classes"
label var agglo5 "Size of home town in 5 classes"
ren rs1 age
label var age "Age in years"
replace rs2=0 if rs2==2
ren rs2 gender
label define genderX 1 "male" 0 "female"
label values   gender genderX

ren rs5 employmentstatus
replace employmentstatus=0 if employmentstatus==6 |employmentstatus==.a |employmentstatus==.b
label define employmentstatusX 0 "Dont know or no answer" 1 "Self-employed" 2 "Employer" 3 "Receives private salary" 4 "Public service" 5 "Public Enterprise employee" 
label values   employmentstatus employmentstatusX

ren dipl degree
replace degree=0 if degree==.b

clonevar dependence_regional=q8
replace dependence_regional=1 if q8==1
replace dependence_regional=0 if q8!=1

label define regional 1 "regional level" 0 "other level or doesn't know"
label values dependence_regional regional
label variable dependence_regional "In 10 years, our living conditions will be influenced by regional descisions"
*"Dans dix ans, les conditions dependront des decisions prises au niveau regional?"

clonevar dependence_france=q8
replace dependence_france=1 if q8==2
replace dependence_france=0 if q8!=2
label define national 1 "national level" 0 "other level or doesn't know"
label values dependence_france national
label variable dependence_france "In 10 years, our living conditions will be influenced by national descisions"
*"Dans dix ans, les conditions dependront des dÍ§©sions prises au niveau national?"

clonevar dependence_europe=q8
replace dependence_europe=1 if q8==3
replace dependence_europe=0 if q8!=3
label define european 1 "European level" 0 "other level or doesn't know"
label values dependence_europe european
label variable dependence_europe "In 10 years, our living conditions will be influenced by European descisions"
*"Dans dix ans, les conditions dependront des dÍ§©sions prises au niveau europe?"


local varlist q10a1 q10a2 q10a3 q10a4 q10a5 q10a6
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace `var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
} 

rename q10a1 opinion_management_health
label variable opinion_management_health "Health issues should be managed at regional instead of state-level management"

rename q10a2 opinion_management_culture
label variable opinion_management_culture "Cultural issues should be managed at regional instead of state-level management"

rename q10a3 opinion_management_education
label variable opinion_management_education "Education staff should be managed at regional instead of state-level management"

rename q10a4 opinion_management_youthcon
label variable opinion_management_youthcon "Youth consulting should be managed at regional instead of state-level management"

rename q10a5 opinion_management_youthed
label variable opinion_management_youthed "Youth education should be managed at regional instead of state-level management"

rename q10a6 opinion_management_bus
label variable opinion_management_bus "Business support should be managed at regional instead of state-level management"

local varlist q11a1 q11a2 q11a3 q11a4
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace `var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}

rename q11a1 concern_tax
label variable concern_tax "I am concerned regional administration would lead to tax increases"

rename q11a2 concern_ineq
label variable concern_ineq "I am concerned regional administration would increase interregional inequality"

rename q11a3 concern_emp
label variable concern_emp "I am concerned regional administration would worsen the situation of state employees in the region"

rename q11a4 concern_pub
label variable concern_pub "I am concerned regional administration would lead to a decrease in public service quality"

********************************************************************************************************************
local varlist q12a1 q12a2 q12a3 q12a4 q12a5
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace `var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}

rename q12a1 favorability_lycee1
label variable favorability_lycee1 "I am in favor of regional management of high school implementation"

rename q12a2 favorability_lycee2
label variable favorability_lycee2 "I am in favor of regional management of high school teachers"

rename q12a3 favorability_lycee3
label variable favorability_lycee3 "I am in favor of management of high school standards and staff administration"

rename q12a4 favorability_lycee4
label variable favorability_lycee4 "I am in favor of regional management of school programs and diplomas"

rename q12a5 favorability_lycee5
label variable favorability_lycee5 "I am in favor of regional management of university implanation"
*********************************************************************************************************************
local varlist  q1a3 q1a4 q13 q9 q1a3 q1a4
foreach var in `varlist' {
clonevar X`var'=`var'
replace X`var'=1 if `var'==4
replace X`var'=2 if `var'==3
replace X`var'=3 if `var'==2
replace X`var'=4 if `var'==1
replace `var'=. if `var'==5 
label define LabX`var' 1 "Disagree strongly" 2 "Disagree"  3 "Agree" 4 "Strongly agree" ,modify
label values X`var' LabX`var'
drop `var'
ren X`var' `var'
}
rename q13 european_citizen
label variable european_citizen "I think of myself as a European citizen? "

rename q1a2 Opt_reg_future
label variable Opt_reg_future "I am optimistic about the future of my region"

rename   q1a3 Opt_nation_future
label variable Opt_nation_future "I am optimistic about the future of the central state"

rename q1a4 Opt_EU_future
label variable Opt_EU_future "I am optimistic about the future of the EU"

egen Av_educationOIP2003=rowmean(favorability_lycee1 favorability_lycee2 favorability_lycee3  favorability_lycee4 favorability_lycee5)
label var  Av_educationOIP2003 "Decisions about education should be taken at regional level"

************Tables
****************
gen ID_2=dep
merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"
drop if _merge ==1 | _merge ==2
drop _merge 
gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1
gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1
label define row 0 "Second Row" 1  "First Row",modify
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"
keep ID_2 dep age gender employmentstatus rs13 treat_AL Av_educationOIP2003 row_dum row_dum2
save "processed data\oip2003.dta",replace


***************************Cahiers 1789***************************************
import excel "cahiers1789.xlsx", sheet("data") firstrow clear
drop  N O
ren dep Dpartement

destring Clergy, replace
destring Nobility, replace
destring ThirdEstate, replace

*Generate average:
egen NatIden=rowmean( Nobility ThirdEstate UnitedOrders)  //Mean of the regular people
label var NatIden "National Identity among nobility, third estate and united orders"
tab Dpartement,sum(NatIden )
***Adjust by hand so names match
ren municipality commune
save "processed data\cahiers.dta",replace
*
use "processed data\cahiers.dta",replace
keep if code==55 | code==54 | code ==57
tab Dpartement,sum(NatIden )
save "processed data\cahiers_lorraine.dta",replace
**************************************************************************
use "processed data\oip1999_temp.dta", clear
cap drop treat_AL
gen treat_AL = .
replace treat_AL=0 if dep == 54 | dep == 55   | dep == 88
replace treat_AL = 1 if dep == 67 | dep == 68 | dep == 57

rename dep ID_2

gen is_aslr = 0
replace is_aslr = 1 if treat_AL ==1

estimates drop _all

eststo: reg DemoRegion is_aslr age gender employmentstatus if treat_AL!=., r
estadd ysumm
eststo: reg DemoFrance is_aslr age gender employmentstatus if treat_AL!=., r
estadd ysumm
eststo: reg Optm_region is_aslr age gender employmentstatus if treat_AL!=., r
estadd ysumm
eststo: reg Optm_france is_aslr age gender employmentstatus if treat_AL!=., r
estadd ysumm
merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"
drop if _merge ==1 | _merge ==2
drop _merge

gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1
gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1
label define row 0 "Second Row" 1  "First Row",modify
label values row_dum row
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"
label variable row_dum "Spatial Position of Department relativ to national border (only bordering neighbouring countries)"
estimates drop _all
save "processed data\oip1999.dta",replace

************************************* OID 2000 ****************************************************************************
usespss "fr_cdsp_ddi_oip_2000_F1.sav",clear
gen treat_AL = .
replace treat_AL=0 if dep == 54 | dep == 55  | dep == 88
replace treat_AL = 1 if dep == 67 | dep == 68 | dep == 57
label var treat_AL "Binary Indicator for AL indicating treatment"
*keep if dep=="Territoire de Belfort" |dep=="Haut-Rhin" |dep=="Bas-Rhin" |dep=="Bas-Rhin" |dep=="Meurthe-et-Moselle"|dep=="Moselle " |dep=="Meuse"
*keep if dep==67 |dep==54 |dep==68 |dep==55 |dep==90|dep==88|dep==57
gen treat_L=.
replace treat_L=1 if dep==57
replace treat_L=0 if dep==54 | dep==55
label var treat_L "Binary Indicator for Lorraine indicating treatment"

label var age5 "Age in 5 classes"
label var agglo5 "Size of home town in 5 classes"
ren rs1 age
label var age "Age in years"
replace rs2=0 if rs2==2
ren rs2 gender
label define genderX 1 "male" 0 "female"
label values   gender genderX

ren rs5 employmentstatus
replace employmentstatus=0 if employmentstatus==6 |employmentstatus==.a |employmentstatus==.b
label define employmentstatusX 0 "Dont know or no answer" 1 "Self-employed" 2 "Employer" 3 "Receives private salary" 4 "Public service" 5 "Public Enterprise employee" 
label values   employmentstatus employmentstatusX


replace q4 =. if q4 == 4 | q4 == .b
replace q10 = . if q10 ==5

codebook q4 q10

ttest q4, by(treat_AL)
ttest q10, by(treat_AL)

gen is_aslr = 0
replace is_aslr = 1 if treat_AL ==1

reg q4 is_aslr age gender employmentstatus if treat_AL!=., r
reg q10 is_aslr age gender employmentstatus if treat_AL!=., r


ren dep ID_2

merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"

drop if _merge ==1 | _merge ==2
drop _merge

gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1

gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1

label define row 0 "Second Row" 1  "First Row",modify
label values row_dum row
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"
label variable row_dum "Spatial Position of Department relativ to national border (only bordering neighbouring countries)"

save "processed data\quest2000.dta", replace

collapse reginsee, by(ID_2)
ren ID_2 dep

save "processed data\region_ID.dta", replace

******************************************************************************
usespss "fr.cdsp.ddi.PEFV2_F1.sav",clear
merge m:1 dep using "processed data\region_ID.dta", nogen
gen age = 2002 - q100 
label var age "Age in years"
ren xq101 gender
label define genderX 1 "male" 2 "female"
label values gender genderX


tab xq106
tab xq107

replace xq242 = . if xq242 ==0
replace xq242 = 0 if xq242 == 2
replace xq242 = 2 if xq242 == 1
replace xq242 = 1 if xq242 == 3
ren xq242 Opinion_EU


replace xq43 = . if xq43 ==0 | xq43 ==4
ren xq43 identification_EU_FRA

gen is_aslr = .
replace is_aslr = 0 if dep == 88 | dep == 54 | dep == 55
replace is_aslr = 1 if dep == 67 | dep == 68 | dep == 57

//xq243_0 xq243_1 xq243_2 xq243_3 xq243_4

replace xq243_0 = . if xq243_0 == 0
replace xq243_1 = . if xq243_1 == 0
replace xq243_2 = . if xq243_2 == 0
replace xq243_3 = . if xq243_3 == 0
replace xq243_4 = . if xq243_4 == 0

ren xq243_0 Pay
ren xq243_1 Protection
ren xq243_2 Identity
ren xq243_3 International
ren xq243_4 Immigrants
ren xq109 employmentstatus
replace employmentstatus=. if employmentstatus==99
label define employmentstatusX 0 "No answer" 1 "Self-employed or Employer" 2 "Receives private salary" 4 "Public service" 3 "Public Enterprise employee" 
label values   employmentstatus employmentstatusX
ren dep ID_2

merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"

drop if _merge ==1 | _merge ==2
drop _merge

gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1
gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1

label define row 0 "Second Row" 1  "First Row",modify
label values row_dum row
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"
label variable row_dum "Spatial Position of Department relativ to national border (only bordering neighbouring countries)"
save "processed data\quest2002.dta", replace
**********************************************************
use "processed data\quest2000.dta", clear
cap ren q10 dem_EU
replace dem_EU= 5 - dem_EU
cap label define demo 1 "very bad" 2 "bad" 3 "good" 4 "very good"
label values dem_EU demo
cap egen st_dem_EU1 = std(dem_EU) if treat_AL!=.
cap egen st_dem_EU2 = std(dem_EU) if treat_AL==.
save "processed data\quest2000.dta", replace
*******************************************************
use "processed data\quest2002.dta", clear
replace Opinion_EU = . if Opinion_EU == 0
replace Opinion_EU = 0 if Opinion_EU == 2
cap label define opinion 0 "bad" 1 "good"
label values   Opinion_EU opinion
cap egen st_Opinion_EU1 = std(Opinion_EU) if is_aslr!=.
cap egen st_Opinion_EU2 = std(Opinion_EU) if is_aslr==.
save "processed data\quest2002.dta", replace

*********************
use "processed data\oip99_01_temp.dta",clear

gen is_aslr = 0
replace is_aslr = 1 if treat_AL ==1

replace gender = . if gender == .a
replace age = . if age == .a

gen EuropeVSFrance = attachement_europe/attachement_france
gen RegionVSFrance = attachement_region/attachement_france
gen EuropeVSRegion = attachement_europe/attachement_region

gen ID_2=dep

merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"
drop if _merge ==1 | _merge ==2
drop _merge 

gen row_dum = .
replace row_dum = 1 if border_1_row == 1
replace row_dum = 0 if border_2_row == 1

gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1

label define row 0 "Second Row" 1  "First Row",modify
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"

drop dep_name all_border_1_row all_border_2_row

egen zattach_regionVSnation_rowdum = std(attach_regionVSnation) if row_dum!=. & treat_AL==.
label var zattach_regionVSnation_rowdum "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_rowdum = std(attach_EUVSnation) if row_dum!=. & treat_AL==.
label var zattach_EUVSnation_rowdum "European relative to national attachment, standardized"

egen zattach_regionVSnation_rowdum2 = std(attach_regionVSnation) if row_dum2!=. & treat_AL==.
label var zattach_regionVSnation_rowdum2 "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_rowdum2 = std(attach_EUVSnation) if row_dum2!=. & treat_AL==.
label var zattach_EUVSnation_rowdum2 "European relative to national attachment, standardized"

egen st_attachement_europe1 = std(attachement_europe) if treat_AL!=.
label variable st_attachement_europe1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_europe2 = std(attachement_europe) if row_dum2!=. & treat_AL==.
label variable st_attachement_europe2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_europe3 = std(attachement_europe) 
label variable st_attachement_europe3 "Standardization Level: All of France"
egen st_attachement_europe4 = std(attachement_europe) if treat_L!=.
label variable st_attachement_europe4 "Standardization Level: Lorraine"

egen st_attachement_france1 = std(attachement_france) if treat_AL!=.
label variable st_attachement_france1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_france2 = std(attachement_france) if row_dum2!=. & treat_AL==.
label variable st_attachement_france2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_france3 = std(attachement_france) 
label variable st_attachement_france3 "Standardization Level: All of France"
egen st_attachement_france4 = std(attachement_france) if treat_L!=.
label variable st_attachement_france4 "Standardization Level: Lorraine"

egen st_attachement_region1 = std(attachement_region) if treat_AL!=.
label variable st_attachement_region1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_region2 = std(attachement_region) if row_dum2!=. & treat_AL==.
label variable st_attachement_region2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_region3 = std(attachement_region) 
label variable st_attachement_region3 "Standardization Level: All of France"
egen st_attachement_region4 = std(attachement_region) if treat_L!=.
label variable st_attachement_region4 "Standardization Level: Lorraine"

egen st_attachement_department1 = std(attachement_department) if treat_AL!=.
label variable st_attachement_department1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_department2 = std(attachement_department) if row_dum2!=. & treat_AL==.
label variable st_attachement_department2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_department3 = std(attachement_department) 
label variable st_attachement_department3 "Standardization Level: All of France"
egen st_attachement_department4 = std(attachement_department) if treat_L!=.
label variable st_attachement_department4 "Standardization Level: Lorraine"

egen st_attachement_municipality1 = std(attachement_municipality) if treat_AL!=.
label variable st_attachement_municipality1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_municipality2 = std(attachement_municipality) if row_dum2!=. & treat_AL==.
label variable st_attachement_municipality2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_municipality3 = std(attachement_municipality) 
label variable st_attachement_municipality3 "Standardization Level: All of France"
egen st_attachement_municipality4 = std(attachement_municipality) if treat_L!=.
label variable st_attachement_municipality4 "Standardization Level: Lorraine"

egen st_EuropeVSFrance = std(EuropeVSFrance) if treat_AL!=.
egen st_EuropeVSFrance2 = std(EuropeVSFrance) if row_dum2!=. & treat_AL==.

egen st_RegionVSFrance = std(RegionVSFrance) if treat_AL!=.
egen st_RegionVSFrance2 = std(RegionVSFrance) if row_dum2!=. & treat_AL==.

egen st_EuropeVSRegion = std(EuropeVSRegion) if treat_AL!=.
egen st_EuropeVSRegion2 = std(EuropeVSRegion) if row_dum2!=. & treat_AL==.

keep treat_AL ID_2 age gender year employmentstatus rs13 attachement_region attachement_france Av_transferOIP200 row_dum row_dum2 attachement_europe year

save "processed data\oip99_01.dta", replace

****** Attachment Dataset ***********************

use "processed data\oip1995_attachment.dta",clear
foreach x in 1997 1999 {
append using "processed data\oip`x'_attachment.dta"
}
gen is_aslr = 0
replace is_aslr = 1 if treat_AL ==1

replace gender = . if gender == .a
replace age = . if age == .a

gen EuropeVSFrance = attachement_europe/attachement_france
gen RegionVSFrance = attachement_region/attachement_france
gen EuropeVSRegion = attachement_europe/attachement_region

gen attach_regionVSnation=attachement_region/attachement_france
label var attach_regionVSnation "Regional relative to national attachment"
gen attach_EUVSnation=attachement_europe/attachement_france
label var attach_EUVSnation "European relative to national attachment"

ren dep ID_2

merge m:1 ID_2 using "processed data\dep_closesness_to_border.dta"
drop if _merge ==1 | _merge ==2
drop _merge border_1_row border_2_row

gen row_dum2 = .
replace row_dum2 = 1 if all_border_1_row == 1
replace row_dum2 = 0 if all_border_2_row == 1

label define row 0 "Second Row" 1  "First Row",modify
label values row_dum2 row
label variable row_dum2 "Spatial Position of Department relativ to national border"

drop dep_name all_border_1_row all_border_2_row

egen zattach_regionVSnation_rowdum = std(attach_regionVSnation) if row_dum!=. & treat_AL==.
label var zattach_regionVSnation_rowdum "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_rowdum = std(attach_EUVSnation) if row_dum!=. & treat_AL==.
label var zattach_EUVSnation_rowdum "European relative to national attachment, standardized"


egen zattach_regionVSnation_rowdum2 = std(attach_regionVSnation) if row_dum2!=. & treat_AL==.
label var zattach_regionVSnation_rowdum2 "Regional relative to national attachment, standardized"
egen zattach_EUVSnation_rowdum2 = std(attach_EUVSnation) if row_dum2!=. & treat_AL==.
label var zattach_EUVSnation_rowdum2 "European relative to national attachment, standardized"


egen st_attachement_europe1 = std(attachement_europe) if treat_AL!=.
label variable st_attachement_europe1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_europe2 = std(attachement_europe) if row_dum2!=. & treat_AL==.
label variable st_attachement_europe2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_europe3 = std(attachement_europe) 
label variable st_attachement_europe3 "Standardization Level: All of France"
egen st_attachement_europe4 = std(attachement_europe) if treat_L!=.
label variable st_attachement_europe4 "Standardization Level: Lorraine"

egen st_attachement_france1 = std(attachement_france) if treat_AL!=.
label variable st_attachement_france1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_france2 = std(attachement_france) if row_dum2!=. & treat_AL==.
label variable st_attachement_france2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_france3 = std(attachement_france) 
label variable st_attachement_france3 "Standardization Level: All of France"
egen st_attachement_france4 = std(attachement_france) if treat_L!=.
label variable st_attachement_france4 "Standardization Level: Lorraine"

egen st_attachement_region1 = std(attachement_region) if treat_AL!=.
label variable st_attachement_region1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_region2 = std(attachement_region) if row_dum2!=. & treat_AL==.
label variable st_attachement_region2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_region3 = std(attachement_region) 
label variable st_attachement_region3 "Standardization Level: All of France"
egen st_attachement_region4 = std(attachement_region) if treat_L!=.
label variable st_attachement_region4 "Standardization Level: Lorraine"

egen st_attachement_department1 = std(attachement_department) if treat_AL!=.
label variable st_attachement_department1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_department2 = std(attachement_department) if row_dum2!=. & treat_AL==.
label variable st_attachement_department2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_department3 = std(attachement_department) 
label variable st_attachement_department3 "Standardization Level: All of France"
egen st_attachement_department4 = std(attachement_department) if treat_L!=.
label variable st_attachement_department4 "Standardization Level: Lorraine"

egen st_attachement_municipality1 = std(attachement_municipality) if treat_AL!=.
label variable st_attachement_municipality1 "Standardization Level: Alsace and Lorraine"
egen st_attachement_municipality2 = std(attachement_municipality) if row_dum2!=. & treat_AL==.
label variable st_attachement_municipality2 "Standardization Level: Border and Adjacent Departments"
egen st_attachement_municipality3 = std(attachement_municipality) 
label variable st_attachement_municipality3 "Standardization Level: All of France"
egen st_attachement_municipality4 = std(attachement_municipality) if treat_L!=.
label variable st_attachement_municipality4 "Standardization Level: Lorraine"

egen st_EuropeVSFrance = std(EuropeVSFrance) if treat_AL!=.
egen st_EuropeVSFrance2 = std(EuropeVSFrance) if row_dum2!=. & treat_AL==.

egen st_RegionVSFrance = std(RegionVSFrance) if treat_AL!=.
egen st_RegionVSFrance2 = std(RegionVSFrance) if row_dum2!=. & treat_AL==.

egen st_EuropeVSRegion = std(EuropeVSRegion) if treat_AL!=.
egen st_EuropeVSRegion2 = std(EuropeVSRegion) if row_dum2!=. & treat_AL==.

save "processed data\oip_attachment.dta", replace
***********************************************************************
